@@ -1,7 +1,7 @@
 #   This module defines and implements a class that represents
 #   a connection to a lond daemon.
 #
-# $Id: LondConnection.pm,v 1.46 2007/04/10 23:15:20 albertel Exp $
+# $Id: LondConnection.pm,v 1.47 2009/10/29 03:23:52 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -241,11 +241,11 @@ sub new {
 	if((defined $ca)  && (defined $cert) && (defined $sslkeyfile)) {
 
 	    $self->{AuthenticationMode} = "ssl";
-	    $self->{TransactionRequest} = "init:ssl\n";
+	    $self->{TransactionRequest} = "init:ssl:$perlvar{'lonVersion'}\n";
 	} else {
 	    if($InsecureOk) {		# Allowed to do insecure:
 		$self->{AuthenticationMode} = "insecure";
-		$self->{TransactionRequest} = "init\n";
+		$self->{TransactionRequest} = "init::$perlvar{'lonVersion'}\n";
 	    }
 	    else {		# Not allowed to do insecure...
 		$socket->close;
