@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Cookie Based Access Handler
 #
-# $Id: lonacc.pm,v 1.116.2.2 2008/12/31 20:22:47 raeburn Exp $
+# $Id: lonacc.pm,v 1.130.4.1 2010/03/19 22:22:34 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -27,6 +27,73 @@
 #
 ###
 
+=head1 NAME
+
+Apache::lonacc - Cookie Based Access Handler
+
+=head1 SYNOPSIS
+
+Invoked (for various locations) by /etc/httpd/conf/srm.conf:
+
+ PerlAccessHandler       Apache::lonacc
+
+=head1 INTRODUCTION
+
+This module enables cookie based authentication and is used
+to control access for many different LON-CAPA URIs.
+
+Whenever the client sends the cookie back to the server, 
+this cookie is handled by either lonacc.pm or loncacc.pm
+(see srm.conf for what is invoked when).  If
+the cookie is missing or invalid, the user is re-challenged
+for login information.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 HANDLER SUBROUTINE
+
+This routine is called by Apache and mod_perl.
+
+=over 4
+
+=item *
+
+transfer profile into environment
+
+=item *
+
+load POST parameters
+
+=item *
+
+check access
+
+=item *
+
+if allowed, get symb, log, generate course statistics if applicable
+
+=item *
+
+otherwise return error
+
+=item *
+
+see if public resource
+
+=item *
+
+store attempted access
+
+=back
+
+=head1 NOTABLE SUBROUTINES
+
+=over
+
+=cut
+
+
 package Apache::lonacc;
 
 use strict;
@@ -93,7 +160,7 @@ sub get_posted_cgi {
                     if (ref($fields) eq 'ARRAY') {
                         next if (!grep(/^\Q$name\E$/,@{$fields}));
                     }
-		    if ($fname) {
+                    if ($fname) {
                         if ($env{'form.symb'} ne '') {
                             my $size = (length($value))/(1024.0 * 1024.0);
                             if (&upload_size_allowed($name,$size,$fname) eq 'ok') {
@@ -102,14 +169,14 @@ sub get_posted_cgi {
                                 &Apache::loncommon::add_to_env("form.$name",$value);
                             }
                         } else {
-			    $env{"form.$name.filename"}=$fname;
-			    $env{"form.$name.mimetype"}=$fmime;
+                            $env{"form.$name.filename"}=$fname;
+                            $env{"form.$name.mimetype"}=$fmime;
                             &Apache::loncommon::add_to_env("form.$name",$value);
                         }
-		    } else {
-			$value=~s/\s+$//s;
+                    } else {
+                        $value=~s/\s+$//s;
                         &Apache::loncommon::add_to_env("form.$name",$value);
-		    }
+                    }
 		}
 		if ($i<$#lines) {
 		    $i++;
@@ -155,13 +222,17 @@ sub get_posted_cgi {
     $r->headers_in->unset('Content-length');
 }
 
-#
-# Perform size checks for file uploads to essayresponse items in course context.
-#
-# Add form.HWFILESIZE.$part_$id to %env with file size (MB)
-# If file exceeds maximum allowed size, add form.HWFILETOOBIG.$part_$id to %env.
-#
+=pod
 
+=item upload_size_allowed()
+
+	Perform size checks for file uploads to essayresponse items in course context.
+	
+	Add form.HWFILESIZE.$part_$id to %env with file size (MB)
+	If file exceeds maximum allowed size, add form.HWFILETOOBIG.$part_$id to %env.
+
+=cut
+ 
 sub upload_size_allowed {
     my ($name,$size,$fname) = @_;
     if ($name =~ /^HWFILE(\w+)$/) {
@@ -182,12 +253,18 @@ sub upload_size_allowed {
     return 'ok';
 }
 
+=pod
+
+=item sso_login()
+
+	handle the case of the single sign on user, at this point $r->user 
+	will be set and valid now need to find the loncapa user info and possibly
+	balance them
+	returns OK if it was a SSO and user was handled
+        undef if not SSO or no means to hanle the user
+        
+=cut
 
-# handle the case of the single sign on user, at this point $r->user 
-# will be set and valid now need to find the loncapa user info and possibly
-# balance them
-# returns OK if it was a SSO and user was handled
-#         undef if not SSO or no means to hanle the user
 sub sso_login {
     my ($r,$handle) = @_;
 
@@ -201,6 +278,18 @@ sub sso_login {
 
     my ($user) = ($r->user =~ m/([a-zA-Z0-9_\-@.]*)/);
 
+    my $query = $r->args;
+    my %form;
+    if ($query) {
+        my @items = ('role','symb');
+        &Apache::loncommon::get_unprocessed_cgi($query,\@items);
+        foreach my $item (@items) {
+            if (defined($env{'form.'.$item})) {
+                $form{$item} = $env{'form.'.$item};
+            }
+        }
+    }
+
     my $domain = $r->dir_config('lonDefDomain');
     my $home=&Apache::lonnet::homeserver($user,$domain);
     if ($home !~ /(con_lost|no_host|no_such_host)/) {
@@ -225,6 +314,11 @@ sub sso_login {
 		      'server'    => $r->dir_config('lonHostID'),
 		      'sso.login' => 1
 		      );
+            foreach my $item ('role','symb') {
+                if (exists($form{$item})) {
+                    $info{$item} = $form{$item};
+                }
+            }
             if ($r->dir_config("ssodirecturl") == 1) {
                 $info{'origurl'} = $r->uri;
             }
@@ -278,7 +372,7 @@ sub handler {
     if ($requrl =~ m{^/res/adm/pages/[^/]+\.(gif|png)$}) {
         return OK;
     }
- 
+
     my $handle = &Apache::lonnet::check_for_valid_session($r);
 
     my $result = &sso_login($r,$handle);
@@ -317,6 +411,22 @@ sub handler {
 	}
 	$env{'request.filename'} = $r->filename;
 	$env{'request.noversionuri'} = &Apache::lonnet::deversion($requrl);
+        if ($requrl =~ m{^/adm/wrapper/ext/}) {
+            my $query = $r->args;
+            if ($query) {
+                my $preserved;
+                foreach my $pair (split(/&/,$query)) {
+                    my ($name, $value) = split(/=/,$pair);
+                    unless (($name eq 'symb') || ($name eq 'wrapperdisplay')) {
+                        $preserved .= $pair.'&';
+                    }
+                }
+                $preserved =~ s/\&$//;
+                if ($preserved) {
+                    $env{'request.external.querystring'} = $preserved;
+                }
+            }
+        }
 # -------------------------------------------------------- Load POST parameters
 
 	&Apache::lonacc::get_posted_cgi($r);
@@ -339,8 +449,24 @@ sub handler {
                 return OK;
             }
 	    if (($access ne '2') && ($access ne 'F')) {
-		$env{'user.error.msg'}="$requrl:bre:1:1:Access Denied";
-		return HTTP_NOT_ACCEPTABLE; 
+                if ($requrl =~ m{^/res/}) {
+                    $access = &Apache::lonnet::allowed('bro',$requrl);
+                    if ($access ne 'F') {
+                        if ($requrl eq '/res/lib/templates/simpleproblem.problem/smpedit') {
+                            $access = &Apache::lonnet::allowed('bre','/res/lib/templates/simpleproblem.problem');
+                            if ($access ne 'F') {
+                                $env{'user.error.msg'}="$requrl:bre:1:1:Access Denied";
+                                return HTTP_NOT_ACCEPTABLE;
+                            }
+                        } else {
+                            $env{'user.error.msg'}="$requrl:bre:1:1:Access Denied";
+                            return HTTP_NOT_ACCEPTABLE;
+                        }
+                    }
+                } else {
+		    $env{'user.error.msg'}="$requrl:bre:1:1:Access Denied";
+		    return HTTP_NOT_ACCEPTABLE;
+                }
 	    }
 	}
 	if ($requrl =~ m|^/prtspool/|) {
@@ -363,6 +489,7 @@ sub handler {
 	    $env{'user.domain'} eq 'public' &&
 	    $requrl !~ m{^/+(res|public|uploaded)/} &&
 	    $requrl !~ m{^/adm/[^/]+/[^/]+/aboutme/portfolio$ }x &&
+        $requrl !~ m{^/adm/blockingstatus/.*$} &&
 	    $requrl !~ m{^/+adm/(help|logout|restrictedaccess|randomlabel\.png)}) {
 	    $env{'request.querystring'}=$r->args;
 	    $env{'request.firsturl'}=$requrl;
@@ -372,6 +499,7 @@ sub handler {
 	if ($env{'request.course.id'}) {
 	    &Apache::lonnet::countacc($requrl);
 	    $requrl=~/\.(\w+)$/;
+            my $query=$r->args;
 	    if ((&Apache::loncommon::fileembstyle($1) eq 'ssi') ||
 		($requrl=~/^\/adm\/.*\/(aboutme|navmaps|smppg|bulletinboard)(\?|$ )/x) ||
 		($requrl=~/^\/adm\/wrapper\//) ||
@@ -379,7 +507,6 @@ sub handler {
 		($requrl=~m|\.problem/smpedit$|) ||
 		($requrl=~/^\/public\/.*\/syllabus$/)) {
 # ------------------------------------- This is serious stuff, get symb and log
-		my $query=$r->args;
 		my $symb;
 		if ($query) {
 		    &Apache::loncommon::get_unprocessed_cgi($query,['symb']);
@@ -426,6 +553,18 @@ sub handler {
 # ------------------------------------------------------- This is other content
 		&Apache::lonnet::courseacclog($requrl);    
 	    }
+            my $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};;
+            my $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};;
+            if ($requrl =~ m{^/+uploaded/\Q$cdom\E/\Q$cnum\E/docs/.+\.html?$}) {
+                if (&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) {
+                    if ($query) {
+                        &Apache::loncommon::get_unprocessed_cgi($query,['forceedit']);
+                        if ($env{'form.forceedit'}) {
+                            $env{'request.state'} = 'edit';
+                        }
+                    }
+                }
+            }
 	}
 	return OK;
     }
@@ -464,64 +603,9 @@ sub handler {
 1;
 __END__
 
-=head1 NAME
-
-Apache::lonacc - Cookie Based Access Handler
-
-=head1 SYNOPSIS
-
-Invoked (for various locations) by /etc/httpd/conf/srm.conf:
-
- PerlAccessHandler       Apache::lonacc
-
-=head1 INTRODUCTION
-
-This module enables cookie based authentication and is used
-to control access for many different LON-CAPA URIs.
-
-Whenever the client sends the cookie back to the server, 
-this cookie is handled by either lonacc.pm or loncacc.pm
-(see srm.conf for what is invoked when).  If
-the cookie is missing or invalid, the user is re-challenged
-for login information.
-
-This is part of the LearningOnline Network with CAPA project
-described at http://www.lon-capa.org.
-
-=head1 HANDLER SUBROUTINE
-
-This routine is called by Apache and mod_perl.
-
-=over 4
-
-=item *
-
-transfer profile into environment
-
-=item *
-
-load POST parameters
-
-=item *
-
-check access
-
-=item *
-
-if allowed, get symb, log, generate course statistics if applicable
-
-=item *
-
-otherwise return error
-
-=item *
-
-see if public resource
-
-=item *
-
-store attempted access
+=pod
 
 =back
 
 =cut
+
