@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Logout Handler
 #
-# $Id: lonlogout.pm,v 1.32 2008/08/01 11:04:09 bisitz Exp $
+# $Id: lonlogout.pm,v 1.37 2009/03/16 17:07:38 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,6 +26,19 @@
 # http://www.lon-capa.org/
 #
 
+=head1 NAME
+
+Apache::lonlogout
+
+=head1 SYNOPSIS
+
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+
+=cut
+
 package Apache::lonlogout;
 
 use strict;
@@ -85,7 +98,7 @@ sub handler {
     my $relogmessage='';
     if ($env{'form.handover'}) {
 	$switch='<meta HTTP-EQUIV="Refresh" CONTENT="0.5; url='.
-	    $env{'form.handover'}.'">';
+	    $env{'form.handover'}.'" />';
 	$start_page=&Apache::loncommon::start_page('Switching Server ...',
 						   $switch);
     } else {
@@ -105,11 +118,18 @@ sub handler {
 
             $relogmessage.='<p>'.&mt('You have been successfully logged out.').' '
                           .&mt('You can [_1]close this window[_2] now.'
-                              ,'','')
-#                              ,'<a href="javascript:self.close();">','</a>');
-# Due to security reasons in new web browsers a window could only be closed with java script, if this window has also been opend with javascript. This is not done here which means that in most cases the close link will not work. Unless we find another solution, this link should not be offered. (Stefan Bisitz, 2008-08-01)
-                          .'</p>'
-                          .'<p>'.&mt('[_1]Log in again[_2]'
+                              ,'','') # ,'<a href="javascript:self.close();">','</a>')
+                          .'</p>';
+=pod
+
+=head1 NOTES:
+
+'<a href="javascript:self.close();">','</a>'
+
+Due to security reasons in new web browsers a window could only be closed with java script, if this window has also been opend with javascript. This is not done here which means that in most cases the close link will not work. Unless we find another solution, this link should not be offered. (Stefan Bisitz, 2008-08-01)
+
+=cut
+            $relogmessage.='<p>'.&mt('[_1]Log in again[_2]'
                               ,'<a href="'.$login_url.'?domain='.$env{'user.domain'}.'">','</a>')
                           .'</p>';
         }
@@ -152,4 +172,3 @@ __END__
 
 
 
-
