@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 # Gets keywords from metadata database.
-# $Id: metadata_keywords.pl,v 1.8 2008/12/25 01:56:03 raeburn Exp $
+# $Id: metadata_keywords.pl,v 1.9 2009/01/06 08:58:30 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -102,7 +102,7 @@ sub main {
     undef($perlvarref);
 
     unless ($perlvar{'lonRole'} eq 'library') {
-         print(&Apache::lonlocal::mt('This can only be run on a library server!)."\n");
+         print(&Apache::lonlocal::mt('This can only be run on a library server!')."\n");
          return;
     }
 
