@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # caparesponse definition
 #
-# $Id: caparesponse.pm,v 1.235 2008/09/23 19:15:57 raeburn Exp $
+# $Id: caparesponse.pm,v 1.236 2009/01/15 18:31:23 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -752,16 +752,17 @@ sub end_numericalresponse {
 	    if ($ad ne 'EXACT_ANS' && $ad ne 'APPROX_ANS') {
 		my $error;
 		if ($tag eq 'formularesponse') {
-		    $error=&mt('Computer\'s answer is incorrect ("[_1]").',join(', ',@$response));
+		    $error=&mt("Computer's answer is incorrect ([_1]).",'"'.join(', ',@$response).'"');
 		} else {
 		    # answer failed check if it is sig figs that is failing
 		    my ($ad,$msg)=&check_submission($response,$partid,$id,
 						    $tag,$parstack,
 						    $safeeval,1);
+		    $error=&mt("Computer's answer is incorrect ([_1]).",'"'.join(', ',@$response).'"').' ';
 		    if ($sigline ne '') {
-			$error=&mt('Computer\'s answer is incorrect ("[_1]"). It is likely that the tolerance range [_2] or significant figures [_3] need to be adjusted.',join(', ',@$response),$tolline,$sigline);
+			$error.=&mt('It is likely that the tolerance range [_1] or significant figures [_2] need to be adjusted.',$tolline,$sigline);
 		    } else {
-			$error=&mt('Computer\'s answer is incorrect ("[_1]"). It is likely that the tolerance range [_2] needs to be adjusted.',join(', ',@$response),$tolline);
+			$error.=&mt('It is likely that the tolerance range [_1] needs to be adjusted.',$tolline);
 		    }
 		}
 		if ($ad ne 'EXACT_ANS' && $ad ne 'APPROX_ANS') {
