@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # edit mode helpers
 #
-# $Id: edit.pm,v 1.122 2009/02/18 07:06:12 raeburn Exp $
+# $Id: edit.pm,v 1.123.4.1 2010/01/31 00:47:41 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,6 +26,8 @@
 # http://www.lon-capa.org/
 #
 
+=pod
+
 =head1 NAME
 
 Apache::edit - edit mode helpers
@@ -612,6 +614,18 @@ sub insert_numericalhint {
 </numericalhint>';
 }
 
+sub insert_reactionhint {
+    return '
+<reactionhint>
+</reactionhint>';
+}
+
+sub insert_organichint {
+    return '
+<organichint>
+</organichint>';
+}
+
 sub insert_stringhint {
     return '
 <stringhint>
