@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Interface routines to MAXIMA CAS
 #
-# $Id: lonmaxima.pm,v 1.26 2008/09/24 18:01:07 riegler Exp $
+# $Id: lonmaxima.pm,v 1.28 2008/12/10 23:28:04 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -61,7 +61,7 @@ sub maximareply {
 sub blacklisted {
     my ($cmd)=@_;
     foreach my $forbidden (
-        '\? ','\?','%o','batch','block'
+        '\? ','\?','%i\d+','%o','batch','block'
        ,'compil','concat','describe','display2d','file','inchar'
        ,'includ','lisp','load','outchar','plot','quit'
        ,'read','reset','save','stin','stout','stringout'
