@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # rank style response
 #
-# $Id: rankresponse.pm,v 1.57.2.2 2008/12/18 20:04:46 raeburn Exp $
+# $Id: rankresponse.pm,v 1.61 2008/12/12 09:19:34 bisitz Exp $
 # Copyright Michigan State University Board of Trustees
 #
 # This file is part of the LearningOnline Network with CAPA (LON-CAPA).
@@ -30,6 +30,8 @@ use strict;
 use HTML::Entities();
 use Apache::optionresponse();
 use Apache::lonlocal;
+use Apache::lonxml;
+use Apache::lonnet;
 
 BEGIN {
     &Apache::lonxml::register('Apache::rankresponse',('rankresponse'));
@@ -48,7 +50,7 @@ sub start_rankresponse {
     if ($target eq 'meta') {
 	$result=&Apache::response::meta_package_write('rankresponse');
     } elsif ($target eq 'edit' ) {
-        $result.=&Apache::edit::start_table($token)
+	$result.=&Apache::edit::start_table($token)
            .'<tr><td>'.&Apache::lonxml::description($token).'</td>'
            .'<td><span class="LC_nobreak">'.&mt('Delete?').' '
            .&Apache::edit::deletelist($target,$token)
@@ -319,24 +321,43 @@ sub displayfoils {
 	my %lastresponse=&Apache::lonnet::str2hash($lastresponse); 
 	my @alp = splice @alphabet, 0, $#whichopt + 1;
 	my $internal_counter=$Apache::lonxml::counter;
-	foreach my $name (@whichfoils) {
+        if($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes') {
+            $result .= '\strut \\\\ \strut \\\\' ;
+        }
+        foreach my $name (@whichfoils) {
 	    my $lastopt=$lastresponse{$name};
 	    my $optionlist='';
-	    if ($target ne 'tex') {$optionlist="<option></option>\n";}
+	    if ($target ne 'tex') {
+                $optionlist = "<option></option>\n";
+            } 
+            if ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes') {
+                my $fieldname = $env{'request.symb'}.'&part_'.$Apache::inputtags::part.'&rankresponse'.'&HWVAL_'.$Apache::inputtags::response['-1'].':'.$temp;
+                $optionlist =  &Apache::lonxml::print_pdf_start_combobox($fieldname);
+            }
 	    my $option;
 	    foreach $option (@whichopt) {
 		if ($option eq $lastopt) {
-		    if ($target ne 'tex') {$optionlist.="<option selected=\"on\">$option</option>\n";}
+		    if ($target ne 'tex' ) {
+                        $optionlist.="<option selected=\"on\">$option</option>\n";
+                    } elsif ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes') {
+                        $optionlist .= &Apache::lonxml::print_pdf_add_combobox_option($option); 
+                    }
 		} else {
-		    if ($target ne 'tex') {$optionlist.="<option>$option</option>\n";}
-		}
+		    if ($target ne 'tex') {
+                        $optionlist.="<option>$option</option>\n";
+                    } elsif ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes') {
+                        $optionlist .= &Apache::lonxml::print_pdf_add_combobox_option($option); 
+                    }
+		} 
 	    }
 	    if ($target ne 'tex' && $Apache::lonhomework::type ne 'exam') {
 		$optionlist='<select onchange="javascript:setSubmittedPart(\''.
 		  $part.'\');" name="HWVAL_'.
 		    $Apache::inputtags::response[-1].':'.$temp.'">'.
 		        $optionlist."</select>\n";
-	    } else {
+	    } elsif ($env{'form.pdfFormFields'} eq 'yes') {
+                #do nothing
+            } else {
 		$optionlist=' '.$temp.' '.$optionlist.' ';
 	    }
 	    my $text=$Apache::response::foilgroup{$name.'.text'};
@@ -356,7 +377,11 @@ sub displayfoils {
 		    $result.='\vskip -1 mm\noindent\begin{enumerate}\item[\textbf{'.$internal_counter.'}.]'.&Apache::optionresponse::bubbles(\@alp,\@whichopt,'rankresponse').'\end{enumerate} \vskip -8 mm \strut ';
 		    $internal_counter++;
 		} else {
-		    $result.=' \vskip 0mm \framebox[5 mm][s]{\tiny\strut} '.$text."\n";
+                    if($env{'form.pdfFormFields'} ne 'yes') {
+		        $result.=' \vskip 0mm \framebox[5 mm][s]{\tiny\strut} '.$text."\n";
+                    } else {
+                        $result.= $optionlist.' '. &Apache::lonxml::print_pdf_end_combobox($text).'\strut \\\\';
+                    }
 		}
 	    }
 	    $temp++;
