@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # various response type definitons response definition
 #
-# $Id: response.pm,v 1.206.2.1 2008/12/11 04:11:09 raeburn Exp $
+# $Id: response.pm,v 1.216 2009/05/24 13:08:18 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,11 +26,35 @@
 # http://www.lon-capa.org/
 #
 
+=pod
+
+=head1 NAME
+
+Apache::resonse.pm
+
+=head1 SYNOPSIS
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+
+=head1 NOTABLE SUBROUTINES
+
+=over
+
+=item 
+
+=back
+
+=cut
+
+
 package Apache::response;
 use strict;
 use Apache::lonlocal;
 use Apache::lonnet;
 use Apache::lonmaxima();
+use Apache::lonr();
 
 BEGIN {
     &Apache::lonxml::register('Apache::response',('responseparam','parameter','dataresponse','customresponse','mathresponse'));
@@ -216,35 +240,26 @@ sub meta_stores_write {
 		      "></stores>\n";
 }
 
+=pod
+
+=item mandatory_part_meta()
+
+Autogenerate metadata for mandatory
+input (from RAT or lonparmset) and
+output (to lonspreadsheet)
+of each part
+
+Note: responseid-specific data 'submission' and 'awarddetail'
+not available to spreadsheet -> skip here
+
+=cut
+
+
 sub mandatory_part_meta {
-#
-# Autogenerate metadata for mandatory
-# input (from RAT or lonparmset) and 
-# output (to lonspreadsheet)
-# of each part
-#
-    return
-#    &meta_parameter_write('opendate','date_start','',
-#                          'Opening Date').
-#    &meta_parameter_write('duedate','date_end','',
-#                          'Due Date').
-#    &meta_parameter_write('answerdate','date_start','',
-#                          'Show Answer Date').
-#    &meta_parameter_write('weight','int_zeropos','',
-#                          'Available Points').
-#    &meta_parameter_write('maxtries','int_pos','',
-#                          'Maximum Number of Tries').
-	&meta_package_write('part').
-        &meta_stores_write('solved','string',
-			   'Problem Status').
-        &meta_stores_write('tries','int_zeropos',
-			   'Number of Attempts').
-        &meta_stores_write('awarded','float',
-			   'Partial Credit Factor');
-#
-# Note: responseid-specific data 'submission' and 'awarddetail'
-# not available to spreadsheet -> skip here
-#
+    return &meta_package_write('part').
+           &meta_stores_write('solved','string','Problem Status').
+           &meta_stores_write('tries','int_zeropos','Number of Attempts').
+           &meta_stores_write('awarded','float','Partial Credit Factor');
 }
 
 sub meta_part_order {
@@ -269,7 +284,7 @@ sub check_for_previous {
     my %previous;
     $previous{'used'} = 0;
     foreach my $key (sort(keys(%Apache::lonhomework::history))) {
-	if ($key =~ /resource\.$partid\.$id\.submission$/) {
+	if ($key =~ /resource\.\Q$partid\E\.\Q$id\E\.submission$/) {
 	    if ( $last && $key =~ /^(\d+):/ ) {
 		next if ($1 >= $last);
 	    }
@@ -424,7 +439,7 @@ sub end_customresponse {
 	    ${$safeeval->varglob('LONCAPA::customresponse_submission')}=
 		$response;
 	    
-	    my $award = &Apache::run::run('{ my $submission=$LONCAPA::customresponse_submission;'.$Apache::response::custom_answer[-1].'}',$safeeval);
+	    my ($award,$score) = &Apache::run::run('{ my $submission=$LONCAPA::customresponse_submission;'.$Apache::response::custom_answer[-1].'}',$safeeval);
 	    if (!&Apache::inputtags::valid_award($award)) {
 		$error = $award;
 		$award = 'ERROR';
@@ -432,6 +447,9 @@ sub end_customresponse {
 	    &Apache::response::handle_previous(\%previous,$award);
 	    $Apache::lonhomework::results{"resource.$part.$id.awarddetail"}=
 		$award;
+            if ($award eq 'ASSIGNED_SCORE') {
+                $Apache::lonhomework::results{"resource.$part.$id.awarded"}=1.0*$score;
+            }
 	    if ($error) {
 		$Apache::lonhomework::results{"resource.$part.$id.awardmsg"}=
 		    $error;
@@ -494,7 +512,7 @@ sub start_mathresponse {
 					 'answerdisplay',$token);
 	$result.=&Apache::edit::select_arg('Algebra System:',
 					   'cas',
-					   ['maxima'],
+					   ['maxima','R'],
 					   $token);
 	$result.=&Apache::edit::text_arg('Argument Array:',
 					 'args',$token).
@@ -524,14 +542,14 @@ sub edit_mathresponse_button {
 #    my $helplink=&Apache::loncommon::help_open_topic('Formula_Editor');
     my $iconpath=$Apache::lonnet::perlvar{'lonIconsURL'};
     return(<<ENDFORMULABUTTON);
-<script language="JavaScript">
+<script type="text/javascript" language="JavaScript">
 function edit_${id}_${field} (textarea) {
     thenumber = textarea;
     thedata = document.forms['lonhomework'].elements[textarea].value;
     newwin = window.open("/adm/dragmath/applet/MaximaPopup.html","","width=565,height=400,resizable");
 }
 </script>
-<a href="javascript:edit_${id}_${field}('${field}');void(0);"><img class="stift" src='$iconpath/stift.gif' alt='$button' title='$button'/></a>
+<a href="javascript:edit_${id}_${field}('${field}');void(0);"><img class="stift" src="$iconpath/stift.gif" alt="$button" title="$button" /></a>
 ENDFORMULABUTTON
 }
 
@@ -558,6 +576,12 @@ sub end_mathresponse {
                 $award=&Apache::lonmaxima::maxima_run($Apache::response::custom_answer[-1],$response,$args,
                                                       &Apache::lonxml::get_param('libraries',$parstack,$safeeval));
             }
+            if ($cas eq 'R') {
+                my $args = [&Apache::lonxml::get_param_var('args',$parstack,$safeeval)];
+                $award=&Apache::lonr::r_run($Apache::response::custom_answer[-1],$response,$args,
+                                            &Apache::lonxml::get_param('libraries',$parstack,$safeeval));
+            }
+
 	    if (!&Apache::inputtags::valid_award($award)) {
 		$error = $award;
 		$award = 'ERROR';
@@ -888,7 +912,7 @@ sub showallfoils {
 
 =pod
 
-=item &getresponse($offset,$resulttype);
+=item &getresponse();
 
 Retreives the current submitted response, helps out in the case of
 scantron mode.
@@ -934,13 +958,17 @@ sub getresponse {
 	my $id    = $Apache::inputtags::response[-1];
 	
 	my $line;
+	my $startline = $env{'form.scantron_questnum_start.'.$part.'.'.$id};
+        if (!$startline) {
+            $startline = $Apache::lonxml::counter;
+        }
 	for ($line = 0; $line < $lines; $line++) {
-	    my $theline = $Apache::lonxml::counter+$offset-1+$line;
+            my $theline = $startline+$offset-1+$line;
 	    $response = $env{"scantron.$theline.answer"};
 	    if ((defined($response)) && ($response ne "") && ($response ne " ")) {
 		last;
 	    }
-	    
+ 
 	}
 
 	# save bubbled letter for later
@@ -992,7 +1020,7 @@ sub repetition {
 
 =pod
 
-=item &scored_response($part_id,$response_id);
+=item &scored_response();
 
 Sets the results hash elements
 
@@ -1149,17 +1177,20 @@ sub pick_foil_for_concept {
 	$Apache::response::conceptgroup{'names'};
 
 }
-#------------------------------------------------------------
-#
-#  Get a parameter associated with a problem.
-# Parameters:
-#  $id        - the id of the paramater, either a part id, 
-#               or a partid and responspe id joined by _
-#  $name      - Name of the parameter to fetch
-#  $default   - Default value for the paramter.
-#
-#  
-#
+
+=pod
+
+=item get_response_param()
+
+Get a parameter associated with a problem.
+Parameters:
+	$id        - the id of the paramater, either a part id, 
+              or a partid and responspe id joined by _
+	$name      - Name of the parameter to fetch
+	$default   - Default value for the paramter.
+
+=cut
+
 sub get_response_param {
     my ($id,$name,$default)=@_;
     my $parameter;
@@ -1220,14 +1251,21 @@ sub add_to_gradingqueue {
     }
 }
 
-# basically undef and 0 (both false) mean that they still have work to do
-# and all true values mean that they can't do any more work
-#
-# a return of undef means it is unattempted
-# a return of 0 means it is attmpted and wrong but still has tries
-# a return of 1 means it is marked correct
-# a return of 2 means they have exceed maximum number of tries
-# a return of 3 means it after the answer date
+=pod 
+
+=item check_status()
+
+basically undef and 0 (both false) mean that they still have work to do
+and all true values mean that they can't do any more work
+
+	a return of undef means it is unattempted
+	a return of 0 means it is attmpted and wrong but still has tries
+	a return of 1 means it is marked correct
+	a return of 2 means they have exceed maximum number of tries
+	a return of 3 means it after the answer date
+
+=cut
+
 sub check_status {
     my ($id)=@_;
     if (!defined($id)) { $id=$Apache::inputtags::part; }
@@ -1252,7 +1290,7 @@ sub check_status {
 
 =pod
 
-=item setup_prior_tries_hash($func,$data)
+=item setup_prior_tries_hash()
 
   Foreach each past .submission $func is called with 3 arguments
      - the mode to set things up for (currently always 'grade')
@@ -1295,3 +1333,6 @@ sub setup_prior_tries_hash {
 1;
 __END__
  
+=pod
+
+=cut
