@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.434.2.1 2008/12/11 04:54:32 raeburn Exp $
+# $Id: structuretags.pm,v 1.444.4.6 2010/02/10 21:06:07 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -27,6 +27,29 @@
 #
 ###
 
+=pod
+
+=head1 NAME
+
+Apache::structuretags
+
+=head1 SYNOPSIS
+
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+
+=head1 NOTABLE SUBROUTINES
+
+=over
+
+=item 
+
+=back
+
+=cut
+
 
 package Apache::structuretags; 
 
@@ -220,10 +243,10 @@ sub page_start {
 
 	my ($symb,undef,undef,undef,$publicuser)= &Apache::lonnet::whichuser();
 	if ($symb eq '' && !$publicuser) {
-	    my $help = &Apache::loncommon::help_open_topic("Ambiguous_Reference");
-	    $help=&mt("Browsing resource, all submissions are temporary.")."<br />";
-	    $page_start .= $help;
-	}
+            $page_start .= '<p class="LC_info">'
+                          .&mt('Browsing resource, all submissions are temporary.')
+                          .'</p>';
+        }
     }
 
     if (!defined($found{'body'}) && $env{'request.state'} ne 'construct') {
@@ -233,7 +256,9 @@ sub page_start {
     my $form_tag_start;
     if (!defined($found{'form'})) {
 	$form_tag_start='<form name="lonhomework" enctype="multipart/form-data" method="post" action="';
-	my $uri = &Apache::lonenc::check_encrypt($env{'request.uri'});
+        my $uri = Apache::loncommon::inhibit_menu_check(
+                &Apache::lonenc::check_encrypt($env{'request.uri'}));
+        $uri = &HTML::Entities::encode($uri,'<>&"');
 	$form_tag_start.=$uri.'" ';
 	if ($target eq 'edit') {
 	    $form_tag_start.=&Apache::edit::form_change_detection();
@@ -395,14 +420,16 @@ sub problem_web_to_edit_header {
 	    '</div>';
     }
     
-    my $show_all_foils_text = 
-	($Apache::lonhomework::parsing_a_task) ?
-	&mt('&nbsp;Show&nbsp;All&nbsp;Instances')
-	: &mt('&nbsp;Show&nbsp;All&nbsp;Foils');
+    my $show_all_foils_text =
+        ($Apache::lonhomework::parsing_a_task) ?
+        &mt('Show All Instances')
+        : &mt('Show All Foils');
 
-    my $show_all= '<span class="LC_nobreak"><label><input type="checkbox" name="showallfoils" ';
-    if (defined($env{'form.showallfoils'})) { $show_all.='checked="checked"'; }
-    $show_all.= ' />'.$show_all_foils_text.'</label></span>';
+    my $show_all= '<span class="LC_nobreak"><label for="showallfoils">'
+                 .'<input type="checkbox" name="showallfoils"';
+    if (defined($env{'form.showallfoils'})) { $show_all.=' checked="checked"'; }
+    $show_all.= ' /> '.$show_all_foils_text
+               .'</label></span>';
 
 
 
@@ -551,12 +578,19 @@ sub initialize_storage {
     if ($temp =~ m/^error:.*/) { %Apache::lonhomework::history=(); }
 }
 
-# -------------------------------------------------------------finalize_storage
-# Stores away the result has to a student's environment
-# checks form.grade_ for specific values, other wises stores
-# to the running users environment
-# Will increment totals for attempts, students, and corrects
-# if running user has student role.  
+=pod
+
+=item finalize_storage()
+
+	Stores away the result has to a student's environment
+	checks form.grade_ for specific values, other wises stores
+	to the running users environment
+	Will increment totals for attempts, students, and corrects
+	if running user has student role.
+	
+=cut
+
+
 sub finalize_storage {
     my ($given_symb) = @_;
     my $result;
@@ -587,10 +621,16 @@ sub finalize_storage {
     return $result;
 }
 
-# -------------------------------------------------------------store_aggregates
-# Sends hash of values to be incremented in nohist_resourcetracker.db
-# for the course. Increments total number of attempts, unique students 
-# and corrects for each part for an instance of a problem, as appropriate.
+=pod
+
+item store_aggregates()
+
+	Sends hash of values to be incremented in nohist_resourcetracker.db
+	for the course. Increments total number of attempts, unique students 
+	and corrects for each part for an instance of a problem, as appropriate.
+	
+=cut
+
 sub store_aggregates {
     my ($symb,$courseid) = @_;
     my %aggregate;
@@ -638,10 +678,8 @@ sub checkout_msg {
     return (<<ENDCHECKOUT);
 <h2>$lt{'resource'}</h2>
     <p>$lt{'id_expln'}</p>
-<font color="red">
-<p>$lt{'warning'}</p>
-</font>
-<form name="checkout" method="POST" action="$uri">
+<p class="LC_warning">$lt{'warning'}</p>
+<form name="checkout" method="post" action="$uri">
 <input type="hidden" name="doescheckout" value="yes" />
 <input type="button" name="checkoutbutton" value="$lt{'checkout'}" onClick="javascript:if (confirm('$lt{'checkout?'}')) { document.checkout.submit(); }" />
 </form>
@@ -675,7 +713,7 @@ sub firstaccess_msg {
     my $buttontext = &mt('Show Resource');
     my $timertext = &mt('Start Timer?');
     $result .= (<<ENDCHECKOUT);
-<form name="markaccess" method="POST" action="$uri">
+<form name="markaccess" method="post" action="$uri">
 <input type="hidden" name="markaccess" value="yes" />
 <input type="button" name="accessbutton" value="$buttontext" onClick="javascript:if (confirm('$timertext')) { document.markaccess.submit(); }" />
 </form>
@@ -866,14 +904,16 @@ sub start_problem {
 		    '<input type="hidden" name="username"
                              value="'.$env{'form.username'}.'" />';
 	    }
-	    if ($env{'request.role.adv'}) {
-		$form_tag_start.=
-		    ' <label><input type="checkbox" name="showallfoils" ';
-		if (defined($env{'form.showallfoils'})) {
-		    $form_tag_start.='checked="on"';
-		}
-		$form_tag_start.= ' />'.&mt('&nbsp;Show&nbsp;All&nbsp;Foils').
-		    '</label>';
+            if ($env{'request.role.adv'}) {
+                $form_tag_start.= ' <label class="LC_nobreak">'
+                         .'<input type="checkbox" name="showallfoils"';
+                if (defined($env{'form.showallfoils'})) {
+                    $form_tag_start.=' checked="checked"';
+                }
+                $form_tag_start.= ' /> '
+                                 .&mt('Show All Foils')
+                                 .'</label>';
+
 	    }
             if ($Apache::lonhomework::type eq 'practice') {
                 $form_tag_start.=&practice_problem_header();
@@ -903,6 +943,8 @@ sub start_problem {
 		my $msg;
 		if ($status eq 'UNAVAILABLE') {
 		    $msg.='<h1>'.&mt('Unable to determine if this resource is open due to network problems. Please try again later.').'</h1>';
+                } elsif ($status eq 'NOT_IN_A_SLOT') {
+                    $msg.='<h1>'.&mt('You are not currently signed up to work at this time and/or place.').'</h1>';
 		} elsif ($status ne 'NOT_YET_VIEWED') {
 		    $msg.='<h1>'.&mt('Not open to be viewed').'</h1>';
 		}
@@ -913,13 +955,13 @@ sub start_problem {
 		} elsif ($status eq 'NOT_YET_VIEWED') {
 		    $msg.=&firstaccess_msg($accessmsg,$symb);
 		} elsif ($status eq 'NOT_IN_A_SLOT') {
-		    $msg.=&Apache::bridgetask::add_request_another_attempt_button("Sign up for time to work.");
+		    $msg.=&Apache::bridgetask::add_request_another_attempt_button("Sign up for time to work");
 		}
 		$result.=$msg.'<br />';
 	    } elsif ($target eq 'tex') {
 		my $startminipage = ($env{'form.problem_split'}=~/yes/i)? ''
 		                    : '\begin{minipage}{\textwidth}';
-		$result.='\begin{document}\noindent \vskip 1 mm '.
+		$result.='\noindent \vskip 1 mm '.
 		    $startminipage.'\vskip 0 mm';
 		if ($status eq 'UNAVAILABLE') {
 		    $result.=&mt('Unable to determine if this resource is open due to network problems. Please try again later.').'\vskip 0 mm ';
@@ -1020,7 +1062,7 @@ sub end_problem {
 	    $allow_print_points=0;
 	}
 	my $name_of_resourse= &Apache::lonxml::latex_special_symbols(&get_resource_name($parstack,$safeeval),'header');
-	my $begin_doc='\begin{document} \typeout{STAMPOFPASSEDRESOURCESTART Resource <h2>"'.$name_of_resourse.'"</h2> located in <br /><small><b>'.$env{'request.uri'}.'</b></small><br /> STAMPOFPASSEDRESOURCEEND} \noindent ';
+	my $begin_doc=' \typeout{STAMPOFPASSEDRESOURCESTART Resource <h2>"'.$name_of_resourse.'"</h2> located in <br /><small><b>'.$env{'request.uri'}.'</b></small><br /> STAMPOFPASSEDRESOURCEEND} \noindent ';
 	my $toc_line='\vskip 1 mm\noindent '.$startminipage.
 	    '\addcontentsline{toc}{subsection}{'.$name_of_resourse.'}';
 	
@@ -1028,8 +1070,10 @@ sub end_problem {
 	#  it in the problem header.  We have been logging the
 	#  last due date written to file. 
 	
-	my $duetime = &Apache::lonnet::EXT("resource.$id.duedate"); 
+	my $duetime = &Apache::lonnet::EXT("resource.$id.duedate");
 	my $duedate = POSIX::strftime("%c",localtime($duetime));
+        my $duedate_text = &mt('Due date: [_1]'
+                              ,&Apache::lonlocal::locallocaltime($duetime));
 	my $temp_file;
 	my $filename = "/home/httpd/prtspool/$env{'user.name'}_$env{'user.domain'}_printout.due";
 	
@@ -1061,18 +1105,22 @@ sub end_problem {
 	    if (not $env{'request.symb'} =~ m/\.page_/) {
 		if(not $duedate=~m/1969/ and $Apache::lonhomework::type ne 'exam') {
 		    $frontmatter .= $begin_doc.
-			'\textit{Due date: '.$duedate.'} '.$toc_line;
+			'\textit{'.$duedate_text.'} '.$toc_line;
 		} else {
 		    $frontmatter.= $begin_doc.$toc_line;
-		    if ($Apache::lonhomework::type eq 'exam' and $allow_print_points==1) { $frontmatter .= '\fbox{\textit{'.$weight.' pt}}';}
+                    if ($Apache::lonhomework::type eq 'exam' and $allow_print_points==1) {
+                        $frontmatter .= '\fbox{\textit{'.$weight.' pt}}';
+                    }
 		}
 	    } else {
-		$frontmatter .= '\vskip 1mm\textit{Due date: '.$duedate.'} \\\\\\\\'.$startminipage;
+		$frontmatter .= '\vskip 1mm\textit{'.$duedate_text.'} \\\\\\\\'.$startminipage;
 	    }
 	} else {
 	    if (not $env{'request.symb'} =~ m/\.page_/) {
 		$frontmatter .= $begin_doc.$toc_line;
-		if (($Apache::lonhomework::type eq 'exam') and ($allow_print_points==1)) { $frontmatter .= '\fbox{\textit{'.$weight.' pt}}';}
+                if (($Apache::lonhomework::type eq 'exam') and ($allow_print_points==1)) {
+                    $frontmatter .= '\fbox{\textit{'.$weight.' pt}}';
+                }
 	    } else {
 		$frontmatter .= '\vskip 1mm \\\\\\\\'.$startminipage;
 	    }
@@ -1563,6 +1611,20 @@ sub start_randomlist {
 	    my $showarg=&Apache::lonxml::get_param('show',$parstack,$safeeval);
 	    $showarg--;
 	    if ( ($showarg >= 0) && ($showarg < $show) ) { $show = $showarg; }
+            if (($target eq 'analyze') && ($env{'form.check_parts_withrandomlist'})) {
+                my @currlist;
+                my $part = $Apache::inputtags::part;
+                if ($part ne '') {
+                    if (ref($Apache::lonhomework::analyze{'parts_withrandomlist'}) eq 'ARRAY') {
+                        my @currlist = @{$Apache::lonhomework::analyze{'parts_withrandomlist'}};
+                        if (!(grep(/^\Q$part\E$/,@currlist))) {
+                            push(@{$Apache::lonhomework::analyze{'parts_withrandomlist'}},$part);
+                        }
+                    } else {
+                        push(@{$Apache::lonhomework::analyze{'parts_withrandomlist'}},$part);
+                    }
+                }
+            }
 	    for(0 .. $show) {
 		$bodytext .= "$randomlist[ $idx_arr[$_] ]";
 	    }
@@ -1700,7 +1762,9 @@ sub start_part {
 				    '.disableexampointprint'}) eq 'yes') {
 			$allow_print_points=0;
 		    }
-		    if (($Apache::lonhomework::type eq 'exam') && ($allow_print_points)) { $result .= '\fbox{\textit{'.$weight.' pt}}';}
+                    if (($Apache::lonhomework::type eq 'exam') && ($allow_print_points)) { 
+                        $result .= '\vskip 10mm\fbox{\textit{'.$weight.' pt}}';
+                    }
 		} elsif ($target eq 'web') {
 		    $result.='<a name="'.&escape($Apache::inputtags::part).'" />';
 		}
@@ -1906,9 +1970,8 @@ sub end_startouttext {
     if ($target eq 'edit') {
 	my $areaid = 'homework_edit_'.$Apache::lonxml::curdepth;
 	$text=&Apache::lonxml::get_all_text("endouttext",$parser,$style);
-
 	$result.=&Apache::edit::start_table($token)."<tr><td>".&mt('Text Block')."</td>"
-                 .'<td><span clas="LC_nobreak">'.&mt('Delete?').' '
+                 .'<td><span class="LC_nobreak">'.&mt('Delete?').' '
                  .&Apache::edit::deletelist($target,$token)
                  .'</span></td>';
         unless ($env{'environment.wysiwygeditor'} eq 'on') {
@@ -1983,9 +2046,15 @@ sub start_simpleeditbutton {
         my $url=$env{'request.noversionuri'};
         $url=~s/\?.*$//;
 	my ($symb) = &Apache::lonnet::whichuser();
-	$result='<table width="100%" bgcolor="#FFFFAA" border="2"><tr><td>'.
-                '<a href="'.$url.'/smpedit?symb='.&escape($symb).'">'.&mt('Edit').'</a> - '.&mt('Note: it can take up to 10 minutes for changes to take effect for all users.').
-&Apache::loncommon::help_open_topic('Caching').'</td></tr></table><br />';
+#       Warning make more sense and is more important on edit screen
+#       $result='<p class="LC_warning">'
+#              .&mt('Note: it can take up to 10 minutes for changes to take effect for all users.')
+#              .&Apache::loncommon::help_open_topic('Caching')
+#              .'</p>';
+        $result .= '<table width="100%" bgcolor="#FFFFAA" border="2"><tr><td>'.
+                   '<a href="'.$url.'/smpedit?symb='.&escape($symb).'">'.
+                   &mt('Edit').'</a></td></tr></table><br />';
+
     }
     return $result;
 }
@@ -2002,3 +2071,9 @@ sub practice_problem_header {
 
 1;
 __END__
+
+=pod
+
+=back
+
+=cut
