@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 # 
-# $Id: imsimport.pm,v 1.26 2008/12/24 07:57:39 raeburn Exp $
+# $Id: imsimport.pm,v 1.32 2009/08/17 03:52:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -90,7 +90,7 @@ function createWin() {
   newWindow = window.open("","CreateDir","HEIGHT=400,WIDTH=750,scrollbars=yes")
   newWindow.document.open()
   newWindow.document.write('$start_page')
-  newWindow.document.write("\\n<img border='0' src='/adm/lonInterFace/author.jpg' alt='[Author Header]'>\\n")
+  newWindow.document.write("\\n<img border='0' src='/adm/lonInterFace/author.jpg' alt='[Author Header]' />\\n")
   newWindow.document.write("<table border='0' cellspacing='0' cellpadding='0' width='600'>\\n")
   newWindow.document.write("<tr><td width='2'>&nbsp;</td><td width='3'>&nbsp;</td>\\n")
   newWindow.document.write("<td><h3>$lt{'loca'} <tt>$fullpath</tt></h3><h3>$lt{'newd'}</h3></td></tr>\\n")
@@ -296,10 +296,10 @@ sub display_one {
               &Apache::lonhtmlcommon::topic_bar(1,&mt('Specify the Course Management system used to create the package')).
         &mt('Choose the CMS used to create your IMS content package.').'&nbsp;&nbsp;
         <select name="source">
-         <option value="-1" selected="true">Please select</option>
+         <option value="-1" selected="selected">Please select</option>
          <option value="bb5">Blackboard 5</option>
          <option value="bb6">Blackboard 6</option>
-         <option value="angel">ANGEL</option>
+         <option value="angel5">ANGEL 5.5</option>
          <option value="webctce4">WebCT 4 Campus Edition</option>
          <option value="webctvista4">WebCT Vista 4</option>
         </select><br />'."\n".
@@ -380,7 +380,7 @@ sub display_two {
                             $count{$area} ++;
                         }
                     }
-                } elsif ($cms eq 'angel') {
+                } elsif ($cms eq 'angel5') {
                     foreach my $area (keys %{$$cmsmap{$cms}}) {
                         if ($area eq 'doc') {
                             if (grep/^$resources{$res}{type}$/,@{$$cmsmap{$cms}{doc}}) {
@@ -459,8 +459,8 @@ sub display_two {
           <input type="hidden" name="conditions" value="'.$conditions.'" />
           <input type="hidden" name="source" value="'.$cms.'" />
           <input type="hidden" name="tempdir" value="'.$tempdir.'" />
-          <input type="hidden" name="uploaduname" value="'.$uname.'">
-          <input type="hidden" name="filename" value="'.$fname.'">
+          <input type="hidden" name="uploaduname" value="'.$uname.'" />
+          <input type="hidden" name="filename" value="'.$fname.'" />
           <input type="hidden" name="phase" value="four" />'."\n");
             if ($count{board} == 0) {
                 $r->print('<input type="hidden" name="board" value="" />'."\n");
@@ -526,7 +526,7 @@ sub display_three {
 
     foreach my $area (@{$areas}) {
         if (defined($env{"form.$area"}) ) {
-            if ($cms eq 'angel' && $area eq 'doc') {
+            if ($cms eq 'angel5' && $area eq 'doc') {
                 foreach (@{$$cmsmap{$cms}{$area}}) {
                     $importareas{$_} = 1;
                 }
@@ -599,7 +599,7 @@ sub display_three {
 
         $r->print("<h3>IMS import completed</h3>");
 
-        if ($cms eq 'angel') {
+        if ($cms eq 'angel5') {
             $r->print($lt{'yims'}.' '.&mt('A total of [quant,_1,sequence], [quant,_2,composite page], and [quant,_3,bulletin board] have been created, and [quant,_4,file] copied.',$total{seq},$total{page},$total{board},$total{file})."\n");
         } else {
             $r->print($lt{'yims'}.' '.&mt('A total of [quant,_1,sequence], [quant,_2,composite page], [quant,_3,bulletin board], [quant,_4,quiz,quizzes], [quant,_5,survey], and [quant,_6,problem] have been created, and [quant,_7,file] copied.',$total{seq},$total{page},$total{board},$total{quiz},$total{surv},$total{prob},$total{file})."\n");
@@ -762,8 +762,10 @@ sub handler {
     $r->print(&Apache::loncommon::start_page($title, $javascript));
 
     if (($uname ne $env{'user.name'}) || ($udom ne $env{'user.domain'})) {
-        $r->print('<h3><font color=red>'.&mt('Co-Author').': '.$uname.
-                  &mt(' at ').$udom.'</font></h3>');
+        $r->print('<p><span class="LC_warning">'
+                  .&mt('Co-Author [_1]',$uname.':'.$udom)
+                  .'</span></p>'
+        );
     }   
     if ($env{'form.phase'} eq 'two') {
         my $flag = &Apache::lonupload::phasetwo($r,$fn,$uname,$udom,'imsimport');
