@@ -3,7 +3,7 @@
 # institutional log-in ID (institutional authentication required - localauth
 #  or kerberos) or an e-mail address.
 #
-# $Id: createaccount.pm,v 1.32 2009/03/14 02:04:22 raeburn Exp $
+# $Id: createaccount.pm,v 1.37 2009/10/23 16:14:43 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -92,7 +92,7 @@ sub handler {
         my $end_page =
             &Apache::loncommon::end_page();
         $r->print($start_page."\n".'<h2>'.&mt('You are already logged in').'</h2>'.
-                  '<p>'.&mt('Please either [_1]continue the current session[_2] or [_3]logout[_4].','<a href="/adm/roles">','</a>','<a href="/adm/logout">','</a>').
+                  '<p>'.&mt('Please either [_1]continue the current session[_2] or [_3]log out[_4].','<a href="/adm/roles">','</a>','<a href="/adm/logout">','</a>').
                   '</p><p><a href="/adm/loginproblems.html">'.&mt('Login problems?').'</a></p>'.$end_page);
         return OK;
     }
@@ -112,10 +112,16 @@ sub handler {
         if ($env{'form.udom'} ne '') {
             $domain = $env{'form.udom'};
         }
+
+        my %domconfig = 
+            &Apache::lonnet::get_dom('configuration',['usercreation'],$domain);
+        my ($cancreate,$statustocreate) = 
+            &get_creation_controls($domain,$domconfig{'usercreation'});
+
         my ($result,$output) =
             &username_validation($r,$env{'form.uname'},$domain,$domdesc,
                                  $contact_name,$contact_email,$courseid,
-                                 $lonhost);
+                                 $lonhost,$statustocreate);
         if ($result eq 'existingaccount') {
             $r->print($output);
             &print_footer($r);
@@ -133,20 +139,11 @@ sub handler {
     $start_page =
         &Apache::loncommon::start_page($title,$js,
                                        {'no_inline_link'   => 1,});
-    my @cancreate;
-    my %domconfig = &Apache::lonnet::get_dom('configuration',['usercreation'],$domain);
-    if (ref($domconfig{'usercreation'}) eq 'HASH') {
-        if (ref($domconfig{'usercreation'}{'cancreate'}) eq 'HASH') {
-            if (ref($domconfig{'usercreation'}{'cancreate'}{'selfcreate'}) eq 'ARRAY') {
-                @cancreate = @{$domconfig{'usercreation'}{'cancreate'}{'selfcreate'}};
-            } elsif (($domconfig{'usercreation'}{'cancreate'}{'selfcreate'} ne 'none') &&
-                     ($domconfig{'usercreation'}{'cancreate'}{'selfcreate'} ne '')) {
-                @cancreate = ($domconfig{'usercreation'}{'cancreate'}{'selfcreate'});
-            }
-        }
-    }
 
-    if (@cancreate == 0) {
+    my %domconfig = 
+        &Apache::lonnet::get_dom('configuration',['usercreation'],$domain);
+    my ($cancreate,$statustocreate) = &get_creation_controls($domain,$domconfig{'usercreation'});
+    if (@{$cancreate} == 0) {
         &print_header($r,$start_page,$courseid);
         my $output = '<h3>'.&mt('Account creation unavailable').'</h3>'.
                      '<span class="LC_warning">'.
@@ -160,12 +157,13 @@ sub handler {
         &print_header($r,$start_page,$courseid);
         my ($msg,$sso_logout);
         $sso_logout = &sso_logout_frag($r,$domain);
-        if (grep(/^sso$/,@cancreate)) {
+        if (grep(/^sso$/,@{$cancreate})) {
             $msg = '<h3>'.&mt('Account creation').'</h3>'.
                    &mt("Although your username and password were authenticated by your institution's Single Sign On system, you do not currently have a LON-CAPA account at this institution.").'<br />';
 
             $msg .= &username_check($sso_username,$domain,$domdesc,$courseid, 
-                                    $lonhost,$contact_email,$contact_name,$sso_logout);
+                                    $lonhost,$contact_email,$contact_name,
+                                    $sso_logout,$statustocreate);
         } else {
             $msg = '<h3>'.&mt('Account creation unavailable').'</h3>'.
                    '<span class="LC_warning">'.&mt("Although your username and password were authenticated by your institution's Single Sign On system, you do not currently have a LON-CAPA account at this institution, and you are not permitted to create one.").'</span><br /><br />'.&mt('Please contact the [_1] ([_2]) for assistance.',$contact_name,$contact_email).'<hr />'.
@@ -215,7 +213,7 @@ sub handler {
         (my $result,$output) = 
             &username_validation($r,$env{'form.uname'},$domain,$domdesc,
                                  $contact_name,$contact_email,$courseid,
-                                 $lonhost);
+                                 $lonhost,$statustocreate);
         if ($result eq 'existingaccount') {
             $r->print($output);
             &print_footer($r);
@@ -226,21 +224,21 @@ sub handler {
     } elsif ($env{'form.create_with_email'}) {
         &print_header($r,$start_page,$courseid);
         $output = &process_email_request($env{'form.useremail'},$domain,$domdesc,
-                                         $contact_name,$contact_email,\@cancreate,
+                                         $contact_name,$contact_email,$cancreate,
                                          $lonhost,$domconfig{'usercreation'},
                                          $courseid);
     } elsif (!$token) {
         &print_header($r,$start_page,$courseid);
         my $now=time;
-        if (grep(/^login$/,@cancreate)) {
+        if (grep(/^login$/,@{$cancreate})) {
             my $jsh=Apache::File->new($include."/londes.js");
             $r->print(<$jsh>);
             $r->print(&javascript_setforms($now));
         }
-        if (grep(/^email$/,@cancreate)) {
+        if (grep(/^email$/,@{$cancreate})) {
             $r->print(&javascript_validmail());
         }
-        $output = &print_username_form($domain,$domdesc,\@cancreate,$now,$lonhost,
+        $output = &print_username_form($domain,$domdesc,$cancreate,$now,$lonhost,
                                        $courseid);
     }
     $r->print($output);
@@ -280,7 +278,7 @@ sub selfenroll_crumbs {
     my ($r,$courseid,$desc) = @_;
     &Apache::lonhtmlcommon::add_breadcrumb
          ({href=>"javascript:ToCatalog('backupcrumbs','')",
-           text=>"Course Catalog"});
+           text=>"Course/Community Catalog"});
     if ($env{'form.coursenum'} ne '') {
         &Apache::lonhtmlcommon::add_breadcrumb
           ({href=>"javascript:ToCatalog('backupcrumbs','details')",
@@ -499,8 +497,8 @@ sub login_box {
     }
     $output .= &Apache::lonhtmlcommon::row_closure(1)."\n".
                &Apache::lonhtmlcommon::end_pick_box().'<br />'."\n";
-    $output .= '<input type="hidden" name="lextkey" value="'.$lextkey.'">'."\n".
-               '<input type="hidden" name="uextkey" value="'.$uextkey.'">'."\n".
+    $output .= '<input type="hidden" name="lextkey" value="'.$lextkey.'" />'."\n".
+               '<input type="hidden" name="uextkey" value="'.$uextkey.'" />'."\n".
                '</form>';
     return $output;
 }
@@ -792,6 +790,32 @@ ENDSERVERFORM
     return $output;
 }
 
+sub get_creation_controls {
+    my ($domain,$usercreation) = @_;
+    my (@cancreate,@statustocreate);
+    if (ref($usercreation) eq 'HASH') {
+        if (ref($usercreation->{'cancreate'}) eq 'HASH') {
+            if (ref($usercreation->{'cancreate'}{'statustocreate'}) eq 'ARRAY') {
+                @statustocreate = @{$usercreation->{'cancreate'}{'statustocreate'}};
+            } else {
+                @statustocreate = ('default');
+                my ($othertitle,$usertypes,$types) =
+                    &Apache::loncommon::sorted_inst_types($domain);
+                if (ref($types) eq 'ARRAY') {
+                    push(@statustocreate,@{$types});
+                }
+            }
+            if (ref($usercreation->{'cancreate'}{'selfcreate'}) eq 'ARRAY') {
+                @cancreate = @{$usercreation->{'cancreate'}{'selfcreate'}};
+            } elsif (($usercreation->{'cancreate'}{'selfcreate'} ne 'none') &&
+                     ($usercreation->{'cancreate'}{'selfcreate'} ne '')) {
+                @cancreate = ($usercreation->{'cancreate'}{'selfcreate'});
+            }
+        }
+    }
+    return (\@cancreate,\@statustocreate);
+}
+
 sub create_account {
     my ($r,$domain,$lonhost,$username,$domdesc) = @_;
     my ($retrieved,$output,$upass) = &process_credentials($env{'form.logtoken'},
@@ -829,7 +853,7 @@ sub create_account {
 
 sub username_validation {
     my ($r,$username,$domain,$domdesc,$contact_name,$contact_email,$courseid,
-        $lonhost) = @_;
+        $lonhost,$statustocreate) = @_;
     my ($retrieved,$output,$upass);
 
     $username= &LONCAPA::clean_username($username);
@@ -863,7 +887,8 @@ sub username_validation {
         }
         if ($authok eq 'authorized') {
             $output = &username_check($username,$domain,$domdesc,$courseid,$lonhost,
-                                      $contact_email,$contact_name);
+                                      $contact_email,$contact_name,undef,
+                                      $statustocreate);
         } else {
             $output = &login_failure_msg($courseid);
         }
@@ -888,8 +913,8 @@ sub login_failure_msg {
 }
 
 sub username_check {
-    my ($username,$domain,$domdesc,$courseid,$lonhost,$contact_email,$contact_name,
-        $sso_logout) = @_;
+    my ($username,$domain,$domdesc,$courseid,$lonhost,$contact_email,
+        $contact_name,$sso_logout,$statustocreate) = @_;
     my (%rulematch,%inst_results,$checkfail,$rowcount,$editable,$output,$msg,
         %alerts,%curr_rules,%got_rules);
     &call_rulecheck($username,$domain,\%alerts,\%rulematch,
@@ -908,6 +933,21 @@ sub username_check {
             }
         }
     }
+    if (!$checkfail) {
+        if (ref($statustocreate) eq 'ARRAY') {
+            $checkfail = 'inststatus';
+            if (ref($inst_results{$username.':'.$domain}{inststatus}) eq 'ARRAY') {
+                foreach my $inststatus (@{$inst_results{$username.':'.$domain}{inststatus}}) {
+                    if (grep(/^\Q$inststatus\E$/,@{$statustocreate})) {
+                        undef($checkfail);
+                        last;
+                    }
+                }
+            } elsif (grep(/^default$/,@{$statustocreate})) {
+                undef($checkfail);
+            }
+        }
+    }
     if (!$checkfail) {
         $output = '<form method="post" action="/adm/createaccount">';
         (my $datatable,$rowcount,$editable) = 
@@ -943,6 +983,10 @@ sub username_check {
         } elsif ($checkfail eq 'authtoken') {
             $msg .= '<span class="LC_error">'.&mt('Error creating token.').'</span>'.
                     '<br />'.$output;
+        } elsif ($checkfail eq 'inststatus') {
+            $msg .= '<span class="LC_warning">'.
+                     &mt('You are not permitted to create a LON-CAPA account.').
+                     '</span><br /><br />'.$output;
         }
         $msg .= &mt('Please contact the [_1] ([_2]) for assistance.',
                 $contact_name,$contact_email).'<br /><hr />'.
@@ -1142,7 +1186,7 @@ sub create_captcha {
             $output = '<input type="hidden" name="crypt" value="'.$md5sum.'" />'."\n".
                       &mt('Type in the letters/numbers shown below').'&nbsp;'.
                      '<input type="text" size="5" name="code" value="" /><br />'.
-                     '<img src="'.$captcha_params{'www_output_dir'}.'/'.$md5sum.'.png">';
+                     '<img src="'.$captcha_params{'www_output_dir'}.'/'.$md5sum.'.png" />';
             last;
         }
     }
