@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Directory Indexer
 #
-# $Id: lonindexer.pm,v 1.181.2.2 2008/12/17 18:49:13 raeburn Exp $
+# $Id: lonindexer.pm,v 1.181.4.6 2010/04/14 16:11:34 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -183,7 +183,7 @@ ENDSUBM
 	    $colspan=" colspan='2' ";
             my $cl=&mt('Close');
             $closebutton=<<END;
-<input type="button" name="close" value='$cl' onClick="self.close()" />
+<input type="button" name="close" value='$cl' onclick="self.close()" />
 END
         }
 	elsif ($env{'form.catalogmode'} eq 'import') {
@@ -194,11 +194,11 @@ END
 	    my $cl=&mt('Close');
             my $gi=&mt('Import');
             $closebutton=<<END;
-<input type="button" name="close" value='$cl' onClick="self.close()" />
+<input type="button" name="close" value='$cl' onclick="self.close()" />
 END
             $groupimportbutton=<<END;
 <input type="button" name="groupimport" value='$gi'
-onClick="javascript:select_group()" />
+onclick="javascript:select_group()" />
 END
         }
 	# Additions made by Matthew to make the browser a little easier to deal
@@ -319,10 +319,8 @@ function select_group() {
 
 function changeURL(val) {
     if (window.opener.document) {
-        var elementname  = "$element"+"_value";
-        var checkboxname = "$element"+"_setparmval";
+        var elementname  = "$element";
 	window.opener.document.forms["$form"].elements[elementname].value=val;
-        window.opener.document.forms["$form"].elements[checkboxname].checked=true;
     } else {
 	    alert("The file you selected is: "+val);
     }
@@ -407,8 +405,14 @@ function gothere(val) {
 ENDHEADER
 
         my ($headerdom)=($uri=~m{^/res/($match_domain)/});
-	$r->print(&Apache::loncommon::start_page('Browse Resources',$js,
-						 {'domain' => $headerdom,}));
+        my %args = (
+                      'domain' => $headerdom,
+                   );
+        if ($env{'form.catalogmode'}) {
+            # "Popup mode"
+            $args{'only_body'} = 1;
+        }
+	$r->print(&Apache::loncommon::start_page('Browse Resources',$js,\%args));
 # ---------------------------------- get state of file types to be showing
 	if ($env{'form.only'}) {
 	    $typeselect = $env{'form.only'};
@@ -418,84 +422,104 @@ ENDHEADER
 
 # ---------------------------------- get state of file attributes to be showing
 	if ($env{'form.attrs'}) {
-	    for (my $i=0; $i<=11; $i++) {
+	    for (my $i=0; $i<=16; $i++) {
 		delete $hash{'display_attrs_'.$i};
 		if ($env{'form.attr'.$i} == 1) {
-		    $attrchk[$i] = 'checked';
+		    $attrchk[$i] = 'checked="checked"';
 		    $hash{'display_attrs_'.$i} = 1;
 		}
 	    }
 	} else {
-	    for (my $i=0; $i<=11; $i++) {
-		$attrchk[$i] = 'checked' if $hash{'display_attrs_'.$i} == 1;
+	    for (my $i=0; $i<=16; $i++) {
+		$attrchk[$i] = 'checked="checked"' if $hash{'display_attrs_'.$i} == 1;
 	    }
 	}
 
-# ------------------------------- output state of file attributes to be showing
-#                                 All versions has to the last item
-#                                 since it does not take an extra col
-	my %lt=&Apache::lonlocal::texthash(
-					   'ti' => 'Title',
-					   'si' => 'Size',
-					   'la' => 'Last access',
-					   'lm' => 'Last modified',
-					   'st' => 'Statistics',
-					   'au' => 'Author',
-					   'kw' => 'Keywords',
-					   'ln' => 'Language',
-					   'sa' => 'Source Available',
-					   'sr' => 'Show resource',
-					   'li' => 'Linked/Related Resources',
-					   'av' => 'All versions',
-					   'ud' => 'Update Display',
-					   'pr' => 'Problems',
-					   'gr' => 'Graphics',
-					   'at' => 'All types'
-					   );
-	$r->print(<<END);
-<form method="post" name="fileattr" action="$uri"
- enctype="application/x-www-form-urlencoded">
-<label><input type="checkbox" name="attr9" value="1" $attrchk[9] onClick="this.form.submit();" /> $lt{'av'}</label>
-<table border="0">
-<tr>
-<td><label><input type="checkbox" name="attr0" value="1" $attrchk[0] onClick="this.form.submit();" /> $lt{'ti'}</label></td>
-<td><label><input type="checkbox" name="attr4" value="1" $attrchk[4] onClick="this.form.submit();" /> $lt{'au'}</label></td>
-<td><label><input type="checkbox" name="attr5" value="1" $attrchk[5] onClick="this.form.submit();" /> $lt{'kw'}</label></td>
-<td><label><input type="checkbox" name="attr6" value="1" $attrchk[6] onClick="this.form.submit();" /> $lt{'ln'}</label></td>
-</tr>
-<tr>
-<td><label><input type="checkbox" name="attr1" value="1" $attrchk[1] onClick="this.form.submit();" /> $lt{'si'}</label></td>
-<td><label><input type="checkbox" name="attr2" value="1" $attrchk[2] onClick="this.form.submit();" /> $lt{'la'}</label></td>
-<td><label><input type="checkbox" name="attr3" value="1" $attrchk[3] onClick="this.form.submit();" /> $lt{'lm'}</label></td>
-<td><label><input type="checkbox" name="attr10" value="1" $attrchk[10] onClick="this.form.submit();" /> $lt{'sa'}</label></td>
-</tr>
-<tr>
-<td><label><input type="checkbox" name="attr8" value="1" $attrchk[8] onClick="this.form.submit();" /> $lt{'st'}</label></td>
-<td><label><input type="checkbox" name="attr11" value="1" $attrchk[11] onClick="this.form.submit();" /> $lt{'li'}</label></td>
-<td><label><input type="checkbox" name="attr7" value="1" $attrchk[7] onClick="this.form.submit();" /> $lt{'sr'}</label></td>
-<td>&nbsp;</td>
-</tr>
-</table>
-<input type="hidden" name="attrs" value="1" />
-END
         my @file_categories = &Apache::loncommon::filecategories();
         my %select_file_categories;
         my @select_form_order = ('');
         $select_file_categories{''} = &mt('All file types');
         foreach my $cat (@file_categories) {
-	    my $types = join(",",&Apache::loncommon::filecategorytypes($cat));
-	    $select_file_categories{$types} = $cat;
-	    push(@select_form_order,$types);
-	}
+            my $types = join(",",&Apache::loncommon::filecategorytypes($cat));
+            $select_file_categories{$types} = &mt($cat);
+            push(@select_form_order,$types);
+        }
         $select_file_categories{'select_form_order'} = \@select_form_order;
         my $type_element=
-	    &Apache::loncommon::select_form($typeselect,'only',
-					    %select_file_categories);
-        $type_element = '<label>'.&mt('File Type Displayed: [_1]',
-				      $type_element).'</label>';
+            &Apache::loncommon::select_form(
+                $typeselect,
+                'only',
+                %select_file_categories);
+        my $type_selector = '<label>'.&mt('File Type Displayed: [_1]',
+                                          $type_element).'</label>';
+
+# ------------------------------- output state of file attributes to be showing
+#                                 All versions has to the last item
+#                                 since it does not take an extra col
+
+        my %lt=&Apache::lonlocal::texthash(
+                                           'av' => 'All versions',
+                                           'ud' => 'Update Display',
+                                           'pr' => 'Problems',
+                                           'gr' => 'Graphics',
+                                           'at' => 'All types',
+                                           'hd' => 'Display Options'
+                                           );
+        my @disp_order = ('0','4','5','6','13','1','2','3','10','14','8','11','7','12','15','16');
+        my %disp_options = &Apache::lonlocal::texthash (
+                              0  => 'Title',
+                              4  => 'Author',
+                              5  => 'Keywords',
+                              6  => 'Language',
+                              13 => 'Notes',
+                              1  => 'Size',
+                              2  => 'Last access',
+                              3  => 'Last modified',
+                              10 => 'Source Available',
+                              14 => 'Abstract',
+                              8  => 'Statistics',
+                              11 => 'Linked/Related Resources',
+                              7  => 'Show resource',
+                              12 => 'Subject',
+                              15 => 'Grade Level',
+                              16 => 'Standards',
+                           );
+        my $cell = 0;
+        my $numinrow = 4;
+        $r->print('
+<form method="post" name="fileattr" action="'.$uri.'" enctype="application/x-www-form-urlencoded">
+<fieldset>
+<legend><b>'.$lt{'hd'}.'</b></legend>
+<table style=" border-collapse: collapse; border-style: none;">'."\n");
+        foreach my $item (@disp_order) {
+            my $style = 'padding-left: 12px; padding-right: 8px;';
+            if ($cell%$numinrow == 0) {
+                $r->print('<tr>');
+            }
+            $cell ++;
+            if ($cell > 3 * $numinrow) {
+                $style .= ' padding-bottom: 6px;';
+            }
+            if (defined($disp_options{$item})) {
+                $r->print('<td style="'.$style.'"><span class="LC_nobreak">'.
+                          '<label><input type="checkbox" name="attr'.$item.'" value="1" '.
+                          $attrchk[$item].' onclick="this.form.submit();" /> '.$disp_options{$item}.
+                          '</label></span></td>'."\n");
+            }
+            if ($cell > 1 && $cell%$numinrow == 0) {
+                $r->print('</tr>');
+            }
+        }
         $r->print(<<END);
-$type_element
-<br />
+<tr>
+<td style="font-style: italic; border-top: 1px solid black; padding-top: 6px">
+<label><input type="checkbox" name="attr9" value="1" $attrchk[9] onclick="this.form.submit();" /> $lt{'av'}</label>
+</td>
+<td colspan="3" style="padding-left:8px; padding-top: 4px; font-style: italic; border-top: 1px solid black; padding-top: 8px">$type_selector</td>
+</tr>
+</table>
+<input type="hidden" name="attrs" value="1" />
+</fieldset>
 <input type="submit" name="updatedisplay" value="$lt{'ud'}" />
 <input type="hidden" name="acts" value="" />
 $closebutton $groupimportbutton
@@ -529,8 +553,8 @@ END
 	&Apache::lonhtmlcommon::store_recent('residx',$storeuri,$storeuri);
 # -------------------------------------------------- Check All and Uncheck all
 	if ($env{'form.catalogmode'} eq 'import') {
-	    $r->print('<br /><input type="button" value="'.&mt("Check All").'" id="checkallbutton" onClick="javascript:checkAll()" />');
-	    $r->print('<input type="button" value="'.&mt("Uncheck All").'" id="uncheckallbutton" onClick="javascript:uncheckAll()" />');
+	    $r->print('<br /><input type="button" value="'.&mt("Check All").'" id="checkallbutton" onclick="javascript:checkAll()" />');
+	    $r->print('<input type="button" value="'.&mt("Uncheck All").'" id="uncheckallbutton" onclick="javascript:uncheckAll()" />');
 	}
 # ----------------- output starting row to the indexed file/directory hierarchy
         my $titleclr="#ddffff";
@@ -542,8 +566,8 @@ END
 	$r->print("<td $colspan><b>".&mt('Name')."</b></td>\n");
 	$r->print("<td><b>".&mt('Title')."</b></td>\n") 
 	    if ($hash{'display_attrs_0'} == 1);
-	$r->print('<td align="right"><b>'.&mt('Size').' ('.&mt('bytes').') '.
-		  '</b></td>'."\n") if ($hash{'display_attrs_1'} == 1);
+	$r->print("<td align=right><b>".&mt("Size")." (".&mt("bytes").") ".
+		  "</b></td>\n") if ($hash{'display_attrs_1'} == 1);
 	$r->print("<td><b>".&mt("Last accessed")."</b></td>\n") 
 	    if ($hash{'display_attrs_2'} == 1);
 	$r->print("<td><b>".&mt("Last modified")."</b></td>\n")
@@ -563,6 +587,16 @@ END
 	    if ($hash{'display_attrs_11'} == 1);
 	$r->print("<td><b>".&mt("Resource")."</b></td>\n")
 	    if ($hash{'display_attrs_7'} == 1);
+        $r->print("<td><b>".&mt("Subject")."</b></td>\n")
+            if ($hash{'display_attrs_12'} == 1);
+        $r->print("<td><b>".&mt("Notes")."</b></td>\n")
+            if ($hash{'display_attrs_13'} == 1);
+        $r->print("<td><b>".&mt("Abstract")."</b></td>\n")
+            if ($hash{'display_attrs_14'} == 1);
+        $r->print("<td><b>".&mt("Grade Level")."</b></td>\n")
+            if ($hash{'display_attrs_15'} == 1);
+        $r->print("<td><b>".&mt("Standards")."</b></td>\n")
+            if ($hash{'display_attrs_16'} == 1);
 	$r->print('</tr>');
 
 # ----------------- read in what directories have previously been set to "open"
@@ -830,7 +864,7 @@ sub display_line {
 
     my $tabtag='</td>';
     my $i=0;
-    while ($i<=11) {
+    while ($i<=16) {
 	$tabtag=join('',$tabtag,"<td>&nbsp;</td>")
 	    if ($i != 9 &&
 		$hash{'display_attrs_'.$i} == 1);
@@ -849,23 +883,23 @@ sub display_line {
 	$r->print("<td>\n");
 	$r->print ('<form method="post" name="dirpathUP" action="'.$updir.
 		   '/" '.
-		   'onSubmit="return rep_dirpath(\'UP\','.
+		   'onsubmit="return rep_dirpath(\'UP\','.
 		   'document.forms.fileattr.acts.value)" '.
 		   'enctype="application/x-www-form-urlencoded"'.
                    '>'."\n");
 	$r->print(&Apache::loncommon::inhibit_menu_check('input'));
-	$r->print ('<input type=hidden name=openuri value="'.
+	$r->print ('<input type="hidden" name="openuri" value="'.
 		   $startdir.'" />'."\n");
 	$r->print ('<input type="hidden" name="acts" value="" />'."\n");
 	$r->print ('<input src="'.$iconpath.'arrow_up.gif"');
-	$r->print (' name="'.$msg.'" type="image" class="LC_indexer_icon" />'.
+	$r->print (' name="'.$msg.'" alt="'.$msg.'" type="image" class="LC_indexer_icon" />'.
 		   "\n");
 	$r->print(&mt("Up")."</form>$tabtag</tr>\n");
 	return OK;
     }
 # Do we have permission to look at this?
 
-    if($filecom[15] ne '1') { return OK if (!&Apache::lonnet::allowed('bre',$pathprefix.$filecom[0])); }
+    if($filecom[15] ne '1') { return OK if ((!&Apache::lonnet::allowed('bre',$pathprefix.$filecom[0])) && (!&Apache::lonnet::allowed('bro',$pathprefix.$filecom[0]))); }
 
 # make absolute links appear on different background
     if ($absolute) { $fileclr='#ccdd99'; }
@@ -883,7 +917,7 @@ sub display_line {
 	$r->print ('<input type="hidden" name="acts" value="" />');
 	$r->print ('<input src="'.$iconpath.'folder_pointer_'.
 		   $diropen.'.gif"'); 
-	$r->print (' name="'.$msg.'" type="image" class="LC_indexer_icon" />'.
+	$r->print (' name="'.$msg.'" alt="'.$msg.'" type="image" class="LC_indexer_icon" />'.
 		   "\n");
 	my $quotable_filecom = &Apache::loncommon::escape_single($filecom[0]);
 	$r->print ('<a href="javascript:gothere(\''.$quotable_filecom.
@@ -911,7 +945,7 @@ sub display_line {
 	$r->print ('<input type="hidden" name="acts" value="" />');
 	$r->print ('<input src="'.$iconpath.'folder_pointer_'.$diropen.
 		   '.gif"'); 
-	$r->print (' name="'.$msg.'" type="image" class="LC_indexer_icon" />'.
+	$r->print (' name="'.$msg.'" alt="'.$msg.'" type="image" class="LC_indexer_icon" />'.
 		   "\n");
 	my $quotable_curdir = &Apache::loncommon::escape_single($curdir);
 	$r->print ('<a href="javascript:gothere(\''.$quotable_curdir
@@ -957,7 +991,7 @@ sub display_line {
 	} elsif ($env{'form.catalogmode'} eq 'import') {
 	    $r->print("<form name='form$fnum' action=''>\n");
 	    $r->print("<input type='checkbox' name='filelink"."' ".
-		      "value='$filelink' onClick='".
+		      "value='$filelink' onclick='".
 		      "javascript:queue(\"form$fnum\")' ");
 	    if ($hash{'store_'.$filelink}) {
 		$r->print("checked");
@@ -978,7 +1012,7 @@ sub display_line {
 	    $indent--;
 	}
 # General indentation
-	if ($indent > 0 and $indent < 11) {
+	if ($indent > 0 and $indent < 16) {
 	    $r->print("<img alt=\"\" src='",$iconpath,"whitespace",$indent,
 		      ".gif' class='LC_icon' />\n");
 	} elsif ($indent >0) {
@@ -1001,7 +1035,7 @@ sub display_line {
 	    $r->print ('<input type="hidden" name="acts" value="" />');
 	    $r->print ('<a name="'.$anchor.'"></a><input src="'.$iconpath.
 		       'folder_pointer_'.$diropen.'.gif"');
-	    $r->print (' name="'.$msg.'" type="image" class="LC_indexer_icon" />'.
+	    $r->print (' name="'.$msg.'" alt="'.$msg.'" type="image" class="LC_indexer_icon" />'.
 		       "\n");
 	}
 # Filetype icons
@@ -1058,17 +1092,11 @@ sub display_line {
 # statistics
 	    &dynmetaread($filelink);
 	    $r->print("<td>");
-	    &dynmetaprint($r,$filelink,'count');
-	    &dynmetaprint($r,$filelink,'course');
-	    &dynmetaprint($r,$filelink,'stdno');
-	    &dynmetaprint($r,$filelink,'avetries');
-	    &dynmetaprint($r,$filelink,'difficulty');
-	    &dynmetaprint($r,$filelink,'disc');
-	    &dynmetaprint($r,$filelink,'clear');
-	    &dynmetaprint($r,$filelink,'technical');
-	    &dynmetaprint($r,$filelink,'correct');
-	    &dynmetaprint($r,$filelink,'helpful');
-	    &dynmetaprint($r,$filelink,'depth');
+            for (qw(count course stdno avetries difficulty disc clear technical
+                correct helpful depth)) {
+
+                &dynmetaprint($r,$filelink,$_);
+            }
 	    $r->print("&nbsp;</td>\n");
 
 	}
@@ -1091,12 +1119,10 @@ sub display_line {
 	   &dynmetaread($filelink);
 	   $r->print('<td>');
 	   &coursecontext($r,$filelink);
-	   &dynmetaprint($r,$filelink,'goto_list');
-	   &dynmetaprint($r,$filelink,'comefrom_list');
-	   &dynmetaprint($r,$filelink,'sequsage_list');
-	   &dynmetaprint($r,$filelink,'dependencies');
-           &dynmetaprint($r,$filelink,'course_list');
-	   $r->print('</td>');
+           for (qw(goto_list comefrom_list sequsage_list dependencies course_list)) {
+               &dynmetaprint($r,$filelink,$_);
+           }
+           $r->print('</td>');
         }
         if ($hash{'display_attrs_7'} == 1) {
 # Show resource
@@ -1104,6 +1130,36 @@ sub display_line {
            $r->print('<td> '.($output eq '' ? '&nbsp;':$output).
 		      " </td>\n");
         }
+        if ($hash{'display_attrs_12'} == 1) {
+            my $subject = &Apache::lonnet::metadata($filelink,'subject');
+            $r->print('<td> '.($subject eq '' ? '&nbsp;' : $subject).
+                      " </td>\n");
+        }
+
+        if ($hash{'display_attrs_13'} == 1) {
+            my $notes = &Apache::lonnet::metadata($filelink,'notes');
+            $r->print('<td> '.($notes eq '' ? '&nbsp;' : $notes).
+                      " </td>\n");
+        }
+
+        if ($hash{'display_attrs_14'} == 1) {
+            my $abstract = &Apache::lonnet::metadata($filelink,'abstract');
+            $r->print('<td> '.($abstract eq '' ? '&nbsp;' : $abstract).
+                      " </td>\n");
+        }
+
+        if ($hash{'display_attrs_15'} == 1) {
+            my $gradelevel = &Apache::lonnet::metadata($filelink,'gradelevel');
+            $r->print('<td> '.($gradelevel eq '' ? '&nbsp;' : $gradelevel).
+                      " </td>\n");
+        }
+
+        if ($hash{'display_attrs_16'} == 1) {
+            my $standards = &Apache::lonnet::metadata($filelink,'standards');
+            $r->print('<td> '.($standards eq '' ? '&nbsp;' : $standards).
+                      " </td>\n");
+        }
+
 	$r->print("</tr>\n");
     }
 
@@ -1115,7 +1171,7 @@ sub display_line {
 	$r->print("<tr bgcolor=\"$fileclr\">$extrafield<td valign=$valign>");
 	&begin_form ($r,$curdir);
 	my $indentm1 = $indent-1;
-	if ($indentm1 < 11 and $indentm1 > 0) {
+	if ($indentm1 < 16 and $indentm1 > 0) {
 	    $r->print("<img alt=\"\" src=",$iconpath,"whitespace",$indentm1,
 		      ".gif class='LC_icon' />\n");
 	} else {
@@ -1133,7 +1189,7 @@ sub display_line {
 	$r->print ('<input type="hidden" name="acts" value="" />');
 	$r->print ('<a name="'.$anchor.'"></a><input src="'.$iconpath.
 		   'folder_pointer_'.$diropen.'.gif"');
-	$r->print (' name="'.$msg.'" type="image" class="LC_indexer_icon" />'.
+	$r->print (' name="'.$msg.'" alt="'.$msg.'" type="image" class="LC_indexer_icon" />'.
 		   "\n");
 	my $quotable_curdir = &Apache::loncommon::escape_single($curdir);
 	$r->print ('<a href="javascript:gothere(\''
@@ -1150,7 +1206,7 @@ sub display_line {
 	    $r->print('<td> '.($title eq '' ? '&nbsp;' : $title).
 		      ' </td>'."\n");
 	}
-	$r->print('<td align="right"> ',
+	$r->print('<td align=right> ',
 		  $filecom[8]," </td>\n") 
 	    if $hash{'display_attrs_1'} == 1;
 	$r->print('<td> '.
@@ -1183,12 +1239,42 @@ sub display_line {
  	if ($hash{'display_attrs_10'} == 1) {
 	   $r->print('<td>&nbsp;</td>');
 	}
-	if ($hash{'display_attrs_11'} == 1) {
-	   $r->print('<td>&nbsp;</td>');
-	}
 	if ($hash{'display_attrs_7'} == 1) {
 	   $r->print('<td>&nbsp;</td>');
         }
+        if ($hash{'display_attrs_12'} == 1) {
+            my $subject = &Apache::lonnet::metadata($filelink,'subject');
+            $r->print('<td> '.($subject eq '' ? '&nbsp;' : $subject).
+                      " </td>\n");
+        }
+        if ($hash{'display_attrs_11'} == 1) {
+            $r->print('<td>&nbsp;</td>');
+        }
+        if ($hash{'display_attrs_12'} == 1) {
+            my $subject = &Apache::lonnet::metadata($filelink,'subject');
+            $r->print('<td> '.($subject eq '' ? '&nbsp;' : $subject).
+                      " </td>\n");
+        }
+        if ($hash{'display_attrs_13'} == 1) {
+            my $notes = &Apache::lonnet::metadata($filelink,'notes');
+            $r->print('<td> '.($notes eq '' ? '&nbsp;' : $notes).
+                      " </td>\n");
+        }
+        if ($hash{'display_attrs_14'} == 1) {
+            my $abstract = &Apache::lonnet::metadata($filelink,'abstract');
+            $r->print('<td> '.($abstract eq '' ? '&nbsp;' : $abstract).
+                      " </td>\n");
+        }
+        if ($hash{'display_attrs_15'} == 1) {
+            my $gradelevel = &Apache::lonnet::metadata($filelink,'gradelevel');
+            $r->print('<td> '.($gradelevel eq '' ? '&nbsp;' : $gradelevel).
+                      " </td>\n");
+        }
+        if ($hash{'display_attrs_16'} == 1) {
+            my $standards = &Apache::lonnet::metadata($filelink,'standards');
+            $r->print('<td> '.($standards eq '' ? '&nbsp;' : $standards).
+                      " </td>\n");
+        }
 	$r->print('</tr>');
     }
 
@@ -1269,7 +1355,7 @@ sub begin_form {
     $uri=&Apache::loncommon::escape_single($uri);
     $r->print ('<form method="post" name="dirpath'.$dnum.'" action="'.$uri.
 	       '#'.$anchor.
-	       '" onSubmit="return rep_dirpath(\''.$dnum.'\''.
+	       '" onsubmit="return rep_dirpath(\''.$dnum.'\''.
 	       ',document.forms.fileattr.acts.value)" '.
 	       'enctype="application/x-www-form-urlencoded">'."\n");
     $r->print ('<input type="hidden" name="openuri" value="'.$uri.'" />'.
