@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to manage course access keys 
 #
-# $Id: lonmanagekeys.pm,v 1.22 2007/06/20 23:15:15 albertel Exp $
+# $Id: lonmanagekeys.pm,v 1.24 2009/04/15 11:16:44 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -272,15 +272,22 @@ ENDKEYMENU
 	&Apache::loncommon::content_type($r,'text/html');
 	$r->send_http_header;
 	$r->print(&header().&Apache::loncommon::coursebrowser_javascript());
-        $r->print(
-   &mt('Course ID of Key Authority').': <input input type="text" size="25" name="course" value="" />');
-        $r->print(&mt('Domain').': '.&Apache::loncommon::select_dom_form(
-               $env{'request.role.domain'},'domain'));
-        $r->print(&Apache::loncommon::selectcourse_link(
-					        'keyform','course','domain',
-                                                undef,undef,undef,'Course'));
-        $r->print('<br /><input type="submit" value="'.&mt('Manage Access Keys').'" />');
-	$r->print('</form>'.&Apache::loncommon::end_page());
+        $r->print(&Apache::lonhtmlcommon::start_pick_box()
+                 .&Apache::lonhtmlcommon::row_title(&mt('Course ID of Key Authority'))
+                 .'<input input type="text" size="25" name="course" value="" />'
+                 .' '.&Apache::loncommon::selectcourse_link(
+                          'keyform','course','domain',
+                          undef,undef,undef,'Course')
+                 .&Apache::lonhtmlcommon::row_closure()
+                 .&Apache::lonhtmlcommon::row_title(&mt('Domain'))
+                 .&Apache::loncommon::select_dom_form($env{'request.role.domain'},'domain')
+                 .&Apache::lonhtmlcommon::row_closure(1)
+                 .&Apache::lonhtmlcommon::end_pick_box()
+        );
+        $r->print('<input type="submit" value="'.&mt('Next').'" />'
+                .'</form>'
+                .&Apache::loncommon::end_page()
+        );
     }
     return OK;
 }
