@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines to control the menu
 #
-# $Id: lonmenu.pm,v 1.244.2.14 2010/01/19 16:53:10 raeburn Exp $
+# $Id: lonmenu.pm,v 1.244.2.17 2010/05/24 12:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -163,19 +163,23 @@ sub show_course {
 }
 
 sub initlittle {
-    return &Apache::lonlocal::texthash('ret' => 'Return to Last Location',
-				       'nav' => 'Navigate Contents',
+    my %lt=&Apache::lonlocal::texthash('ret' => 'Return to Last Location',
+				       'nav' => 'Course Contents',
 				       'main' => 'Main Menu',
                                        'roles' => (&Apache::loncommon::show_course()?
                                                     'Courses':'Roles'),
                                        'other' => 'Other Roles',
-                                       'docs' => 'Edit Course',
+                                       'docs' => 'Course Editor',
                                        'exit' => 'Logout',
                                        'login' => 'Log In',
 				       'launch' => 'Launch Remote Control',
                                        'groups' => 'Groups',
-                                       'gdoc' => 'Community Documents',
                                        );
+    if (&Apache::loncommon::course_type() eq 'Community') {
+        $lt{'nav'} = &mt('Community Contents');
+        $lt{'docs'} = &mt('Community Editor');
+    }
+    return %lt;
 }
 
 sub menubuttons {
@@ -242,12 +246,9 @@ ENDNAV
 <a href="/adm/flip?postdata=$escreload" target="_top">$lt{'ret'}</a>
 ENDRELOAD
             }
-            my $is_community =
-                (&Apache::loncommon::course_type() eq 'Community');
             if (&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) {
-                my $text = ($is_community) ? $lt{'gdoc'} : $lt{'docs'};
                 $docs=(<<ENDDOCS);
-<a href="/adm/coursedocs" target="_top">$text</a>
+<a href="/adm/coursedocs" target="_top">$lt{'docs'}</a>
 ENDDOCS
             }
             if ($showgroups) {
@@ -312,12 +313,9 @@ ENDINLINEMENU
 	    $navmaps=(<<ENDNAV);
 <td><a href="$link" target="_top">$lt{'nav'}</a></td>
 ENDNAV
-            my $is_community =
-                (&Apache::loncommon::course_type() eq 'Community');
 	    if (&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) {
-                my $text = ($is_community) ? $lt{'gdoc'} : $lt{'docs'};
 		$docs=(<<ENDDOCS);
-<td><a href="/adm/coursedocs" target="_top">$text</a></td>
+<td><a href="/adm/coursedocs" target="_top">$lt{'docs'}</a></td>
 ENDDOCS
             }
             if ($showgroups) {
@@ -1250,7 +1248,6 @@ sub rawconfig {
         my ($row,$col,$pro,$prt,$img,$top,$bot,$act,$desc,$cat)=split(/\:/,$line);
         $prt=~s/\$uname/$uname/g;
         $prt=~s/\$udom/$udom/g;
-        $prt=~s/\$crs/$crs/g;
         if ($prt =~ /\$crs/) {
             next unless ($env{'request.course.id'});
             next if ($crstype eq 'Community');
