@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Metadata display handler
 #
-# $Id: lonmeta.pm,v 1.212.2.5 2009/04/04 13:47:50 raeburn Exp $
+# $Id: lonmeta.pm,v 1.233 2009/05/27 13:29:47 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -42,24 +42,6 @@ use Apache::lonmsg;
 use LONCAPA qw(:DEFAULT :match);
 
 
-############################################################
-############################################################
-##
-## &get_dynamic_metadata_from_sql($url)
-## 
-## Queries sql database for dynamic metdata
-## Returns a hash of hashes, with keys of urls which match $url
-## Returned fields are given below.
-##
-## Examples:
-## 
-## %DynamicMetadata = &Apache::lonmeta::get_dynmaic_metadata_from_sql
-##     ('/res/msu/korte/');
-##
-## $DynamicMetadata{'/res/msu/korte/example.problem'}->{$field}
-##
-############################################################
-############################################################
 sub get_dynamic_metadata_from_sql {
     my ($url) = shift();
     my ($authordom,$author)=($url=~m{^/res/($match_domain)/($match_username)/});
@@ -356,7 +338,7 @@ sub pre_select_course {
         &Apache::lonpublisher::metaeval($result);
     }
     $r->print('<hr /><form method="post" action="" >');
-    $r->print('<p>'.&mt('If you would like to associate this resource ([_1]) with a current or previous course, please select one from the list below, otherwise select, \'None\'','<tt>'.$res_uri.'</tt>').'</p>');
+    $r->print('<p>'.&mt('If you would like to associate this resource ([_1]) with a current or previous course, please select one from the list below, otherwise select, "None".','<tt>'.$res_uri.'</tt>').'</p>');
     $output = &select_course();
     $r->print($output.'<br /><input type="submit" name="store" value="'.
                   &mt('Associate Resource With Selected Course').'" />');
@@ -450,7 +432,7 @@ sub prettyprint {
     }
     # Title
     if ($type eq 'title') {
-	return '<font size="+1" face="arial">'.$value.'</font>';
+	return $value;
     }
     # Dates
     if (($type eq 'creationdate') ||
@@ -500,7 +482,7 @@ sub prettyprint {
 	($type eq 'comefrom_list') ||
 	($type eq 'sequsage_list') ||
 	($type eq 'dependencies')) {
-	return '<font size="-1"><ul>'.join("\n",map {
+	return '<ul class="LC_fontsize_medium">'.join("\n",map {
             my $url = &Apache::lonnet::clutter_with_no_wrapper($_);
             my $title = &Apache::lonnet::gettitle($url);
             if ($title eq '') {
@@ -518,9 +500,9 @@ sub prettyprint {
                 } 
             }
             $_ = '<li>'.$title.' '.
-		&Apache::lonhtmlcommon::crumbs($url,$target,$prefix,$form,'-1',$noformat).
+		&Apache::lonhtmlcommon::crumbs($url,$target,$prefix,$form,'0',$noformat).
                 '</li>'
-	    } split(/\s*\,\s*/,$value)).'</ul></font>';
+	    } split(/\s*\,\s*/,$value)).'</ul>';
     }
     # Evaluations
     if (($type eq 'clear') ||
@@ -537,7 +519,7 @@ sub prettyprint {
     # List of courses
     if ($type=~/\_list/) {
         my @Courses = split(/\s*\,\s*/,$value);
-        my $Str='<font size="-1"><ul>';
+        my $Str='<ul class="LC_fontsize_medium">';
 	my %descriptions;
         foreach my $course (@Courses) {
             my %courseinfo =
@@ -556,7 +538,7 @@ sub prettyprint {
 	    $Str .= $descriptions{$course};
 	}
 
-	return $Str.'</ul></font>';
+	return $Str.'</ul>';
     }
     # No pretty print found
     return $value;
@@ -596,7 +578,7 @@ sub relatedfield {
         return $relatedsep.'&nbsp;';
     }
     return $relatedsep.'<input type="checkbox" name="'.$fieldname.'_related"'.
-	($relatedvalue?' checked="1"':'').' />';
+	($relatedvalue?' checked="checked"':'').' />';
 }
 
 sub prettyinput {
@@ -709,7 +691,7 @@ sub prettyinput {
     # Obsolete
     if ($type eq 'obsolete') {
 	return '<input type="checkbox" name="'.$fieldname.'"'.
-	    ($value?' checked="1"':'').' />'.
+	    ($value?' checked="checked"':'').' />'.
             &relatedfield(0,$relatedsearchflag,$relatedsep); 
     }
     # Obsolete replacement file
@@ -780,7 +762,7 @@ sub handler {
     } elsif ($uri=~m|^/editupload/[^/]+/[^/]+/portfolio/|) {
 	    ($resdomain,$resuser)=
 		(&Apache::lonnet::declutter($uri)=~m|^($match_domain)/($match_name)/portfolio|);
-        $r->print(&Apache::loncommon::start_page('Edit Portfolio File Catalog Information',
+        $r->print(&Apache::loncommon::start_page('Edit Portfolio File Metadata',
 						 undef,
 						 {'domain' => $resdomain,}));
         if ($env{'form.store'}) {
@@ -799,20 +781,20 @@ sub handler {
             }
         }
     } elsif ($uri=~m|^/editupload/[^/]+/[^/]+/groups/|) {
-        $r->print(&Apache::loncommon::start_page('Edit Group Portfolio File Catalog Information',
+        $r->print(&Apache::loncommon::start_page('Edit Group Portfolio File Metadata',
 						 undef,
 						 {'domain' => $resdomain,}));
         &present_editable_metadata($r,$uri,'groups');    
     } elsif ($uri=~m|^/~|) { 
         # Construction space
-        $r->print(&Apache::loncommon::start_page('Edit Catalog Information',
+        $r->print(&Apache::loncommon::start_page('Edit Metadata',
 						"\n".'<script type="text/javascript">'."\n".
                                                 &Apache::loncommon::browser_and_searcher_javascript().
                                                 "\n".'</script>',
 						 {'domain' => $resdomain,}));
         &present_editable_metadata($r,$uri);
     } else {
-        $r->print(&Apache::loncommon::start_page('Catalog Information',
+        $r->print(&Apache::loncommon::start_page('Metadata',
 						 undef,
 						 {'domain' => $resdomain,}));
         &present_uneditable_metadata($r,$uri);
@@ -949,22 +931,22 @@ sub present_uneditable_metadata {
     foreach my $field (@fields) {
         my $lastrow = '';
         $rownum ++;
-        $lastrow = 1 if ($rownum == @fields);
+        $lastrow = 1 if ($rownum == @fields); 
         $table.=&Apache::lonhtmlcommon::row_title($lt{$field})
-                .&prettyprint($field,$content{$field})
-                .&Apache::lonhtmlcommon::row_closure($lastrow);
+               .&prettyprint($field,$content{$field})
+               .&Apache::lonhtmlcommon::row_closure($lastrow);
         delete($content{$field});
     }
     #
     $r->print("<h2>$title</h2>"
-              .'<p>'
-              .$disuri.'<br />'
-              .$obsoletewarning
-              .$versiondisplay
-              .'</p>'
-              .&Apache::lonhtmlcommon::start_pick_box()
-              .$table
-              .&Apache::lonhtmlcommon::end_pick_box()
+             .'<p>'
+             .$disuri.'<br />'
+             .$obsoletewarning
+             .$versiondisplay
+             .'</p>'
+             .&Apache::lonhtmlcommon::start_pick_box()
+             .$table
+             .&Apache::lonhtmlcommon::end_pick_box()
     );
     if (!$uploaded && $env{'user.adv'}) {
         &print_dynamic_metadata($r,$uri,\%content);
@@ -986,13 +968,13 @@ sub print_dynamic_metadata {
     my %dynmeta=&dynamicmeta($uri);
     #
     # General Access and Usage Statistics
+    $r->print('<h4>'.&mt('Access and Usage Statistics').'</h4>');
     if (exists($dynmeta{'count'}) ||
         exists($dynmeta{'sequsage'}) ||
         exists($dynmeta{'comefrom'}) ||
         exists($dynmeta{'goto'}) ||
         exists($dynmeta{'course'})) {
-        $r->print('<h4>'.&mt('Access and Usage Statistics').'</h4>'.
-                  &Apache::lonhtmlcommon::start_pick_box());
+        $r->print(&Apache::lonhtmlcommon::start_pick_box());
         my @counts = ('count','sequsage','sequsage_list',
                       'comefrom','comefrom_list','goto',
                       'goto_list','course','course_list');
@@ -1002,13 +984,16 @@ sub print_dynamic_metadata {
             $rownum ++;
             $lastrow = 1 if ($rownum == @counts);
             $r->print(&Apache::lonhtmlcommon::row_title($lt{$item})
-                      .&prettyprint($item,$dynmeta{$item})
-                      .&Apache::lonhtmlcommon::row_closure($lastrow)
+                     .&prettyprint($item,$dynmeta{$item})
+                     .&Apache::lonhtmlcommon::row_closure($lastrow)
             );
         }
         $r->print(&Apache::lonhtmlcommon::end_pick_box());
     } else {
-        $r->print('<h4>'.&mt('No Access or Usages Statistics are available for this resource.').'</h4>');
+        $r->print('<p>'
+                 .&mt('No Access or Usages Statistics are available for this resource.')
+                 .'</p>'
+        );
     }
     #
     # Assessment statistics
@@ -1023,8 +1008,8 @@ sub print_dynamic_metadata {
                       '</h4>'.
                       &Apache::lonhtmlcommon::start_pick_box());
             $r->print(&Apache::lonhtmlcommon::row_title($lt{'stdno'})
-                      .&prettyprint('stdno',$dynmeta{'stdno'})
-                      .&Apache::lonhtmlcommon::row_closure()
+                     .&prettyprint('stdno',$dynmeta{'stdno'})
+                     .&Apache::lonhtmlcommon::row_closure()
             );
             my @stats = ('avetries','difficulty','disc');
             my $rownum = 0;
@@ -1033,28 +1018,29 @@ sub print_dynamic_metadata {
                 $rownum ++;
                 $lastrow = 1 if ($rownum == @stats);
                 $r->print(&Apache::lonhtmlcommon::row_title($lt{$item})
-                          .&prettyprint($item,sprintf('%5.2f',$dynmeta{$item}))
-                          .&Apache::lonhtmlcommon::row_closure($lastrow)
+                         .&prettyprint($item,sprintf('%5.2f',$dynmeta{$item}))
+                         .&Apache::lonhtmlcommon::row_closure($lastrow)
                 );
             }
-            $r->print(&Apache::lonhtmlcommon::end_pick_box());    
+            $r->print(&Apache::lonhtmlcommon::end_pick_box());
         }
+        #
+        # New assessment statistics
+        $r->print('<h4>'
+                 .&mt('Recent Detailed Assessment Statistical Data')
+                 .'</h4>'
+        );
         if (exists($dynmeta{'stats'})) {
-            #
-            # New assessment statistics
-            $r->print('<h4>'.
-                      &mt('Recent Detailed Assessment Statistical Data').
-                      '</h4>');
             my $table=&Apache::loncommon::start_data_table()
-                      .&Apache::loncommon::start_data_table_header_row()
-                      .'<th>'.&mt('Course').'</th>'
-                      .'<th>'.&mt('Section(s)').'</th>'
-                      .'<th>'.&mt('Num Student').'s</th>'
-                      .'<th>'.&mt('Mean Tries').'</th>'
-                      .'<th>'.&mt('Degree of Difficulty').'</th>'
-                      .'<th>'.&mt('Degree of Discrimination').'</th>'
-                      .'<th>'.&mt('Time of computation').'</th>'
-                      .&Apache::loncommon::end_data_table_header_row().$/;
+                     .&Apache::loncommon::start_data_table_header_row()
+                     .'<th>'.&mt('Course').'</th>'
+                     .'<th>'.&mt('Section(s)').'</th>'
+                     .'<th>'.&mt('Num Students').'</th>'
+                     .'<th>'.&mt('Mean Tries').'</th>'
+                     .'<th>'.&mt('Degree of Difficulty').'</th>'
+                     .'<th>'.&mt('Degree of Discrimination').'</th>'
+                     .'<th>'.&mt('Time of computation').'</th>'
+                     .&Apache::loncommon::end_data_table_header_row().$/;
             foreach my $identifier (sort(keys(%{$dynmeta{'stats'}}))) {
                 my $data = $dynmeta{'stats'}->{$identifier};
                 my $course = $data->{'course'};
@@ -1090,7 +1076,10 @@ sub print_dynamic_metadata {
             $table .= &Apache::loncommon::end_data_table().$/;
             $r->print($table);
         } else {
-            $r->print(&mt('No new dynamic data found.'));
+            $r->print('<p>'
+                     .&mt('No new dynamic data found.')
+                     .'</p>'
+            );
         }
     } else {
         $r->print('<h4>'.
@@ -1099,14 +1088,14 @@ sub print_dynamic_metadata {
     }
 
     #
-    #
+    # Evaluation Data
+    $r->print('<h4>'.&mt('Evaluation Data').'</h4>');
     if (exists($dynmeta{'clear'})   || 
         exists($dynmeta{'depth'})   || 
         exists($dynmeta{'helpful'}) || 
         exists($dynmeta{'correct'}) || 
         exists($dynmeta{'technical'})){ 
-        $r->print('<h4>'.&mt('Evaluation Data').'</h4>'.
-                  &Apache::lonhtmlcommon::start_pick_box());
+        $r->print(&Apache::lonhtmlcommon::start_pick_box());
         my @criteria = ('clear','depth','helpful','correct','technical');
         my $rownum = 0;
         foreach my $item (@criteria) {
@@ -1114,33 +1103,46 @@ sub print_dynamic_metadata {
             $rownum ++;
             $lastrow = 1 if ($rownum == @criteria);
             $r->print(&Apache::lonhtmlcommon::row_title($lt{$item})
-                      .&prettyprint($item,$dynmeta{$item})
-                      .&Apache::lonhtmlcommon::row_closure($lastrow)
+                     .&prettyprint($item,$dynmeta{$item})
+                     .&Apache::lonhtmlcommon::row_closure($lastrow)
             );
         }
         $r->print(&Apache::lonhtmlcommon::end_pick_box());
     } else {
-        $r->print('<h4>'.&mt('No Evaluation Data is available for this resource.').'</h4>');
+        $r->print('<p>'
+                 .&mt('No Evaluation Data is available for this resource.')
+                 .'</p>'
+        );
     }
+    # Evaluation Comments
     $uri=~/^\/res\/($match_domain)\/($match_username)\//; 
     if ((($env{'user.domain'} eq $1) && ($env{'user.name'} eq $2))
         || ($env{'user.role.ca./'.$1.'/'.$2})) {
+        $r->print('<h4>'.&mt('Evaluation Comments').'</h4>'
+                 .'<div>('
+                 .&mt('visible to author and co-authors only')
+                 .')</div>'
+        );
         if (exists($dynmeta{'comments'})) {
-            $r->print('<h4>'.&mt('Evaluation Comments').' ('.
-                      &mt('visible to author and co-authors only').
-                      ')</h4>'.
-                      '<blockquote>'.$dynmeta{'comments'}.'</blockquote>');
+            $r->print('<blockquote>'.$dynmeta{'comments'}.'</blockquote>');
         } else {
-            $r->print('<h4>'.&mt('There are no Evaluation Comments on this resource.').'</h4>');
+            $r->print('<p>'
+                     .&mt('There are no Evaluation Comments on this resource.')
+                     .'</p>'
+            );
         }
         my $bombs = &Apache::lonmsg::retrieve_author_res_msg($uri);
         if (defined($bombs) && $bombs ne '') {
-            $r->print('<a name="bombs" /><h4>'.&mt('Error Messages').' ('.
-                      &mt('visible to author and co-authors only').')'.
-                      '</h4>'.$bombs);
-        } else {
-            $r->print('<h4>'.&mt('There are currently no Error Messages for this resource.').'</h4>');
-        }
+            $r->print('<a name="bombs" />'
+                     .'<h4 class="LC_error">'.&mt('Error Messages').'</h4>'
+                     .'<div>('
+                     .&mt('visible to author and co-authors only')
+                     .')</div>'
+                     .$bombs
+            );
+        } #else {
+        #    $r->print('<h4>'.&mt('There are currently no Error Messages for this resource.').'</h4>');
+        #}
     }
     #
     # All other stuff
@@ -1176,7 +1178,8 @@ sub print_dynamic_metadata {
                 }
             }
             $r->print(&Apache::lonhtmlcommon::row_title($display)
-                      .$content{$name});
+                     .$content{$name}
+            );
             if ($otherinfo) {
                 $r->print(' ('.$otherinfo.')');
             }
@@ -1255,11 +1258,12 @@ ENDDEL
 	}
 	$r->print('<br />'.$bombs);
     } else {
-        my $displayfile=&mt('Catalog Information for [_1]',$disuri);
+        my $displayfile=&mt('Metadata for [_1]',$disuri);
         if ($disuri=~/\/default$/) {
             my $dir=$disuri;
             $dir=~s/default$//;
-            $displayfile=&mt('Default Cataloging Information for Directory [_1]',$dir);
+            $displayfile=&mt('Default Metadata for Directory [_1]'
+                            ,'<span class="LC_filename">'.$dir.'</span>');
         }
         %Apache::lonpublisher::metadatafields=();
         %Apache::lonpublisher::metadatakeys=();
@@ -1286,7 +1290,7 @@ ENDDEL
             }
         }
         $r->print(<<ENDEDIT);
-<h1>$displayfile</h1>
+<p>$displayfile</p>
 <form method="post" action="" name="defaultmeta">
 ENDEDIT
         my %lt=&fieldnames($file_type);
@@ -1378,9 +1382,11 @@ ENDEDIT
                 $lt{$field_name} = $$added_metadata_fields{$field_name};
             }
         }
-        $output .= &Apache::loncommon::start_data_table();
-        my $row_alt = 1;
+        $output .= &Apache::lonhtmlcommon::start_pick_box();
+        my $last = $#fields + 1;
+        my $rowcount = 0;
         foreach my $field_name (@fields) {
+            $rowcount++;
             if (defined($env{'form.new_'.$field_name})) {
                 my @values = &Apache::loncommon::get_env_multiple('form.new_'.$field_name);
                 my $newvalue = '';
@@ -1399,31 +1405,32 @@ ENDEDIT
                     ($field_name eq 'courserestricted'))&&
                     (!($env{$Apache::lonpublisher::metadatafields{'courserestricted'}.'.metadata.'.$field_name.'.options'} =~ m/deleted/))){
                     
-                    $output .= "\n".&Apache::loncommon::start_data_table_row();
-                    $output .= ('<td><span class="LC_metadata">'.$lt{$field_name}.':</span></td><td> '.
-                              &prettyinput($field_name,
+                    $output .= &Apache::lonhtmlcommon::row_title($lt{$field_name})
+                              .&prettyinput($field_name,
 				   $Apache::lonpublisher::metadatafields{$field_name},
 				                    'new_'.$field_name,'defaultmeta',
 				                    undef,undef,undef,undef,
-				                    $Apache::lonpublisher::metadatafields{'courserestricted'}).'</td>');
-                    $output .= &Apache::loncommon::end_data_table_row();
+                                                    $Apache::lonpublisher::metadatafields{'courserestricted'});
+                    $output .= &Apache::lonhtmlcommon::row_closure($rowcount == $last?1:0);
                  }
             } else {
 
-                    $output.=(&Apache::loncommon::start_data_table_row().'<td><span class="LC_metadata">'.$lt{$field_name}.':</span></td><td> '.
-			      &prettyinput($field_name,
+                    $output .= &Apache::lonhtmlcommon::row_title($lt{$field_name})
+                              .&prettyinput($field_name,
 					   $Apache::lonpublisher::metadatafields{$field_name},
-					   'new_'.$field_name,'defaultmeta').'</td>'.&Apache::loncommon::end_data_table_row());
+                                           'new_'.$field_name,'defaultmeta')
+                              .&Apache::lonhtmlcommon::row_closure($rowcount == $last?1:0);
                
             }
         }
-        $output .= &Apache::loncommon::end_data_table();
+        $output .= &Apache::lonhtmlcommon::end_pick_box();
 	if ($env{'form.store'}) {
             my ($outcome,$result) = &store_metadata($fn,$uri,'store');
             $r->print($result);
 	}
-	$r->print($output.'<br /><input type="submit" name="store" value="'.
-                  &mt('Save Catalog Information').'" />');
+        my $savebutton = '<p><input type="submit" name="store"'
+                        .' value="'.&mt('Save').'" title="'.&mt('Save Metadata').'" /></p>';
+        $r->print($savebutton.$output.$savebutton);
 
 	if ($file_type eq 'portfolio' || $file_type eq 'groups') {
 	    my ($port_path,$group) = &get_port_path_and_group($uri);
@@ -1484,26 +1491,27 @@ sub store_metadata {
         $output .= $result;
     } else {
         if (! ($mfh=Apache::File->new('>'.$fn))) {
-            $output .= '<p><font color="red">';
+            $output .= '<p class="LC_error">';
             if ($caller eq 'transfer') {
                 $output .= &mt('Could not transfer data in added fields to notes');
             } else { 
                 $output .= &mt('Could not write metadata');
             }
-            $output .= ', '.&mt('FAIL').'</font></p>';
+            $output .= ', '.&mt('FAIL').'</p>';
             $outcome = 'fail';
         } else {
             print $mfh ($file_content);
             close($mfh);
             &update_metadata_table($uri);
-            $output .= '<p><font color="blue">';
+            my $confirmtext;
             if ($caller eq 'transfer') {
-                $output .= &mt('Transferred data in added fields to notes');
+                $confirmtext = &mt('Transferred data in added fields to notes');
             } else {
-                $output .= &mt('Wrote Metadata');
+                $confirmtext = &mt('Wrote Metadata');
             }
-            $output .= ' '.&Apache::lonlocal::locallocaltime(time).
-                       '</font></p>';
+            $output .= &Apache::loncommon::confirmwrapper(
+                           &Apache::lonhtmlcommon::confirm_success(
+                               $confirmtext.' '.&Apache::lonlocal::locallocaltime(time)));
             $outcome = 'ok';
         }
     }
@@ -1531,25 +1539,25 @@ sub store_portfolio_metadata {
     $env{'form.'.$formname.'.filename'}=$new_fn;
     my $result =&Apache::lonnet::userfileupload($formname,'',$path);
     if ($result =~ /(error|notfound)/) {
-        $output = '<p><font color="red">';
+        $output = '<p class="LC_error">';
         if ($caller eq 'transfer') {
             $output .= 
                 &mt('Could not transfer data in added fields to notes'); 
         } else {
             $output .= &mt('Could not write metadata');
         }
-        $output .= ', '.&mt('FAIL').'</font></p>';
+        $output .= ', '.&mt('FAIL').'</p>';
         $outcome = 'fail';
     } else {
         &update_metadata_table($uri);
-        $output = '<p><font color="blue">';
+        $output = '<p class="LC_success">';
         if ($caller eq 'transfer') {
             $output .= &mt('Transferred data in added fields to notes');
         } else {
             $output .= &mt('Wrote Metadata');
         }
         $output .= ' '.&Apache::lonlocal::locallocaltime(time).
-                   '</font></p>';
+                   '</p>';
         $outcome = 'ok';
     }
     return ($outcome,$output);
@@ -1588,3 +1596,95 @@ sub update_metadata_table {
 1;
 __END__
 
+
+=head1 NAME
+
+Apache::lonmeta - display meta data
+
+=head1 SYNOPSIS
+
+Handler to display meta data
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 SUBROUTINES
+
+=over
+
+=item &get_dynamic_metadata_from_sql($url) :
+
+Queries sql database for dynamic metdata
+Returns a hash of hashes, with keys of urls which match $url
+Returned fields are given below.
+
+Examples:
+
+    %DynamicMetadata = &Apache::lonmeta::get_dynmaic_metadata_from_sql
+    ('/res/msu/korte/');
+
+    $DynamicMetadata{'/res/msu/korte/example.problem'}->{$field}
+
+=item dynamicmeta()
+
+Fetch and evaluate dynamic metadata
+
+=item access_count()
+
+=item alttag()
+
+Try to make an alt tag if there is none
+
+=item authordisplay()
+
+Author display
+
+=item evalgraph()
+
+Pretty display
+
+=item diffgraph()
+
+=item fieldnames()
+
+=item portfolio_linked_path()
+
+=item get_port_path_and_group()
+
+=item portfolio_display_uri()
+
+=item pre_select_course()
+
+=item select_course()
+
+=item prettyprint()
+
+Pretty printing of metadata field
+
+=item direct()
+
+Pretty input of metadata field
+
+=item selectbox()
+
+=item relatedfield()
+
+=item prettyinput()
+
+=item report_bombs()
+
+=item present_uneditable_metadata()
+
+=item present_editable_metadata()
+
+=item store_metadata()
+
+=item store_transferred_addedfields()
+
+=item store_portfolio_metadata()
+
+=item update_metadata_table()
+
+=back
+
+=cut
