@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Navigate Maps Handler
 #
-# $Id: lonnavdisplay.pm,v 1.5 2008/10/20 03:25:49 raeburn Exp $
+# $Id: lonnavdisplay.pm,v 1.10.4.1 2010/02/14 21:53:02 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -155,8 +155,13 @@ MENU
 
     # Header
     my $course_type = &Apache::loncommon::course_type();
-    $r->print(&Apache::loncommon::start_page('Navigate '.$course_type.
-					     ' Contents',
+    my $title;
+    if ($course_type eq 'Community') {
+        $title = 'Community Contents';
+    } else {
+        $title = 'Course Contents';
+    }
+    $r->print(&Apache::loncommon::start_page($title,
 					     $js,
 					     {'only_body'       => $body_only,
 					      'force_register'  =>
@@ -256,9 +261,9 @@ MENU
 
         # If we found no problems, print a note to that effect.
         if (!$foundDoableProblem) {
-            $r->print("<font size='+2'>"
+            $r->print("<span class=\"LC_info\">"
                      .&mt("All homework assignments have been completed.")
-                     ."</font><br /><br />");
+                     ."</span>");
         }
     } else {
 	&Apache::lonnavmaps::add_linkitem(\%toplinkitems,'firsthomework',
@@ -281,7 +286,7 @@ MENU
 	&Apache::lonnavmaps::add_linkitem(\%toplinkitems,'everything',
 					  'location.href="navmaps?sort='.$env{'form.sort'}.'"',
 					  "Show everything");
-        $r->print("<p><font size='+2'>".&mt("Uncompleted Problems")."</font></p>");
+        $r->print("<span class=\"LC_info\">".&mt("Uncompleted Problems")."</span>");
         $env{'form.filter'} = '';
         $env{'form.condition'} = 1;
 	$resource_no_folder_link = 1;
@@ -292,18 +297,18 @@ MENU
 					  "Show only uncompleted problems");
     }
 
-    my %selected=($env{'form.sort'} => 'selected=on');
-    my $sort_html=("<form>
-                 <nobr>
+    my %selected=($env{'form.sort'} => ' selected="selected"');
+    my $sort_html=("<form name=\"sortForm\">
+                 <span class=\"LC_nobreak\">
                     <input type=\"hidden\" name=\"showOnlyHomework\" value=\"".$env{'form.showOnlyHomework'}."\" />
-                    <input type=\"submit\" value=\"".&mt('Sort by:')."\" />
-                    <select name=\"sort\">
-                       <option value=\"default\" $selected{'default'}>".&mt('Default')."</option>
-                       <option value=\"title\"   $selected{'title'}  >".&mt('Title')."</option>
-                       <option value=\"duedate\" $selected{'duedate'}>".&mt('Duedate')."</option>
-                       <option value=\"discussion\" $selected{'discussion'}>".&mt('Has New Discussion')."</option>
+                    ".&mt('Sort by:')."
+                    <select name=\"sort\" onChange=\"document.sortForm.submit()\">
+                       <option value=\"default\"$selected{'default'}>".&mt('Default')."</option>
+                       <option value=\"title\"$selected{'title'}  >".&mt('Title')."</option>
+                       <option value=\"duedate\"$selected{'duedate'}>".&mt('Duedate')."</option>
+                       <option value=\"discussion\"$selected{'discussion'}>".&mt('Has New Discussion')."</option>
                     </select>
-                 </nobr>
+                 </span>
                </form>");
     # renderer call
     my $renderArgs = { 'cols' => [0,1,2,3],
@@ -324,9 +329,9 @@ MENU
     # user knows there was no error.
     if ($renderArgs->{'counter'} == 0) {
         if ($showOnlyHomework) {
-            $r->print("<p><font size='+1'>".&mt("All homework is currently completed.")."</font></p>");
+            $r->print("<p><span class=\"LC_info\">".&mt("All homework is currently completed.")."</span></p>");
         } else { # both jumpToFirstHomework and normal use the same: course must be empty
-            $r->print("<p><font size='+1'>".&mt("This course is empty.")."</font></p>");
+            $r->print("<p><span class=\"LC_info\">".&mt("This course is empty.")."</span></p>");
         }
     }
     #my $td=&tv_interval($t0);
