@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Quick Student Grades Display
 #
-# $Id: lonquickgrades.pm,v 1.43.2.2 2008/12/12 18:49:03 raeburn Exp $
+# $Id: lonquickgrades.pm,v 1.49 2009/11/21 18:07:03 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -25,7 +25,6 @@
 #
 # http://www.lon-capa.org/
 #
-# Created Nov. 14, 2002 by Jeremy Bowers
 
 package Apache::lonquickgrades;
 
@@ -65,7 +64,10 @@ sub real_handler {
     my $showPoints = 
         $env{'course.'.$env{'request.course.id'}.'.grading'} eq 'standard';
     my $notshowSPRSlink = 
-        $env{'course.'.$env{'request.course.id'}.'.grading'} eq 'external';
+        (($env{'course.'.$env{'request.course.id'}.'.grading'} eq 'external')
+      || ($env{'course.'.$env{'request.course.id'}.'.grading'} eq 'externalnototals'));
+    my $notshowTotals=
+        $env{'course.'.$env{'request.course.id'}.'.grading'} eq 'externalnototals';
 
     # Create the nav map
     my $navmap = Apache::lonnavmaps::navmap->new();
@@ -81,8 +83,11 @@ sub real_handler {
     my $res = $navmap->firstResource(); # temp resource to access constants
  
     # Header
-    my $title = $showPoints ? "Points Display" : "Completed Problems Display";
-    $r->print(&Apache::loncommon::start_page($title));
+    my $title = "Grading and Statistics";#$showPoints ? "Points Display" : "Completed Problems Display";
+    my $brcrum = [{href=>"/adm/quickgrades",text => "Points Display"}];
+    $r->print(&Apache::loncommon::start_page($title,undef,
+                                            {'bread_crumbs' => $brcrum})
+             );
 
     if (!$showPoints && !$notshowSPRSlink ) {
         $r->print('<p>'
@@ -231,7 +236,7 @@ sub real_handler {
     if ($totalAttempted) {
 	$title .= " / " . &mt("Attempted");
     }
-    $r->print("<th>$title / ".&mt('Total').'</td>'
+    $r->print("<th>$title".($notshowTotals?'':" / ".&mt('Total')).'</th>'
              .&Apache::loncommon::end_data_table_header_row());
     while ($depth > 0) {
         if ($curRes == $iterator->BEGIN_MAP()) {$depth++;}
@@ -255,20 +260,22 @@ sub real_handler {
                 for (my $i = 1; $i < $depth; $i++) { $thisIndent .= $indentString; }
                 
                 $r->print("$thisIndent$title</td>");
-                if ($totalAttempted) {
-                    $r->print('<td valign="top">'
+		if ($totalAttempted) {
+		    $r->print('<td valign="top">'
                              .$thisIndent
                              .'<span class="LC_nobreak">'
-                             .$correct.' / '.$attempted.' / '.$total
-                             .'</span></td>');
-                } else {
-                    $r->print('<td valign="top">'
+                             .$correct.' / '.$attempted.($notshowTotals?'':' / '.$total)
+                             .'</span></td>'
+                             .&Apache::loncommon::end_data_table_row()
+                    );
+		} else {
+		    $r->print('<td valign="top">'
                              .$thisIndent
                              .'<span class="LC_nobreak">'
-                             .$correct.' / '.$total
-                             .'</span></td>');
-                }
-                $r->print(&Apache::loncommon::end_data_table_row());
+                             .$correct.($notshowTotals?'':' / '.$total)
+                             .'</span></td>'
+                             .&Apache::loncommon::end_data_table_row());
+		}
             }
         }
 
@@ -292,8 +299,8 @@ sub real_handler {
 	$title = $showPoints ? "Points" : "Parts Done";
 	my $totaltitle = $showPoints ? &mt("Awarded Total Points") : &mt("Total Parts Done");
 	$r->print(&Apache::loncommon::start_data_table_row()
-                 .'<td colspan="2" align="right">'.$totaltitle.': <b>'.$totalRight.'</b><br>');
-	$r->print(&mt("Max Possible To Date")." $maxHelpLink: <b>$totalPossible</b><br>");
+                 .'<td colspan="2" align="right">'.$totaltitle.': <b>'.$totalRight.'</b><br />');
+	$r->print(&mt('Max Possible To Date')." $maxHelpLink: <b>$totalPossible</b><br />");
 	$title = $showPoints ? "Points" : "Parts";
 	$r->print(&mt("Total $title In Course").': <b>'.$totalParts.'</b></td>'
                  .&Apache::loncommon::end_data_table_row());
