@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Syllabus
 #
-# $Id: lonsyllabus.pm,v 1.69.2.1 2008/12/24 08:10:09 raeburn Exp $
+# $Id: lonsyllabus.pm,v 1.69.4.2 2010/01/28 17:25:10 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -150,7 +150,7 @@ ENDSCRIPT
             &Apache::lonhtmlcommon::clear_breadcrumbs();
             &Apache::lonhtmlcommon::add_breadcrumb
              ({href=>"javascript:ToCatalog()",
-               text=>"Course Catalog"});
+               text=>"Course/Community Catalog"});
             if ($env{'form.coursenum'} ne '') {
                 &Apache::lonhtmlcommon::add_breadcrumb
                   ({href=>"javascript:ToCatalog('details')",
@@ -183,7 +183,7 @@ ENDSCRIPT
     } else {
 	$r->print('\begin{tabular}{|p{0.45\textwidth}|p{0.45\textwidth}|}\hline');
     }
-    my @personnel=sort keys %coursepersonnel;
+    my @personnel=sort(keys(%coursepersonnel));
     my $lastpers=$personnel[$#personnel];
     foreach my $element (@personnel) {
 	if ($target ne 'tex') {
@@ -246,7 +246,10 @@ ENDSCRIPT
 		    .' <tt>'.$protocol.'://'.
 		    &Apache::lonnet::hostname($homeserver).$r->uri.'</tt>'.
                &Apache::loncommon::help_open_topic('Syllabus_ExtLink').'</p>'.
-          '<p>'.&mt('You can specify an external URL as Syllabus in the [_1].','<a href="/adm/parmset?action=crsenv">'.&mt('Course Parameters').'</a>').'</p>'.
+          '<p class="LC_info">'.
+          &mt('Instead of using this template you can specify an external URL as Syllabus in the [_1]Course Configuration[_2].',
+          '<a href="/adm/courseprefs?actions=courseinfo&amp;phase=display">','</a>').
+          '</p>'.
 	  '<p><a href="'.$r->uri.'?forcestudent=1"><font size="+1">'.
 &mt('Show Public View').'</font></a>'.
           &Apache::loncommon::help_open_topic('Uploaded_Templates_PublicView').
@@ -362,8 +365,10 @@ ENDSCRIPT
 		       $r->print($message);
 		   } 
 	       } else {
-		   &Apache::lonfeedback::newline_to_br(\$message);
-		   $message =~s|(https?\://[^\s]+)|<a href="$1"><tt>$1</tt></a>|g;
+                   if (!&Apache::lonfeedback::contains_block_html($message)) {
+                       &Apache::lonfeedback::newline_to_br(\$message);
+                   }
+                   $message=&Apache::lonhtmlcommon::raw_href_to_link($message);
 		   if ($allowed) {
 		       $message=&Apache::lonspeller::markeduptext($message);
 		   }
