@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: loncorrectproblemplot.pm,v 1.22 2006/12/31 22:43:48 albertel Exp $
+# $Id: loncorrectproblemplot.pm,v 1.24 2008/10/30 17:45:25 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -293,37 +293,44 @@ sub CreateInterface {
     $Str .= &Apache::lonhtmlcommon::breadcrumbs('Correct Problems Plot');
     $Str .= '<p>';
     #
-    $Str .= '<table cellspacing="5">'."\n";
-    $Str .= '<tr>';
-    $Str .= '<td align="center"><b>'.&mt('Sections').'</b></td>';
-    $Str .= '<td align="center"><b>'.&mt('Groups').'</b></td>';
-    $Str .= '<td align="center"><b>'.&mt('Access Status').'</b></td>';
-    $Str .= '<td align="center"><b>'.&mt('Sequences and Folders').'</b></td>';
-    $Str .= '<td rowspan="2">'.
-        &Apache::lonstathelpers::limit_by_time_form().'</td>';
-    $Str .= '</tr>'."\n";
+    $Str .= &Apache::loncommon::start_data_table();
+    $Str .= &Apache::loncommon::start_data_table_header_row();
+    $Str .= '<th>'.&mt('Sections').'</th>';
+    $Str .= '<th>'.&mt('Groups').'</th>';
+    $Str .= '<th>'.&mt('Access Status').'</th>';
+    $Str .= '<th>'.&mt('Sequences and Folders').'</th>';
+    $Str .= '<th>'.&mt('Time Period').'</th>';
+    $Str .= &Apache::loncommon::end_data_table_header_row();
     #
-    $Str .= '<tr><td align="center">'."\n";
+    $Str .= &Apache::loncommon::start_data_table_row();
+    $Str .= '<td align="center" valign="top">'."\n";
     $Str .= &Apache::lonstatistics::SectionSelect('Section','multiple',5);
     $Str .= '</td>';
     #
-    $Str .= '<td align="center">'."\n";
+    $Str .= '<td align="center" valign="top">'."\n";
     $Str .= &Apache::lonstatistics::GroupSelect('Group','multiple',5);
     $Str .= '</td>';
-    $Str .= '<td align="center">';
+    $Str .= '<td align="center" valign="top">';
     $Str .= &Apache::lonhtmlcommon::StatusOptions(undef,undef,5);
-    $Str .= '</td><td>'."\n";
+    $Str .= '</td>'."\n";
     #
+    $Str .= '<td align="center" valign="top">'."\n";
     $Str .= &Apache::lonstatistics::map_select('Maps','multiple,all',5);
     $Str .= '</td>';
     #
-    $Str .= '</tr>'."\n";
-    $Str .= '</table>'."\n";
+    $Str .= '<td align="center" valign="top">'."\n";
+    $Str .= &Apache::lonstathelpers::limit_by_time_form();
+    $Str .= '</td>';
     #
-    $Str .= '<nobr>'.&mt('Status: [_1]',
-                         '<input type="text" '.
-                         'name="stats_status" size="60" value="" />').
-            '</nobr>'.'</p>';
+    $Str .= &Apache::loncommon::end_data_table_row();
+    $Str .= &Apache::loncommon::end_data_table();
+    #
+    $Str .= '<p><span class="LC_nobreak">'
+           .&mt('Status: [_1]',
+                    '<input type="text" name="stats_status"'
+                   .' size="60" value="" readonly="readonly" />')
+           .'</span></p>';
+    $Str .= '</p>';
     ##
     return $Str;
 }
