@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonproblemanalysis.pm,v 1.134 2008/12/12 07:26:28 raeburn Exp $
+# $Id: lonproblemanalysis.pm,v 1.138 2010/01/14 17:20:51 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1332,7 +1332,7 @@ sub OR_tries_analysis {
             if ($try > 1) {
                 $analysis_html.= '<tr><td colspan="4">'
                                 .'<div class="LC_info">'
-                                .&mt('None of the selected students attempted the problem more than [_1] times.'
+                                .&mt('None of the selected students attempted the problem more than [quant,_1,time].'
                                     ,$try-1)
                                 .'</div>'
                                 .'</td></tr>';
@@ -1558,7 +1558,7 @@ sub OR_time_analysis {
         $table .= '<tr><td colspan="4" align="center">'.
             &mt('Start time: [_1]',$startdateform).'<br />'.
             &mt('End time: [_1]',$enddateform).'</td></tr>'.$/;
-        $table.= '<tr><td colspan="4">&nbsp</td></tr>'.$/;
+        $table.= '<tr><td colspan="4">&nbsp;</td></tr>'.$/;
     }
     $table .= '</table>';
     #
@@ -1901,16 +1901,16 @@ sub CreateInterface {
     #
     ##
     ##
-    $Str .= '<td align="right" valign="top">';
+    $Str .= '<td valign="top">';
     ##
     my $showprob_checkbox = 
-        '<input type="checkbox" name="show_prob" value="true" ';
+        '<input type="checkbox" name="show_prob" value="true"';
     if ($env{'form.show_prob'} eq 'true') {
-        $showprob_checkbox .= 'checked="checked" ';
+        $showprob_checkbox .= ' checked="checked"';
     }
     $showprob_checkbox.= ' />';
     $Str.= '<span class="LC_nobreak"><label>'.
-        &mt('Show problem [_1]',$showprob_checkbox).
+        $showprob_checkbox.' '.&mt('Show problem').
         '</label></span><br />';
     ##
     my $analyze_selector = '<select name="AnalyzeOver" >';
