@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstudentassessment.pm,v 1.150 2008/09/16 13:10:19 bisitz Exp $
+# $Id: lonstudentassessment.pm,v 1.150.2.5 2010/04/14 07:08:00 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -248,14 +248,14 @@ sub next_and_previous_buttons {
     if (defined($previous)) {
         my $sname = $previous->{'username'}.':'.$previous->{'domain'};
         $previousbutton .= '<input type="button" value="'.
-            'Previous Student ('.
-            $previous->{'username'}.'@'.$previous->{'domain'}.')'.
+            &mt('Previous Student ([_1])',
+            $previous->{'username'}.':'.$previous->{'domain'}).
             '" onclick="document.Statistics.SelectedStudent.value='.
             "'".$sname."'".';'.
             'document.Statistics.submit();" />';
     } else {
         $previousbutton .= '<input type="button" value="'.
-            'Previous student (none)'.'" />';
+            &mt('Previous student').'" disabled="disabled" />';
     }
     #
     # Build the next student link
@@ -264,19 +264,19 @@ sub next_and_previous_buttons {
     if (defined($next)) {
         my $sname = $next->{'username'}.':'.$next->{'domain'};
         $nextbutton .= '<input type="button" value="'.
-            'Next Student ('.
-            $next->{'username'}.'@'.$next->{'domain'}.')'.
+            &mt('Next Student ([_1])',
+            $next->{'username'}.':'.$next->{'domain'}).
             '" onclick="document.Statistics.SelectedStudent.value='.
-            "'".$sname."'".';'.
+            "'$sname'".';'.
             'document.Statistics.submit();" />';
     } else {
         $nextbutton .= '<input type="button" value="'.
-            'Next student (none)'.'" />';
+            &mt('Next student').'" disabled="disabled" />';
     }
     #
     # Build the 'all students' button
     my $all = '';
-    $all .= '<input type="button" value="All Students" '.
+    $all .= '<input type="button" value="'.&mt('All Students').'" '.
             '" onclick="document.Statistics.SelectedStudent.value='.
             "''".';'.'document.Statistics.submit();" />';
     $Str .= $previousbutton.('&nbsp;'x5).$all.('&nbsp;'x5).$nextbutton;
@@ -327,7 +327,7 @@ sub CreateInterface {
 	'</td>';
     $Str .= '<td align="center"><b>'.&mt('Groups').'</b>'.
 	'</td>';
-    $Str .= '<td align="center"><b>'.&mt('Student Data</b>').
+    $Str .= '<td align="center"><b>'.&mt('Student Data').'</b>'.
 	&Apache::loncommon::help_open_topic("Chart_Student_Data").
 	'</td>';
     $Str .= '<td align="center"><b>'.&mt('Access Status').'</b>'.
@@ -361,19 +361,20 @@ sub CreateInterface {
     $Str .= &CreateAndParseOutputDataSelector();
     $Str .= '</td></tr>'."\n";
     $Str .= '</table>'."\n";
-    $Str .= '<input type="submit" name="Generate Chart" value="'.
-        &mt('Generate Chart').'" />';
-    $Str .= '&nbsp;'x5;
+    $Str .= '<p>'.
+            &mt('Status:').' '.
+            '<input type="text" name="stats_status" size="60" value="" readonly="readonly" />'.
+            '</p>';
     $Str .= '<input type="submit" name="selectstudent" value="'.
         &mt('Select One Student').'" />';
     $Str .= '&nbsp;'x5;
     $Str .= '<input type="submit" name="ClearCache" value="'.
         &mt('Clear Caches').'" />';
-    $Str .= '&nbsp;'x5;
-    $Str .= 
-        &mt('Status [_1]',
-            '<input type="text" name="stats_status" size="60" value="" readonly="readonly" />');
-    $Str .= '<br />';
+    $Str .= '<p>'.
+            '<input type="submit" name="Generate Chart"'.
+            ' value="'.&mt('Generate Chart').'" />'.
+            '</p>';
+
     return $Str;
 }
 
@@ -546,7 +547,7 @@ my @OutputDataOptions =
        summary_table => 1,
        maximum_row => 0,
        ignore_weight => 1,
-       shortdesc => 'Number of Problem Parts completed successfully.',
+       shortdesc => 'Number of Problem Parts completed successfully',
        longdesc => 'The Number of Problem Parts completed successfully and '.
            'the maximum possible for each student',
        },
@@ -554,7 +555,8 @@ my @OutputDataOptions =
 
 sub HTMLifyOutputDataDescriptions {
     my $Str = '';
-    $Str .= "<h2>Output Data</h2>\n";
+    $Str .= '<h2>'.&mt('Output Data').'</h2>'."\n";
+
     $Str .= "<dl>\n";
     foreach my $option (@OutputDataOptions) {
         $Str .= '    <dt>'.$option->{'name'}.'</dt>';
@@ -663,9 +665,9 @@ sub html_initialize {
         &Apache::lonstatistics::selected_sequences_with_assessments();
     if (! ref($navmap)) {
         # Unable to get data, so bail out
-        $r->print("<h3>".
+        $r->print('<p class="LC_error">'.
                   &mt('Unable to retrieve course information.').
-                  '</h3>');
+                  '</p>');
     }
 
     # If we're showing links, show a checkbox to open in new
@@ -675,14 +677,14 @@ sub html_initialize {
         $r->print(<<NEW_WINDOW_CHECKBOX);
 <script type="text/javascript">new_window = true;</script>
 <p><label>$labeltext 
-<input type="checkbox" checked="1" onclick="new_window=this.checked" />
+<input type="checkbox" checked="checked" onclick="new_window=this.checked" />
 </label></p>
 NEW_WINDOW_CHECKBOX
     }
 
     #
     $r->print("<h3>".$env{'course.'.$env{'request.course.id'}.'.description'}.
-              "&nbsp;&nbsp;".localtime(time)."</h3>");
+              "&nbsp;&nbsp;".&Apache::lonlocal::locallocaltime(time)."</h3>");
     #
     if ($chosen_output->{'base'} !~ /^final table/) {
         $r->print("<h3>".&mt($chosen_output->{'shortdesc'})."</h3>");        
@@ -994,9 +996,9 @@ sub StudentAverageTotal {
 sub SingleStudentTotal {
     return if (! defined($navmap));
     my $student = &Apache::lonstatistics::current_student();
-    my $Str = '<h3>'.&mt('Summary table for [_1] ([_2]@[_3])',
+    my $Str = '<h3>'.&mt('Summary table for [_1] ([_2])',
                          $student->{'fullname'},
-                         $student->{'username'},$student->{'domain'}).'</h3>';
+                         $student->{'username'}.':'.$student->{'domain'}).'</h3>';
     $Str .= $/;
     $Str .= &Apache::loncommon::start_data_table()."\n";
     $Str .= 
@@ -1177,11 +1179,11 @@ sub excel_initialize {
     #
     # Put the date in there too
     $excel_sheet->write($header_row,$cols_output++,
-                        'Compiled on '.localtime(time),$format->{'h3'});
+                        &mt('Compiled on [_1]',&Apache::lonlocal::locallocaltime(time)),$format->{'h3'});
     #
     $cols_output = 0;
     $excel_sheet->write($description_row,$cols_output++,
-                        $chosen_output->{'shortdesc'},
+                        &mt($chosen_output->{'shortdesc'}),
                         $format->{'b'});
     #
     $cols_output = 0;
@@ -1259,17 +1261,17 @@ sub excel_initialize {
         $formula_data{$symb}->{'Excel:scorecol'}=$cols_output;
         if ($chosen_output->{'base'} eq 'parts correct total') {
             $excel_sheet->write($resource_name_row,$cols_output++,
-                                'parts correct',
+                                &mt('parts correct'),
                                 $format->{'bold'});
         } elsif ($chosen_output->{'sequence_sum'}) {
             if ($chosen_output->{'correct'}) {
                 # Only reporting the number correct, so do not call it score
                 $excel_sheet->write($resource_name_row,$cols_output++,
-                                    'sum',
+                                    &mt('sum'),
                                     $format->{'bold'});
             } else {
                 $excel_sheet->write($resource_name_row,$cols_output++,
-                                    'score',
+                                    &mt('score'),
                                     $format->{'bold'});
             }
         }
@@ -1279,7 +1281,7 @@ sub excel_initialize {
             ($first_data_row,$cols_output-1);
         if ($chosen_output->{'sequence_max'}) {
             $excel_sheet->write($resource_name_row,$cols_output,
-                                'maximum',
+                                &mt('maximum'),
                                 $format->{'bold'});
             $formula_data{$symb}->{'Excel:maxcell'} = 
                 &Spreadsheet::WriteExcel::Utility::xl_rowcol_to_cell
@@ -1293,11 +1295,11 @@ sub excel_initialize {
         }
     }
     if ($chosen_output->{'grand_total'}) {
-        $excel_sheet->write($resource_name_row,$cols_output++,'Total',
+        $excel_sheet->write($resource_name_row,$cols_output++,&mt('Total'),
                             $format->{'bold'});
     }
     if ($chosen_output->{'grand_maximum'}) {
-        $excel_sheet->write($resource_name_row,$cols_output++,'Max. Total',
+        $excel_sheet->write($resource_name_row,$cols_output++,&mt('Max. Total'),
                             $format->{'bold'});
     }
     $total_formula = $excel_sheet->store_formula($total_formula_string);
@@ -1388,17 +1390,17 @@ sub excel_initialize {
     if ($chosen_output->{'summary_table'}) {
         $cols_output = 0;
         $excel_sheet->write($summary_header_row,$cols_output++,
-                            'Summary Table',$format->{'bold'});
+                            &mt('Summary Table'),$format->{'bold'});
         if ($chosen_output->{'maximum_row'}) {
             $excel_sheet->write($summary_header_row,$cols_output++,
-                                'Maximum',$format->{'bold'});
+                                &mt('Maximum'),$format->{'bold'});
         }
         $excel_sheet->write($summary_header_row,$cols_output++,
-                            'Average',$format->{'bold'});
+                            &mt('Average'),$format->{'bold'});
         $excel_sheet->write($summary_header_row,$cols_output++,
-                            'Median',$format->{'bold'});
+                            &mt('Median'),$format->{'bold'});
         $excel_sheet->write($summary_header_row,$cols_output++,
-                            'Std Dev',$format->{'bold'});
+                            &mt('Std Dev'),$format->{'bold'});
         my $row = $summary_header_row+1;
         foreach my $seq (@sequences) {
             my $symb = $seq->symb;
@@ -1438,14 +1440,10 @@ sub excel_initialize {
     if ($env{'form.SelectedStudent'}) {
         $studentcount = '1';
     }
-    if ($studentcount > 1) {
-        $r->print('<h1>'.&mt('Compiling Excel spreadsheet for [_1] students',
-                             $studentcount)."</h1>\n");
-    } else {
-        $r->print('<h1>'.
-                  &mt('Compiling Excel spreadsheet for 1 student').
-                  "</h1>\n");
-    }
+    $r->print('<p>'
+             .&mt('Compiling Excel spreadsheet for [quant,_1,student]...',$studentcount)
+            ."</p>\n"
+    );
     $r->rflush();
     #
     # Initialize progress window
@@ -1593,7 +1591,7 @@ sub excel_finish {
     #
     # Tell the user where to get their excel file
     $r->print('<br />'.
-              '<a href="'.$filename.'">Your Excel spreadsheet.</a>'."\n");
+              '<a href="'.$filename.'">'.&mt('Your Excel spreadsheet').'</a>'."\n");
     $r->rflush();
     &excel_cleanup();
     return;
@@ -1676,7 +1674,7 @@ END
     # Datestamp
     my $description = $env{'course.'.$env{'request.course.id'}.'.description'};
     print $outputfile '"'.&Apache::loncommon::csv_translate($description).'",'.
-        '"'.&Apache::loncommon::csv_translate(scalar(localtime(time))).'"'.
+        '"'.&Apache::loncommon::csv_translate(scalar(&Apache::lonlocal::locallocaltime(time))).'"'.
             "\n";
     print $outputfile '"'.
         &Apache::loncommon::csv_translate
@@ -1716,23 +1714,23 @@ END
         $sequence_row.='"",'x$count;
         if ($chosen_output->{'sequence_sum'}) {
             if($chosen_output->{'correct'}) {
-                $resource_row .= '"sum",';
+                $resource_row .= '"'.&mt('sum').'",';
             } else {
-                $resource_row .= '"score",';
+                $resource_row .= '"'.&mt('score').'",';
             }
         }
         if ($chosen_output->{'sequence_max'}) {
             $sequence_row.= '"",';
-            $resource_row .= '"maximum possible",';
+            $resource_row .= '"'.&mt('maximum possible').'",';
         }
     }
     if ($chosen_output->{'grand_total'}) {
         $sequence_row.= '"",';
-        $resource_row.= '"Total",';
+        $resource_row.= '"'.&mt('Total').'",';
     } 
     if ($chosen_output->{'grand_maximum'}) {
         $sequence_row.= '"",';
-        $resource_row.= '"Maximum",';
+        $resource_row.= '"'.&mt('Maximum').'",';
     } 
     chomp($sequence_row);
     chomp($resource_row);
