@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstudentsubmissions.pm,v 1.52 2008/12/12 05:52:26 raeburn Exp $
+# $Id: lonstudentsubmissions.pm,v 1.56 2010/01/14 17:20:51 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -285,7 +285,7 @@ sub prepare_html_output {
                 $headers{'part'} .= qq{<th colspan="$part_span">$tmpname</th>};
                 $nonempty_part_headers = 1;
             } else {
-                $headers{'part'} .= qq{<th colspan="$part_span">&nbsp</th>};
+                $headers{'part'} .= qq{<th colspan="$part_span">&nbsp;</th>};
             }
             $prob_span += $part_span;
         }
@@ -931,11 +931,13 @@ sub prepare_csv_output {
             time.'_'.rand(1000000000).'.csv';
     unless ($outputfile = Apache::File->new('>/home/httpd'.$filename)) {
         $r->log_error("Couldn't open $filename for output $!");
-        $r->print('<div class="LC_error">'
-                 .&mt('Problems occurred in writing the CSV file. '
-                     .'This error has been logged. '
-                     .'Please alert your LON-CAPA administrator.')
-                 .'</div>');
+        $r->print(
+            '<p class="LC_error">'
+           .&mt('Problems occurred in writing the CSV file.')
+           .' '.&mt('This error has been logged.')
+           .' '.&mt('Please alert your LON-CAPA administrator.')
+           .'</p>'
+        );
         $outputfile = undef;
     }
     #
@@ -1096,7 +1098,6 @@ sub CreateInterface {
     $Str .= '<th>'.&mt('Sections').'</th>';
     $Str .= '<th>'.&mt('Groups').'</th>';
     $Str .= '<th>'.&mt('Access Status').'</th>';
-#    $Str .= '<th>'.&mt('Output as [_1]',$output_selector).'</th>';
     $Str .= '<th>'.&mt('Options').'</th>';
     $Str .= '<th>'.&mt('Output Format').'</th>';
     $Str .= &Apache::loncommon::end_data_table_header_row();
@@ -1144,18 +1145,21 @@ sub CreateInterface {
     }
     $prob_status_checkbox .= 'value="true" />';
     #
-    $Str .= '<td align="right" valign="top">'.
-        '<label><b>'.
-        &mt('Show problem [_1]',$prob_checkbox).'</b></label><br />'.
-        '<label><b>'.
-        &mt('Show correct answers [_1]',$ans_checkbox).'</b></label><br />'.
-        '<label><b>'.
-        &mt('Show all submissions [_1]',$all_sub_checkbox).
-        '</b></label><br />'.
-        '<label><b>'.
-        &mt('Show problem grading [_1]',$prob_status_checkbox).
-        '</b></label><br />'.
-        '</td>';
+    $Str .=
+        '<td valign="top">'
+       .'<label>'
+       .$prob_checkbox.&mt('Show problem')
+       .'</label><br />'
+       .'<label>'
+       .' '.$ans_checkbox.&mt('Show correct answers')
+       .'</label><br />'
+       .'<label>'
+       .$all_sub_checkbox.&mt('Show all submissions')
+       .'</label><br />'
+       .'<label>'
+       .$prob_status_checkbox.&mt('Show problem grading')
+       .'</label>'
+       .'</td>';
     #
     $Str .= '<td align="center" valign="top">'.$output_selector.'</td>';
     #
