@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Localization routines
 #
-# $Id: lonlocal.pm,v 1.50.2.2 2009/01/05 16:55:04 raeburn Exp $
+# $Id: lonlocal.pm,v 1.60 2009/10/01 20:22:33 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -173,9 +173,11 @@ require Exporter;
 our @ISA = qw (Exporter);
 our @EXPORT = qw(mt mtn ns mt_user);
 
+my %mtcache=();
+
 # ========================================================= The language handle
 
-use vars qw($lh);
+use vars qw($lh $current_language);
 
 # ===================================================== The "MakeText" function
 
@@ -191,7 +193,13 @@ sub mt (@) {
                 return $_[0];
             }
         } else {
-            return $lh->maketext(@_);
+            if ($#_>0) { return $lh->maketext(@_); }
+            if ($mtcache{$current_language.':'.$_[0]}) {
+               return $mtcache{$current_language.':'.$_[0]};
+            }
+            my $translation=$lh->maketext(@_);
+            $mtcache{$current_language.':'.$_[0]}=$translation;
+            return $translation; 
         }
     } else {
 	if (wantarray) {
@@ -254,8 +262,8 @@ sub preferred_languages {
         push(@languages,@browser);
     }
 
-    foreach my $domtype ($Apache::lonnet::env{'user.domain'},$Apache::lonnet::env{'request.role.domain'},
-                         $Apache::lonnet::perlvar{'lonDefDomain'}) {
+    my $defdom = &Apache::lonnet::default_login_domain();
+    foreach my $domtype ($Apache::lonnet::env{'user.domain'},$Apache::lonnet::env{'request.role.domain'},$defdom) {
         if ($domtype ne '') {
             my %domdefs = &Apache::lonnet::get_domain_defaults($domtype);
             if ($domdefs{'lang_def'} ne '') {
@@ -287,10 +295,13 @@ sub get_genlanguages {
 
 sub current_encoding {
     my $default='UTF-8';
-    if ($Apache::lonnet::env{'browser.os'} eq 'win' && 
-	$Apache::lonnet::env{'browser.type'} eq 'explorer') {
-        $default='ISO-8859-1';
-    }
+# UTF-8 character encoding needed for the whole LON-CAPA system
+# (interface language and homework problem content)
+# See Bugzilla 5702 vs. 2189 and 4067
+#    if ($Apache::lonnet::env{'browser.os'} eq 'win' && 
+#	$Apache::lonnet::env{'browser.type'} eq 'explorer') {
+#        $default='ISO-8859-1';
+#    }
     if ($lh) {
 	my $enc=$lh->maketext('char_encoding');
 	return ($enc eq 'char_encoding'?$default:$enc);
@@ -332,6 +343,7 @@ sub get_language_handle {
     my @languages=&preferred_languages();
     $ENV{'HTTP_ACCEPT_LANGUAGE'}='';
     $lh=Apache::localize->get_handle(@languages);
+    $current_language=&current_language();
     if ($r) {
 	$r->content_languages([&current_language()]);
     }
@@ -347,10 +359,10 @@ sub gettimezone {
         }
         return $timezone;
     }
-    my $cid = $Apache::lonnet::env{'request.course.id'};
+    my $cid = $Apache::lonnet::env{'request.course.id'};  
     if ($cid ne '') {
         if ($Apache::lonnet::env{'course.'.$cid.'.timezone'}) {
-            $timezone = $Apache::lonnet::env{'course.'.$cid.'.timezone'};
+            $timezone = $Apache::lonnet::env{'course.'.$cid.'.timezone'};    
         } else {
             my $cdom = $Apache::lonnet::env{'course.'.$cid.'.domain'};
             if ($cdom ne '') {
@@ -383,6 +395,7 @@ sub gettimezone {
 
 sub locallocaltime {
     my ($thistime,$timezone) = @_;
+
     if (!defined($thistime) || $thistime eq '') {
 	return &mt('Never');
     }
@@ -396,7 +409,16 @@ sub locallocaltime {
     }
 
     my $dt = DateTime->from_epoch(epoch => $thistime)
-                     ->set_time_zone(&gettimezone($timezone));
+                     ->set_time_zone(gettimezone($timezone));
+
+    # TimeZone tries to determine the 'local' timezone from $ENV{TZ} if this
+    # fails it searches through various system files. Under certain
+    # circumstances this is an extremly expensive operation.
+    # So after the first run we store the timezone in $ENV{TZ} to significantly
+    # speed up future lookups. 
+    $ENV{TZ} = $dt->time_zone()->name() 
+        if (! $ENV{TZ} && gettimezone($timezone) eq 'local');
+
     if ((&current_language=~/^en/) || (!$lh)) {
 
 	return $dt->strftime("%a %b %e %I:%M:%S %P %Y (%Z)");
@@ -469,13 +491,19 @@ sub getdatelocale {
     return $locale_obj;
 }
 
+=pod 
 
-# ==================== Normalize string (reduce fragility in the lexicon files)
+=item * normalize_string
+
+Normalize string (reduce fragility in the lexicon files)
+
+This normalizes a string to reduce fragility in the lexicon files of
+huge messages (such as are used by the helper), and allow useful
+formatting: reduce all consecutive whitespace to a single space,
+and remove all HTML
+
+=cut
 
-# This normalizes a string to reduce fragility in the lexicon files of
-# huge messages (such as are used by the helper), and allow useful
-# formatting: reduce all consecutive whitespace to a single space,
-# and remove all HTML
 sub normalize_string {
     my $s = shift;
     $s =~ s/\s+/ /g;
@@ -486,13 +514,27 @@ sub normalize_string {
     return $s;
 }
 
-# alias for normalize_string; recommend using it only in the lexicon
+=pod 
+
+=item * ns
+
+alias for normalize_string; recommend using it only in the lexicon
+
+=cut
+
 sub ns {
     return normalize_string(@_);
 }
 
-# mtn: call the mt function and the normalization function easily.
-# Returns original non-normalized string if there was no translation
+=pod
+
+=item * mtn
+
+mtn: call the mt function and the normalization function easily.
+Returns original non-normalized string if there was no translation
+
+=cut
+
 sub mtn (@) {
     my @args = @_; # don't want to modify caller's string; if we
 		   # didn't care about that we could set $_[0]
