@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # URL translation for encrypted filenames
 #
-# $Id: lonenc.pm,v 1.23 2008/03/17 09:51:40 foxr Exp $
+# $Id: lonenc.pm,v 1.24 2008/12/19 14:29:13 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -165,7 +165,7 @@ sub encrypt_ref {
 	    next if (!$value); 
 	    next if ($value =~ /^\w+:/); # explict javascript: or http: link
 	    my $href=&Apache::lonnet::hreflocation($Apache::lonxml::pwd[-1],$value);
-	    if ($href !~ /^http:/) {
+	    if ($href !~ /^https?\:/) {
 		# IE really wants an extension
 		my ($extension) = ($href =~ m/(\.[^.]*)$/);
 		$href = &Apache::lonenc::encrypted($href,$force_enc);
