@@ -9,7 +9,7 @@
 #  and displays a page showing the results of the action.
 #
 #
-# $Id: loncfile.pm,v 1.91 2008/12/19 14:01:16 raeburn Exp $
+# $Id: loncfile.pm,v 1.100.2.4 2010/04/13 22:28:42 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -361,18 +361,28 @@ sub cleanDest {
 	my ($newpath)=($dest=~m|(.*)/|);
 	$newpath=&relativeDest($fn,$newpath,$uname);
 	if (! -d "$newpath") {
-	    $request->print("<p><span class=\"LC_error\">".&mt('You have requested to create file in directory [_1] which doesn\'t exist. The requested directory path has been removed from the requested file name.','"'.&display($newpath).'"')."</span></p>");
+	    $request->print('<p><span class="LC_warning">'
+                           .&mt("You have requested to create file in directory [_1] which doesn't exist. The requested directory path has been removed from the requested file name."
+                               ,&display($newpath))
+                           .'</span></p>');
 	    $dest=~s|.*/||;
 	}
     }
     if ($dest =~ /\.(\d+)\.(\w+)$/){
-	$request->print('<span class="LC_error">'
-			.&mt('Bad filename [_1].<br /> <tt>(name).(number).(extension)</tt> not allowed. <br /> Removing the <tt>.number.</tt> from requested filename.',&display($dest))
-			.'</span>');
+	$request->print('<p><span class="LC_warning">'
+			.&mt('Bad filename [_1]',&display($dest))
+                        .'<br />'
+                        .&mt('[_1](name).(number).(extension)[_2] not allowed.','<tt>','</tt>')
+                        .'<br />'
+                        .&mt('Removing the [_1].number.[_2] from requested filename.','<tt>','</tt>')
+			.'</span></p>');
 	$dest =~ s/\.(\d+)(\.\w+)$/$2/;
     }
     if ($foundbad) {
-	$request->print("<p><span class=\"LC_error\">".&mt('Invalid characters in requested name have been removed.')."</span></p>");
+        $request->print('<p><span class="LC_warning">'
+                       .&mt('Invalid characters in requested name have been removed.')
+                        .'</span></p>'
+        );
     }
     return $dest;
 }
@@ -416,7 +426,7 @@ sub CloseForm1 {
     my ($request,  $fn) = @_;
     $request->print('<p><input type="submit" value="'.&mt('Continue').'" /></p></form>');
     $request->print('<form action="'.&url($fn).
-		    '" method="POST"><p><input type="submit" value="'.&mt('Cancel').'" /></p></form>');
+		    '" method="post"><p><input type="submit" value="'.&mt('Cancel').'" /></p></form>');
 }
 
 
@@ -507,10 +517,10 @@ sub Rename1 {
 	    if (-d $fn) {
 		$newfilename=~/\.(\w+)$/;
 		if (&Apache::loncommon::fileembstyle($1) eq 'ssi') {
-		    $request->print('<br /><span classr="LC_warning">'.
-				    &mt('Cannot change MIME type of a directory').
+		    $request->print('<p><span class="LC_error">'.
+				    &mt('Cannot change MIME type of a directory.').
 				    '</span>'.
-				    '<br /><a href="'.&url($fn).'">'.&mt('Cancel').'</a>');
+				    '<br /><a href="'.&url($fn).'">'.&mt('Cancel').'</a></p>');
 		    return;
 		}
 		$newfilename=~s/\/[^\/]+\/([^\/]+)$/\/$1/;
@@ -526,27 +536,38 @@ sub Rename1 {
 		return;
 	    }
 	    unless (&obsolete_unpub($user,$domain,$fn)) {
-		$request->print('<h3>'.&mt('Cannot rename or move non-obsolete published file').'</h3>'.
-				'<br /><a href="'.&url($fn).'">'.&mt('Cancel').'</a>');
+                $request->print('<p><span class="LC_error">'
+                               .&mt('Cannot rename or move non-obsolete published file.')
+                               .'</span><br />'
+                               .'<a href="'.&url($fn).'">'.&mt('Cancel').'</a></p>'
+                );
 		return;
 	    }
 	    my $action;
 	    if ($style eq 'rename') {
-		$action=&mt('Rename');
+		$action='Rename';
 	    } else {
-		$action=&mt('Move');
+		$action='Move';
 	    }
-	    $request->print('<input type="hidden" name="newfilename" value="'.
-			    $newfilename.
-			    '" /><p>'.$action.' '.&display($fn).
-			    '</p><br />to '.&display($newfilename).'?</p>');
+            $request->print('<input type="hidden" name="newfilename" value="'
+                           .$newfilename.'" />'
+                           .'<p>'
+                           .&mt($action.' [_1] to [_2]?',
+                                &display($fn),
+                                &display($newfilename))
+                           .'</p>'
+        );
 	    &CloseForm1($request, $fn);
 	} else {
-	    $request->print('<p>'.&mt('No new filename specified.').'</p></form>');
+	    $request->print('<p class="LC_error">'.&mt('No new filename specified.').'</p></form>');
 	    return;
 	}
     } else {
-	$request->print('<p> '.&mt('No such file').': '.&display($fn).'</p></form>');
+        $request->print('<p class="LC_error">'
+                       .&mt('No such file: [_1]',
+                            &display($fn))
+                       .'</p></form>'
+        );
 	return;
     }
     
@@ -581,25 +602,41 @@ sub Delete1 {
 
     if( -e $fn) {
 	$request->print('<input type="hidden" name="newfilename" value="'.
-			$fn.'"/>');
+			$fn.'" />');
         if (-d $fn) {
             unless (&empty_directory($fn,'Delete1')) {
-                $request->print('<h3>'.&mt('Only empty directories may be deleted.').'</h3>'.
-                            'You must delete the contents of the directory first.<br />'.
-                            '<br /><a href="'.&url($fn).'">'.&mt('Cancel').'</a>');
+                $request->print('<p>'
+                               .'<span class="LC_error">'
+                               .&mt('Only empty directories may be deleted.')
+                               .'</span><br />'
+                               .&mt('You must delete the contents of the directory first.')
+                               .'</p>'
+                               .'<p><a href="'.&url($fn).'">'.&mt('Cancel').'</a></p>'
+                );
                 return;
             }
         } else { 
 	    unless (&obsolete_unpub($user,$domain,$fn)) {
-	        $request->print('<h3>'.&mt('Cannot delete non-obsolete published file').'</h3>'.
-			    '<br /><a href="'.&url($fn).'">'.&mt('Cancel').'</a>');
+                $request->print('<p><span class="LC_error">'
+                               .&mt('Cannot delete non-obsolete published file.')
+                               .'</span><br />'
+                               .'<a href="'.&url($fn).'">'.&mt('Cancel').'</a></p>'
+                );
 	        return;
 	    }
         }
-	$request->print('<p>'.&mt('Delete').' '.&display($fn).'?</p>');
+        $request->print('<p>'
+                       .&mt('Delete [_1]?',
+                            &display($fn))
+                       .'</p>'
+        );
 	&CloseForm1($request, $fn);
     } else {
-	$request->print('<p>'.&mt('No such file').': '.&display($fn).'</p></form>');
+        $request->print('<p class="LC_error">'
+                       .&mt('No such file: [_1]',
+                            &display($fn))
+                       .'</p></form>'
+        );
     }
 }
 
@@ -653,13 +690,23 @@ sub Copy1 {
 	    $request->print('<br /><a href="'.&url($fn).'">'.&mt('Cancel').'</a>');
 	    return;
 	}
-	$request->print('<input type="hidden" name="newfilename" value="'.
-			$newfilename.
-			'" /><p>'.&mt('Copy').' '.&display($fn).'<br />to '.
-			&display($newfilename).'?</p>');
+
+        $request->print(
+            '<input type="hidden" name="newfilename"'
+           .' value="'.$newfilename.'" />'
+           .'<p>'
+           .&mt('Copy [_1] to [_2]?',
+                &display($fn),
+                &display($newfilename))
+           .'</p>'
+        );
 	&CloseForm1($request, $fn);
     } else {
-	$request->print('<p>'.&mt('No such file').': '.&display($fn).'</p></form>');
+        $request->print('<p class="LC_error">'
+                       .&mt('No such file: [_1]',
+                            &display($fn))
+                       .'</p></form>'
+        );
     }
 }
 
@@ -711,13 +758,17 @@ sub NewDir1 {
 	$request->print('</form>');
     } else {
 	if ($mode eq 'testbank') {
-	    $request->print('<input type="hidden" name="callingmode" value="testbank">');
+	    $request->print('<input type="hidden" name="callingmode" value="testbank" />');
 	} elsif ($mode eq 'imsimport') {
-	    $request->print('<input type="hidden" name="callingmode" value="imsimport">');
+	    $request->print('<input type="hidden" name="callingmode" value="imsimport" />');
 	}
-	$request->print('<input type="hidden" name="newfilename" value="'.
-			$newfilename.'" /><p>'.&mt('Make new directory').' '.
-			&display($newfilename).'?</p>');
+        $request->print('<input type="hidden" name="newfilename" value="'
+                       .$newfilename.'" />'
+                       .'<p>'
+                       .&mt('Make new directory [_1]?',
+                            &display($newfilename))
+                       .'</p>'
+        );
 	&CloseForm1($request, $fn);
     }
 }
@@ -726,11 +777,19 @@ sub NewDir1 {
 sub Decompress1 {
     my ($request, $user, $domain, $fn) = @_;
     if( -e $fn) {
-   	$request->print('<input type="hidden" name="newfilename" value="'.$fn.'"/>');
-   	$request->print('<p>'.&mt('Decompress').' '.&display($fn).'?</p>');
+   	$request->print('<input type="hidden" name="newfilename" value="'.$fn.'" />');
+   	$request->print('<p>'
+                   .&mt('Decompress [_1]?',
+                        &display($fn))
+                   .'</p>'
+    );
    	&CloseForm1($request, $fn);
     } else {
-	$request->print('<p>'.&mt('No such file').': '.&display($fn).'</p></form>');
+        $request->print('<p class="LC_error">'
+                       .&mt('No such file: [_1]',
+                            &display($fn))
+                       .'</p></form>'
+        );
     }
 }
 
@@ -776,23 +835,10 @@ button which returns you to the driectory listing you came from
 
 sub NewFile1 {
     my ($request, $user, $domain, $fn, $newfilename) = @_;
+    return if (&filename_check($newfilename) ne 'ok');
 
     if ($env{'form.action'} =~ /new(.+)file/) {
 	my $extension=$1;
-
-        ##Informs User (name).(number).(extension) not allowed 
-	if($newfilename =~ /\.(\d+)\.(\w+)$/){
-	    $r->print('<span class="LC_error">'.$newfilename.
-		      ' - '.&mt('Bad Filename').'<br />('.&mt('name').').('.&mt('number').').('.&mt('extension').') '.
-		      ' '.&mt('Not Allowed').'</span>');
-	    return;
-	}
-	if($newfilename =~ /(\:\:\:|\&\&\&|\_\_\_)/){
-	    $r->print('<span class="LC_error">'.$newfilename.
-		      ' - '.&mt('Bad Filename').'<br />('.&mt('Must not include').' '.$1.') '.
-		      ' '.&mt('Not Allowed').'</span>');
-	    return;
-	}
 	if ($newfilename !~ /\Q.$extension\E$/) {
 	    if ($newfilename =~ m|/[^/.]*\.(?:[^/.]+)$|) {
 		#already has an extension strip it and add in expected one
@@ -806,14 +852,58 @@ sub NewFile1 {
     if ($type eq 'error') {
 	$request->print('</form>');
     } else {
-	
+        my $extension;
+
+        if ($newfilename =~ m{[^/.]+\.([^/.]+)$}) {
+            $extension = $1;
+        }
+
+        my @okexts = qw(xml html xhtml htm xhtm problem page sequence rights sty task library js css txt);
+
+        if (($extension eq '') || (!grep(/^\Q$extension\E/,@okexts))) {
+            my $validexts = '.'.join(', .',@okexts);
+            $request->print('<p class="LC_warning">'.
+                &mt('Invalid filename: ').&display($newfilename).'</p><p>'.
+                &mt('The name of the new file needs to end with an appropriate file extension to indicate the type of file to create.').'<br />'.
+                &mt('The following are valid extensions: [_1].',$validexts).
+                '</p></form><p>'.
+		'<form name="fileaction" action="/adm/cfile" method="post">'.
+                '<input type="hidden" name="qualifiedfilename" value="'.$fn.'" />'.
+		'<input type="hidden" name="action" value="newfile" />'.
+	        '<span class ="LC_nobreak">'.&mt('Enter a file name: ').'<input type="text" name="newfilename" value="Type Name Here" onfocus="if (this.value == '."'Type Name Here') this.value=''".'" />&nbsp;<input type="submit" value="Go" />'.
+                '</span></form></p>'.
+                '<p><form action="'.&url($fn).
+                '" method="post"><p><input type="submit" value="'.&mt('Cancel').'" /></form></p>');
+            return;
+        }
+
 	$request->print('<p>'.&mt('Make new file').' '.&display($newfilename).'?</p>');
 	$request->print('</form>');
+
 	$request->print('<form action="'.&url($newfilename).
-			'" method="POST"><p><input type="submit" value="'.&mt('Continue').'" /></p></form>');
+			'" method="post"><p><input type="submit" value="'.&mt('Continue').'" /></p></form>');
 	$request->print('<form action="'.&url($fn).
-			'" method="POST"><p><input type="submit" value="'.&mt('Cancel').'" /></p></form>');
+			'" method="post"><p><input type="submit" value="'.&mt('Cancel').'" /></p></form>');
     }
+    return;
+}
+
+sub filename_check {
+    my ($newfilename) = @_;
+    ##Informs User (name).(number).(extension) not allowed
+    if($newfilename =~ /\.(\d+)\.(\w+)$/){
+        $r->print('<span class="LC_error">'.$newfilename.
+                  ' - '.&mt('Bad Filename').'<br />('.&mt('name').').('.&mt('number').').('.&mt('extension').') '.
+                  ' '.&mt('Not Allowed').'</span>');
+        return;
+    }
+    if($newfilename =~ /(\:\:\:|\&\&\&|\_\_\_)/){
+        $r->print('<span class="LC_error">'.$newfilename.
+                  ' - '.&mt('Bad Filename').'<br />('.&mt('Must not include').' '.$1.') '.
+                  ' '.&mt('Not Allowed').'</span>');
+        return;
+    }
+    return 'ok'; 
 }
 
 =pod
@@ -868,7 +958,10 @@ sub phaseone {
 	if($newfilename) {
 	    &Copy1($r, $uname, $udom, $fn, $newfilename);
 	} else {
-	    $r->print('<p>'.&mt('No new filename specified.').'</p></form>');
+            $r->print('<p class="LC_error">'
+                     .&mt('No new filename specified.')
+                     .'</p></form>'
+            );
 	}
     } elsif ($env{'form.action'} eq 'newdir') {
 	my $mode = '';
@@ -890,7 +983,10 @@ sub phaseone {
 	if (($newfilename!~/\/$/) && ($newfilename!~/$empty$/)) {
 	    &NewFile1($r, $uname, $udom, $fn, $newfilename);
 	} else {
-	    $r->print('<p>'.&mt('No new filename specified.').'</p></form>');
+            $r->print('<p class="LC_error">'
+                     .&mt('No new filename specified.')
+                     .'</p></form>'
+            );
 	}
     }
 }
@@ -977,7 +1073,11 @@ sub Rename2 {
 	    unlink $tmp2;
 	}
     } else {
-	$request->print("<p> ".&mt('No such file').": ".&display($oldfile).'</p></form>');
+        $request->print('<p>'
+                       .&mt('No such file: [_1]',
+                            &display($oldfile))
+                       .'</p></form>'
+        );
 	return 0;
     }
     return 1;
@@ -1025,7 +1125,7 @@ sub Delete2 {
 		    return 0;
 		}
 	    } else {
-		$request->print('<p> '.&mt('No such file').'. </p></form>');
+        	$request->print('<p class="LC_error">'.&mt('No such file').'</p></form>');
 		return 0;
 	    }
 	}
@@ -1036,7 +1136,7 @@ sub Delete2 {
 		return 0;
 	    }
 	} else {
-	    $request->print('<p> '.&mt('No such file').'. </p></form>');
+            $request->print('<p class="LC_error">'.&mt('No such file').'</p></form>');
 	    return 0;
 	}
     }
@@ -1095,7 +1195,7 @@ sub Copy2 {
 	    return 1;
 	}
     } else {
-	$request->print('<p> '.&mt('No such file').' </p>');
+        $request->print('<p class="LC_error">'.&mt('No such file').'</p>');
 	return 0;
     }
     return 1;
@@ -1249,7 +1349,7 @@ sub phasetwo {
 	    }
 	    $dest = $env{'form.newfilename'};
      	} else {
-	    $r->print('<p>'.&mt('No New filename specified').'</p></form>');
+            $r->print('<p class="LC_error">'.&mt('No New filename specified').'</p></form>');
 	    return;
 	}
 	
@@ -1353,12 +1453,14 @@ function writeDone() {
     $r->print(&Apache::loncommon::start_page('Construction Space File Operation',
 					     $js,
 					     {'add_entries' => \%loaditem,}));
-  
+
     $r->print('<h3>'.&mt('Location').': '.&display($fn).'</h3>');
   
     if (($uname ne $env{'user.name'}) || ($udom ne $env{'user.domain'})) {
-	$r->print('<h3><span class="LC_error">'.&mt('Co-Author').': '.$uname.' at '.$udom.
-		  '</span></h3>');
+        $r->print('<p class="LC_warning">'
+                 .&mt('Co-Author [_1]',$uname.':'.$udom)
+                 .'</p>'
+        );
     }
 
 
@@ -1387,8 +1489,11 @@ function writeDone() {
 	     $env{'form.action'} eq 'Select Action' ) {
 	$r->print('<h3>'.&mt('New Resource').'</h3>');
     } else {
-	$r->print('<p>'.&mt('Unknown Action').' '.$env{'form.action'}.' </p>'.
-		  &Apache::loncommon::end_page());
+        $r->print('<p class="LC_error">'
+                 .&mt('Unknown Action').' '.$env{'form.action'}
+                 .'</p>'
+                 .&Apache::loncommon::end_page()
+        );
 	return OK;  
     }
     if ($env{'form.phase'} eq 'two') {
