@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Publication Handler
 #
-# $Id: lonpublisher.pm,v 1.249 2008/12/07 23:49:40 www Exp $
+# $Id: lonpublisher.pm,v 1.258.2.4 2010/01/27 03:44:48 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -384,11 +384,11 @@ sub selectbox {
     my $selout="\n".&Apache::lonhtmlcommon::row_title($title)
               .'<select name="'.$name.'">';
     foreach (@idlist) {
-        $selout.='<option value=\''.$_.'\'';
+        $selout.='<option value="'.$_.'"';
         if ($_ eq $value) {
-	    $selout.=' selected>'.&{$functionref}($_).'</option>';
-	}
-        else {$selout.='>'.&{$functionref}($_).'</option>';}
+	    $selout.=' selected="selected"';
+        }
+        $selout.='>'.&{$functionref}($_).'</option>';
     }
     $selout.='</select>'.&Apache::lonhtmlcommon::row_closure();
     return $selout;
@@ -1062,7 +1062,7 @@ sub publish {
      my %oldparmstores=();
      
     unless ($batch) {
-     $scrout.='<h3>'.&mt('Metadata Information').' ' .
+     $scrout.='<h3>'.&mt('Metadata').' ' .
        &Apache::loncommon::help_open_topic("Metadata_Description")
        . '</h3>';
     }
@@ -1166,15 +1166,16 @@ sub publish {
 	}
     }
     if ($chparms) {
-	$scrout.='<p><b>'.&mt('Obsolete parameters or saved values').':</b> '.
-	    $chparms.'</p><h1><span class="LC_warning">'.&mt('Warning!').
-	    '</span></h1><p><span class="LC_warning">'.
-	    &mt('If this resource is in active use, student performance data from the previous version may become inaccessible.').'</span></p><hr />';
+        $scrout.='<p><b>'.&mt('Obsolete parameters or saved values').':</b> '
+	        .$chparms.'</p>'
+                .'<p class="LC_warning"><b>'.&mt('Warning!').'</b><br />'
+                .&mt('If this resource is in active use, student performance data from the previous version may become inaccessible.')
+                .'</p><hr />';
     }
     if ($metadatafields{'copyright'} eq 'priv') {
-        $scrout.='</p><h1><span class="LC_warning">'.&mt('Warning!').
-            '</span></h1><p><span class="LC_warning">'.
-            &mt('Copyright/distribution option "Private" is no longer supported. Select another option from below. Consider "Custom Rights" for maximum control over the usage of your resource.').'</span></p><hr />';
+        $scrout.='<p class="LC_warning"><b>'.&mt('Warning!').'</b><br />'
+                .&mt('Copyright/distribution option "Private" is no longer supported. Select another option from below. Consider "Custom Rights" for maximum control over the usage of your resource.')
+                .'</p><hr />';
     }
 
 # ------------------------------------------------------- Now have all metadata
@@ -1282,11 +1283,11 @@ END
         $keywordout.='<label><input type="checkbox" name="keywords" value="'.$word.'"';
         if ($metadatafields{'keywords'}) {
             if ($metadatafields{'keywords'}=~/\Q$word\E/) {
-                $keywordout.=' checked="on"';
+                $keywordout.=' checked="checked"';
                 $env{'form.keywords'}.=$word.',';
             }
         } elsif (&Apache::loncommon::keyword($word)) {
-            $keywordout.=' checked="on"';
+            $keywordout.=' checked="checked"';
             $env{'form.keywords'}.=$word.',';
         }
         $keywordout.=' />'.$word.'</label></td>';
@@ -1401,9 +1402,9 @@ END
 				 (&Apache::loncommon::source_copyrightids));
 #	$intr_scrout.=&text_with_browse_field('Source Custom Distribution File','sourcerights',$metadatafields{'sourcerights'},'rights');
 	my $uctitle=&mt('Obsolete');
-        my $obsolete_checked=($metadatafields{'obsolete'})?' checked="1" ':'';
+        my $obsolete_checked=($metadatafields{'obsolete'})?' checked="checked"':'';
         $intr_scrout.="\n".&Apache::lonhtmlcommon::row_title($uctitle)
-                     .'<input type="checkbox" name="obsolete" '.$obsolete_checked.'/ >'
+                     .'<input type="checkbox" name="obsolete"'.$obsolete_checked.' />'
                      .&Apache::lonhtmlcommon::row_closure(1);
         $intr_scrout.=&text_with_browse_field('Suggested Replacement for Obsolete File',
 				    'obsoletereplacement',
@@ -1504,7 +1505,7 @@ sub phasetwo {
 	    return 0;
 	}
 	if ($target=~/\.(\d+)\.(\w+)$/) {
-	    $r->print('<span class="LC_error">'.&mt('Cannot publish versioned resource, FAIL').'</span>');
+	    $r->print('<span class="LC_error">'.&mt('Filename of resource contains internal version number. Cannot publish such resources, FAIL').'</span>');
 	    return 0;
 	}
     }
@@ -1640,7 +1641,8 @@ sub phasetwo {
         my $srcf=$2;
         my $srct=$3;
         my $srcd=$1;
-        unless ($srcd=~/^\/home\/httpd\/html\/res/) {
+        my $docroot = $Apache::lonnet::perlvar{'lonDocRoot'};
+        unless ($srcd=~/^\Q$docroot\E\/res/) {
             print $logfile "\nPANIC: Target dir is ".$srcd;
             $r->print(
 	 "<span class=\"LC_error\">".&mt('Invalid target directory, FAIL')."</span>");
@@ -1652,25 +1654,24 @@ sub phasetwo {
                 unlink($srcd.'/'.$filename);
                 unlink($srcd.'/'.$filename.'.meta');
             } else {
-                if ($filename=~/\Q$srcf\E\.(\d+)\.\Q$srct\E$/) {
+                if ($filename=~/^\Q$srcf\E\.(\d+)\.\Q$srct\E$/) {
                     $maxversion=($1>$maxversion)?$1:$maxversion;
                 }
             }
         }
         closedir(DIR);
         $maxversion++;
-        $r->print('<p>Creating old version '.$maxversion.'</p>');
+        $r->print('<p>'.&mt('Creating old version [_1]',$maxversion).'</p>');
         print $logfile "\nCreating old version ".$maxversion."\n";
         
         my $copyfile=$srcd.'/'.$srcf.'.'.$maxversion.'.'.$srct;
         
         if (copy($target,$copyfile)) {
 	    print $logfile "Copied old target to ".$copyfile."\n";
-            $r->print('<p>'.&mt('Copied old target file').'</p>');
+            $r->print(&Apache::lonhtmlcommon::confirm_success(&mt('Copied old target file')));
         } else {
 	    print $logfile "Unable to write ".$copyfile.':'.$!."\n";
-            $r->print("<span class=\"LC_error\">".&mt('Failed to copy old target').
-		", $!, ".&mt('FAIL')."</span>");
+            $r->print(&Apache::lonhtmlcommon::confirm_success(&mt('Failed to copy old target').", $!",1));
 	    return 0;
         }
         
@@ -1680,13 +1681,13 @@ sub phasetwo {
         
         if (copy($target.'.meta',$copyfile)) {
 	    print $logfile "Copied old target metadata to ".$copyfile."\n";
-            $r->print('<p>'.&mt('Copied old metadata').'</p>')
+            $r->print(&Apache::lonhtmlcommon::confirm_success(&mt('Copied old metadata')));
         } else {
 	    print $logfile "Unable to write metadata ".$copyfile.':'.$!."\n";
             if (-e $target.'.meta') {
-                $r->print( 
-                    "<span class=\"LC_error\">".
-&mt('Failed to write old metadata copy').", $!, ".&mt('FAIL')."</span>");
+                $r->print(&Apache::lonhtmlcommon::confirm_success(
+                           &mt('Failed to write old metadata copy').", $!",1));
+
 		return 0;
 	    }
         }
@@ -1708,32 +1709,38 @@ sub phasetwo {
         $path.="/$parts[$count]";
         if ((-e $path)!=1) {
             print $logfile "\nCreating directory ".$path;
-            $r->print('<p>'.&mt('Created directory').' '.$parts[$count].'</p>');
             mkdir($path,0777);
+            $r->print('<p>'
+                     .&mt('Created directory [_1]'
+                         ,'<span class="LC_filename">'.$parts[$count].'</span>')
+                     .'</p>'
+            );
         }
     }
     
     if (copy($source,$copyfile)) {
         print $logfile "\nCopied original source to ".$copyfile."\n";
-        $r->print('<p>'.&mt('Copied source file').'</p>');
+        $r->print(&Apache::lonhtmlcommon::confirm_success(&mt('Copied source file')));
     } else {
         print $logfile "\nUnable to write ".$copyfile.':'.$!."\n";
-        $r->print("<span class=\"LC_error\">".
-	    &mt('Failed to copy source').", $!, ".&mt('FAIL')."</span>");
+        $r->print(&Apache::lonhtmlcommon::confirm_success(
+	    &mt('Failed to copy source').", $!",1));
 	return 0;
     }
-    
+
+# ---------------------------------------------- Delete local tmp-preview files
+    unlink($copyfile.'.tmp');
 # --------------------------------------------------------------- Copy Metadata
 
     $copyfile=$copyfile.'.meta';
     
     if (copy($source.'.meta',$copyfile)) {
         print $logfile "\nCopied original metadata to ".$copyfile."\n";
-        $r->print('<p>'.&mt('Copied metadata').'</p>');
+        $r->print(&Apache::lonhtmlcommon::confirm_success(&mt('Copied metadata')));
     } else {
         print $logfile "\nUnable to write metadata ".$copyfile.':'.$!."\n";
-        $r->print(
-            "<span class=\"LC_error\">".&mt('Failed to write metadata copy').", $!, ".&mt('FAIL')."</span>");
+        $r->print(&Apache::lonhtmlcommon::confirm_success(
+                  &mt('Failed to write metadata copy').", $!",1));
 	return 0;
     }
     $r->rflush;
@@ -1741,7 +1748,8 @@ sub phasetwo {
 # ------------------------------------------------------------- Trigger updates
     push(@{$modified_urls},[$target,$source]);
     unless ($registered_cleanup) {
-	$r->register_cleanup(\&notify);
+        my $handlers = $r->get_handlers('PerlCleanupHandler');
+        $r->set_handlers('PerlCleanupHandler' => [\&notify,@{$handlers}]);
 	$registered_cleanup=1;
     }
 
@@ -1752,16 +1760,18 @@ sub phasetwo {
     &Apache::lonnet::devalidate_cache_new('meta',
 			 &Apache::lonnet::declutter($thisdistarget));
 
+# ------------------------------------------------------------- Everything done
+    $logfile->close();
+    $r->print('<p class="LC_success">'.&mt('Done').'</p>');
+
 # ------------------------------------------------ Provide link to new resource
     unless ($batch) {
-        
         my $thissrc=$source;
         $thissrc=~s{^/home/($match_username)/public_html}{/priv/$1};
         
         my $thissrcdir=$thissrc;
         $thissrcdir=~s/\/[^\/]+$/\//;
-        
-        
+ 
         $r->print(
            '<hr /><a href="'.$thisdistarget.'"><font size="+2">'.
            &mt('View Published Version').'</font></a>'.
@@ -1771,8 +1781,6 @@ sub phasetwo {
                    '"><font size="+2">'.
 		  &mt('Back to Source Directory').'</font></a></p>');
     }
-    $logfile->close();
-    $r->print('<p><font color="green">'.&mt('Done').'</font></p>');
     return 1;
 }
 
@@ -1839,7 +1847,11 @@ sub batchpublish {
 
     my $thisembstyle=&Apache::loncommon::fileembstyle($thistype);
      
-    $r->print('<h2>'.&mt('Publishing').' <tt>'.$thisdisfn.'</tt></h2>');
+    $r->print('<h2>'
+             .&mt('Publishing [_1]'
+                 ,'<span class="LC_filename">'.$thisdisfn.'</span>')
+             .'</h2>'
+    );
 
 # phase one takes
 #  my ($source,$target,$style,$batch)=@_;
@@ -1866,22 +1878,36 @@ sub publishdirectory {
     my $resdir=
 	$Apache::lonnet::perlvar{'lonDocRoot'}.'/res/'.$cudom.'/'.$cuname.'/'.
 	$thisdisfn;
-    $r->print('<h1>'.&mt('Directory').' <tt>'.$thisdisfn.'</tt></h1>'.
-	      &mt('Target').': <tt>'.$resdir.'</tt><br />');
+    $r->print(&Apache::lonhtmlcommon::start_pick_box()
+             .&Apache::lonhtmlcommon::row_title(&mt('Directory'))
+            .'<span class="LC_filename">'.$thisdisfn.'</span>'
+            .&Apache::lonhtmlcommon::row_closure()
+            .&Apache::lonhtmlcommon::row_title(&mt('Target'))
+            .'<span class="LC_filename">'.$resdir.'</span>'
+    );
 
     my $dirptr=16384;		# Mask indicating a directory in stat.cmode.
     unless ($env{'form.phase'} eq 'two') {
 # ask user what they want
+        $r->print(&Apache::lonhtmlcommon::row_closure()
+                 .&Apache::lonhtmlcommon::row_title(&mt('Options'))
+        );
         $r->print('<form name="pubdirpref" method="post">'.
 		  &hiddenfield('phase','two').
 		  &hiddenfield('filename',$env{'form.filename'}).
 		  &checkbox('pubrec','include subdirectories').
 		  &checkbox('forcerepub','force republication of previously published files').
                   &checkbox('obsolete','make file(s) obsolete').
-		  &checkbox('forceoverride','force directory level catalog information over existing').
+		  &checkbox('forceoverride','force directory level metadata over existing').
 		  '<br /><input type="submit" value="'.&mt('Publish Directory').'" /></form>');
+        $r->print(&Apache::lonhtmlcommon::row_closure(1)
+                 .&Apache::lonhtmlcommon::end_pick_box()
+        );
         $lock=0;
     } else {
+        $r->print(&Apache::lonhtmlcommon::row_closure(1)
+                 .&Apache::lonhtmlcommon::end_pick_box()
+        );
         unless ($lock) { $lock=&Apache::lonnet::set_lock(&mt('Publishing [_1]',$fn)); }
 # actually publish things
 	opendir(DIR,$fn);
@@ -1949,7 +1975,7 @@ sub defaultmetapublish {
     &Apache::loncommon::content_type($r,'text/html');
     $r->send_http_header;
 
-    $r->print(&Apache::loncommon::start_page('Catalog Information Publication'));
+    $r->print(&Apache::loncommon::start_page('Metadata Publication'));
 
 # ---------------------------------------------------------------- Write Source
     my $copyfile=$target;
@@ -1961,8 +1987,12 @@ sub defaultmetapublish {
     for ($count=5;$count<$#parts;$count++) {
         $path.="/$parts[$count]";
         if ((-e $path)!=1) {
-            $r->print('<p>'.&mt('Created directory').' '.$parts[$count].'</p>');
             mkdir($path,0777);
+            $r->print('<p>'
+                     .&mt('Created directory [_1]'
+                         ,'<span class="LC_filename">'.$parts[$count].'</span>')
+                     .'</p>'
+            );
         }
     }
     
@@ -1984,7 +2014,7 @@ sub defaultmetapublish {
 # ------------------------------------------------------------------- Link back
     my $link=$fn;
     $link=~s/^\/home\/$cuname\/public_html\//\/priv\/$cuname\//;
-    $r->print("<a href='$link'>".&mt('Back to Catalog Information').'</a>');
+    $r->print("<a href='$link'>".&mt('Back to Metadata').'</a>');
     $r->print(&Apache::loncommon::end_page());
     return OK;
 }
@@ -2169,7 +2199,11 @@ sub handler {
 	my $thisembstyle=&Apache::loncommon::fileembstyle($thistype);
         if ($thistype eq 'page') {  $thisembstyle = 'rat'; }
 
-	$r->print('<h2>'.&mt('Publishing [_1]','<tt>'.$thisdisfn.'</tt>').'</h2>');
+        $r->print('<h2>'
+                 .&mt('Publishing [_1]'
+                     ,'<span class="LC_filename">'.$thisdisfn.'</span>')
+                 .'</h2>'
+        );
 
         $r->print('<h3>'.&mt('Resource Details').'</h3>');
 
@@ -2198,7 +2232,7 @@ ENDCAPTION
             $r->print(&Apache::lonhtmlcommon::row_closure()
                      .&Apache::lonhtmlcommon::row_title(&mt('Co-Author'))
                      .'<span class="LC_warning">'
-		     .&mt('[_1] at [_2]',$cuname,$cudom)
+		     .&Apache::loncommon::plainname($cuname,$cudom) .' ('.$cuname.':'.$cudom.')'
                      .'</span>'
                      );
 	}
