@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to retrieve an old version of a file
 #
-# $Id: lonretrieve.pm,v 1.34.2.2 2008/12/21 04:38:43 raeburn Exp $
+# $Id: lonretrieve.pm,v 1.41.2.1 2009/08/13 05:07:55 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -28,6 +28,71 @@
 #
 ###
 
+=head1 NAME
+
+Apache::lonretrieve - retrieves an old version of a file
+
+=head1 SYNOPSIS
+
+Invoked by /etc/httpd/conf/srm.conf:
+
+ <Location /adm/retrieve>
+ PerlAccessHandler       Apache::lonacc
+ SetHandler perl-script
+ PerlHandler Apache::lonretrieve
+ ErrorDocument     403 /adm/login
+ ErrorDocument     404 /adm/notfound.html
+ ErrorDocument     406 /adm/unauthorized.html
+ ErrorDocument	  500 /adm/errorhandler
+ </Location>
+
+=head1 INTRODUCTION
+
+This module retrieves an old published version of a file.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 HANDLER SUBROUTINE
+
+This routine is called by Apache and mod_perl.
+
+=over 4
+
+=item *
+
+Get query string for limited number of parameters
+
+=item *
+
+Start page output
+
+=item *
+
+print phase relevant output
+
+=item *
+
+(phase one is to select version; phase two retrieves version)
+
+=back
+
+=head1 OTHER SUBROUTINES
+
+=over 4
+
+=item *
+
+phaseone() : Interface for selecting previous version.
+
+=item *
+
+phasetwo() : Interface for presenting specified version.
+
+=back
+
+=cut
+
 package Apache::lonretrieve;
 
 use strict;
@@ -55,7 +120,7 @@ sub phaseone {
     my ($main,$suffix,$is_meta) = &get_file_info($fn);
     
     if (-e $resfn) {  
-	$r->print('<form action="/adm/retrieve" method="POST">'.
+	$r->print('<form action="/adm/retrieve" method="post">'.
 		  '<input type="hidden" name="filename" value="/~'.$uname.$fn.'" />'.
 		  '<input type="hidden" name="phase" value="two" />'.
 		  &Apache::loncommon::start_data_table().
@@ -87,11 +152,11 @@ sub phaseone {
 		my $rmtime=&Apache::lonnet::metadata($resdir.'/'.$filename,'lastrevisiondate');
 		$r->print(&Apache::loncommon::start_data_table_row().
 			  '<td><input type="radio" name="version" value="'.
-			  $version.'" /></td><td>'.&mt('Previously published version').' '.$version.'</td><td>'.
-			  localtime($rmtime).'</td>');
+			  $version.'" /></td><td>'.&mt('Previously published version').' '.$version.'</td>'.
+              '<td>'.&Apache::lonlocal::locallocaltime($rmtime).'</td>');
 		
 		if (!$is_meta) {
-		    $r->print('<td><a href="'.$urldir.$filename.'.meta" target=cat>'.
+		    $r->print('<td><a href="'.$urldir.$filename.'.meta" target="cat">'.
 			      &mt('Metadata Version').' '.$version.'</a></td>');
 		}
 		if ($is_meta
@@ -110,10 +175,11 @@ sub phaseone {
 	my $rmtime=&Apache::lonnet::metadata($resfn,'lastrevisiondate');
 	$r->print(&Apache::loncommon::start_data_table_row().
 		  '<td><input type="radio" name="version" value="new" /></td>'.
-		  '<td><b>'.&mt('Currently published version').'</b></td><td>'.localtime($rmtime).
-		  '</td>');
+		  '<td><b>'.&mt('Currently published version').'</b></td>'.
+          '<td>'.&Apache::lonlocal::locallocaltime($rmtime).'</td>'
+    );
 	if (!$is_meta) {
-	    $r->print('<td><a href="'.$urldir.$main.'.'.$suffix.'.meta" target=cat>'.
+	    $r->print('<td><a href="'.$urldir.$main.'.'.$suffix.'.meta" target="cat">'.
 		      &mt('Metadata current version').'</a></td>');           
 	}
 	if ($is_meta 
@@ -130,15 +196,17 @@ sub phaseone {
 		  &mt('Retrieval of an old version will overwrite the file currently in construction space.').'</span></p>');
 	if (!$is_meta) {
 	    $r->print('<p>'.'<span class="LC_warning">'.
-		      &mt('This will only retrieve the resource. If you want to retrieve the metadata you will need to do that separately.').
+		      &mt('This will only retrieve the resource. If you want to retrieve the metadata, you will need to do that separately.').
 		      '</span></p>');
 	}
-	$r->print('<input type="submit" value="'.&mt('Retrieve version').'" /></form>');
+	$r->print('<input type="submit" value="'.&mt('Retrieve selected Version').'" /></form>');
     } else {
 	$r->print('<p class="LC_warning">'.&mt('No previous versions published.').'</p>');
     }
-    $r->print('<p><a href="/priv/'.$uname.$fn.'">'.&mt('Back to [_1]','<span class="LC_filename">'.$fn.'</span>')
-	      .'</a></p>'); 
+
+   $r->print('<p><a href="/priv/'.$uname.$fn.'">'
+            .&mt('Back to [_1]','<span class="LC_filename">'.$fn.'</span>')
+            .'</a></p>'); 
 }
 
 # ---------------------------------- Interface for presenting specified version
@@ -166,9 +234,9 @@ sub phasetwo {
 	if ($is_meta) { $logname =~ s/\.meta$//; }
 	$logname = $ctarget.'.log';
         unless ($logfile=Apache::File->new('>>'.$logname)) {
-	  $r->print('<span class="LC_error">'
-                    .&mt('No write permission to user directory, FAIL')
-                    .'</span>');
+          $r->print('<span class="LC_error">'
+                   .&mt('No write permission to user directory, FAIL')
+                   .'</span>');
         }
         print $logfile 
 "\n\n================= Retrieve ".localtime()." ================\n".
@@ -176,20 +244,20 @@ sub phasetwo {
         $r->print('<p>'.&mt('Copying file').': ');
 	if (copy($csource,$ctarget)) {
 	    $r->print('<span class="LC_success">'
-                      .&mt('ok')
-                      .'</span>');
+                     .&mt('ok')
+                     .'</span>');
             print $logfile "Copied sucessfully.\n\n";
         } else {
             my $error=$!;
 	    $r->print('<span class="LC_error">'
-                      .&mt('Copy failed: [_1]',$error)
-                      .'</span>');
+                     .&mt('Copy failed: [_1]',$error)
+                     .'</span>');
             print $logfile "Copy failed: $error\n\n";
         }
         $r->print('</p>'
-                  .'<p><a href="/priv/'.$uname.$fn.'">'
-                  .&mt('Back to [_1]',$fn)
-                  .'</a></p>'); 
+                 .'<p><a href="/priv/'.$uname.$fn.'">'
+                 .&mt('Back to Resource')
+                 .'</a></p>');
     } else {
        $r->print('<p class="LC_info">'.&mt('Please pick a version to retrieve:').'</p>');
        &phaseone($r,$fn,$uname,$udom);
@@ -256,17 +324,17 @@ sub handler {
   $r->send_http_header;
 
   $r->print(&Apache::loncommon::start_page('Retrieve Published Resources'));
-
-  
-  $r->print('<h1>'
-            .&mt('Retrieve previous versions of [_1]'
-                    ,'<span class="LC_filename">'.$fn.'</span>')
-            .'</h1>');
+  $r->print('<p>'
+           .&mt('Retrieve previous versions of [_1]'
+                   ,'<span class="LC_filename">'.$fn.'</span>')
+           .'</p>');
   
   if (($uname ne $env{'user.name'}) || ($udom ne $env{'user.domain'})) {
-          $r->print('<h3><span class="LC_diff_coauthor">'.&mt('Co-Author').': '.$uname.
-		    &mt(' at ').$udom.
-               '</span></h3>');
+          $r->print('<p><span class="LC_warning">'
+                   .&mt('Co-Author [_1]'
+                       ,&Apache::loncommon::plainname($uname,$udom)
+                       .' ('.$uname.':'.$udom.')')
+                   .'</span></p>');
   }
 
 
@@ -283,67 +351,4 @@ sub handler {
 1;
 __END__
 
-=head1 NAME
 
-Apache::lonretrieve - retrieves an old version of a file
-
-=head1 SYNOPSIS
-
-Invoked by /etc/httpd/conf/srm.conf:
-
- <Location /adm/retrieve>
- PerlAccessHandler       Apache::lonacc
- SetHandler perl-script
- PerlHandler Apache::lonretrieve
- ErrorDocument     403 /adm/login
- ErrorDocument     404 /adm/notfound.html
- ErrorDocument     406 /adm/unauthorized.html
- ErrorDocument	  500 /adm/errorhandler
- </Location>
-
-=head1 INTRODUCTION
-
-This module retrieves an old published version of a file.
-
-This is part of the LearningOnline Network with CAPA project
-described at http://www.lon-capa.org.
-
-=head1 HANDLER SUBROUTINE
-
-This routine is called by Apache and mod_perl.
-
-=over 4
-
-=item *
-
-Get query string for limited number of parameters
-
-=item *
-
-Start page output
-
-=item *
-
-print phase relevant output
-
-=item *
-
-(phase one is to select version; phase two retrieves version)
-
-=back
-
-=head1 OTHER SUBROUTINES
-
-=over 4
-
-=item *
-
-phaseone() : Interface for selecting previous version.
-
-=item *
-
-phasetwo() : Interface for presenting specified version.
-
-=back
-
-=cut
