@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Edit Handler for RAT Maps
 #
-# $Id: lonratedt.pm,v 1.90 2008/10/13 11:54:54 bisitz Exp $
+# $Id: lonratedt.pm,v 1.94.2.1 2009/08/14 02:16:31 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -29,141 +29,6 @@
 
 package Apache::lonratedt;
 
-=pod
-
-=head1 NAME
-
-Apache::lonratedt: simple resource assembly tool
-
-=head1 SYNOPSIS
-
-lonratedt provides the routines and the handler for the Advanced
-    Resource Assembly Tool (RAT), and ties the various pieces together
-    with Javascript.
-
-=head1 OVERVIEW
-
-=head2 Map Representation
-
-=begin latex
-
-%
-\begin{figure}
-\begin{center}\includegraphics[%
-  width=0.55\paperwidth,bb = 0 0 200 100, draft, type=eps]{Map_Example}\end{center}
-
-
-\caption{\label{Map_In_Advanced_Editor}Example of a Map in the Advanced Editor}
-\end{figure}
-%
-\begin{figure}
-\begin{lyxcode}
-<map>
-
-~~<resource~id=\char`\"{}1\char`\"{}
-
-~~~~src=\char`\"{}/res/msu/korte/phy231welcome.html\char`\"{}
-
-~~~~type=\char`\"{}start\char`\"{}
-
-~~~~title=\char`\"{}Start\char`\"{}>
-
-~~~~</resource>
-
-~~<resource~id=\char`\"{}2\char`\"{}
-
-~~~~src=\char`\"{}\char`\"{}~type=\char`\"{}finish\char`\"{}
-
-~~~~title=\char`\"{}Finish\char`\"{}>
-
-~~~~</resource>
-
-~~<resource~id=\char`\"{}6\char`\"{}
-
-~~~~src=\char`\"{}/res/msu/korte/tests/units.problem\char`\"{}
-
-~~~~type=\char`\"{}mandatory\char`\"{}
-
-~~~~title=\char`\"{}Physical~Units~Test\char`\"{}>
-
-~~~~</resource>
-
-~~<resource~id=\char`\"{}9\char`\"{}
-
-~~~~src=\char`\"{}/res/msu/korte/chapters/onedim.sequence\char`\"{}
-
-~~~~title=\char`\"{}Motion~in~One~Dimension\char`\"{}>
-
-~~~~</resource>
-
-~~<resource~id=\char`\"{}11\char`\"{}
-
-~~~~src=\char`\"{}/res/msu/bauer/bridges/units.sequence\char`\"{}
-
-~~~~title=\char`\"{}Physical~Units~Refresher\char`\"{}>
-
-~~~~</resource>
-
-~~<condition~id=\char`\"{}19\char`\"{}
-
-~~~~type=\char`\"{}stop\char`\"{}
-
-~~~~value=\char`\"{}user.assessments{[}this./res/msu/korte/tests/units.problem{]}.status=solved\char`\"{}>
-
-~~~~</condition>
-
-~~<link~from=\char`\"{}1\char`\"{}~to=\char`\"{}6\char`\"{}></link>
-
-~~<link~from=\char`\"{}6\char`\"{}~to=\char`\"{}9\char`\"{}~condition=\char`\"{}19\char`\"{}></link>
-
-~~<link~from=\char`\"{}6\char`\"{}~to=\char`\"{}11\char`\"{}></link>
-
-~~<link~from=\char`\"{}11\char`\"{}~to=\char`\"{}6\char`\"{}></link>
-
-~~</map>
-\end{lyxcode}
-
-\caption{\label{XML}XML for Map in Figure \ref{Map_In_Advanced_Editor}}
-\end{figure}
-
-=end latex
-
-Fig. "XML for Map in Figure" shows the XML representation of the
-resource map shown in Fig. "Example of a Map in the Advanced Editor",
-which is the format in which maps are stored. In the figure, however,
-additional graphical map layout information generated by the Advanced
-Resource Assembly Tool is not displayed. This graphical information is
-optional to re-generate the same graphical layout when the map is
-brought up again in the Resource Assembly Tool, and is not needed for
-any other system functionality.
-
-Maps can be generated by tools other than the Resource Assembly
-Tool. In particular, an author might have some other representation of
-a course sequence, which can be converted into a map using scripts. If
-this map then were to be brought up in the Resource Assembly Tool, the
-Tool would automatically generate a graphical layout for it. Each
-entry of the map (resources, conditions and links) is stored in a
-separate tag.
-
-Resources and conditionsX<conditions> have to have unique ID
-numbers. These numbers are automatically generated by the Resource
-Assembly Tool when the entry is first created, or added to the entries
-when a map generated outside the Resource Assembly Tool is first
-retrieved. They can also be assigned by custom scripts or added in by
-hand.
-
-In the XML example, entry 1 is the start resource of the map. When
-this map is accessed, the source (src) URL of this tag will be the
-first resource rendered. Entry 2 is the finish resource of this
-map. This resource will be the last resource in the sequence of
-resources. Entry 6 is a problem resource with the given URL and title,
-as well as the priority "mandatory". Entry 19 is a condition, which is
-used by the link between entries 6, the problem, and 9, a
-sequence. I<The final syntax for conditions has not yet been
-determined.>
-
-=cut
-
 use strict;
 use Apache::Constants qw(:common);
 use Apache::lonnet;
@@ -210,19 +75,19 @@ ENDDOCUMENT
 
 sub buttons {
     my $adv=shift;
-    my $output='<form method=post>';     
+    my $output='<form method="post">';     
     if ($adv==1) {
-	$output.='<input type=submit name=forceadv value="'.&mt('Edit').'">'.
-	    &Apache::loncommon::help_open_topic('Sequence_Advanced_Editor_Creation');;
+	$output.='<input type="submit" name="forceadv" value="'.&mt('Edit').'" />'.
+	    &Apache::loncommon::help_open_topic('Sequence_Advanced_Editor_Creation');
     } else {
         unless ($adv==2) {
-           $output.='<input type=submit name=forcesmp value="'.&mt('Simple Edit').'">'.
+           $output.='<input type="submit" name="forcesmp" value="'.&mt('Simple Edit').'" />'.
 	    &Apache::loncommon::help_open_topic('Sequence_Simple_Editor_Creation');
         }
-	$output.='<input type=submit name=forceadv value="'.&mt('Advanced Edit').'">'.
+	$output.='<input type="submit" name="forceadv" value="'.&mt('Advanced Edit').'" />'.
 	    &Apache::loncommon::help_open_topic('Sequence_Advanced_Editor_Creation');
     }
-    return $output.'</form><hr>';
+    return $output.'</form><hr />';
 }
 
 # ----------------------------------------------------------------- Edit script
@@ -371,7 +236,7 @@ sub smpedt {
    }
    if (-e $tmpfn) {
       $targetmsg=
-        '<b><font color="red">'.&mt('You are working with an unsaved version of your map.').'</font></b><br>';
+        '<span class="LC_warning">'.&mt('You are working with an unsaved version of your map.').'</span><br />';
       my ($errtext,$fatal)=&LONCAPA::map::mapread($tmpfn,'');
    }
 # ---------------------------------------------------------- Process form input
@@ -684,72 +549,72 @@ ENDJS
     $r->print(<<ENDSMPHEAD);
 $start_page
 $buttons
-<font color=red>$errtext</font>
-<form name=simpleedit method=post>
-<input type=hidden name=forcesmp value=1>
-<input type=hidden name=renameres value=0>
-<input type=hidden name=renametitle value=''>
-<input type=hidden name=renameidx value=0>
+<span class="LC_error">$errtext</span>
+<form name="simpleedit" method="post">
+<input type="hidden" name="forcesmp" value="1" />
+<input type="hidden" name="renameres" value="0" />
+<input type="hidden" name="renametitle" value="" />
+<input type="hidden" name="renameidx" value="0" />
 <table>
     <tr><th width="40%">$lt{'ta'}</th>
 <th>&nbsp;</th>
 <th width="40%">File: $url</th></tr>
 <tr><td bgcolor="#FFFFCC">
-<input type=button onClick="javascript:groupsearch()" value="$lt{'se'}">
-<input type=button onClick="javascript:groupimport();" value="$lt{'im'}">
+<input type="button" onClick="javascript:groupsearch()" value="$lt{'se'}" />
+<input type="button" onClick="javascript:groupimport();" value="$lt{'im'}" />
 $lt{'as'}
-<hr>
-<input type=text size=20 name=importmap>
-<input type=button 
+<hr />
+<input type="text" size="20" name="importmap" />
+<input type="button" 
 onClick="javascript:openbrowser('simpleedit','importmap','sequence,page','')"
-value="Select Map"><input type=submit name=loadmap value="$lt{'lm'}"><hr>
-<input type=submit name="discard" value="$lt{'ds'}">
-<input type=submit name="clear" value="$lt{'ca'}">
-<input type=button onClick="javascript:viewimport()" value="$lt{'vi'}">
+value="Select Map" /><input type="submit" name="loadmap" value="$lt{'lm'}" /><hr />
+<input type="submit" name="discard" value="$lt{'ds'}" />
+<input type="submit" name="clear" value="$lt{'ca'}" />
+<input type="button" onClick="javascript:viewimport()" value="$lt{'vi'}" />
 
     </td><td>&nbsp;</td><td bgcolor="#FFFFCC">
 
-<input type=button onClick=
-"javascript:impfortarget.value=1;groupsearch()" value="$lt{'se'}">
-<input type=button onClick=
-"javascript:impfortarget.value=1;groupimport();" value="$lt{'im'}">
-<input type=button onClick=
-"javascript:impfortarget.value=1;groupopen(0,1,1);" value="$lt{'bk'}">
-<input type=button onClick=
-"javascript:impfortarget.value=1;groupopen('$url',1,0);" value="$lt{'reco'}">
+<input type="button" onClick=
+"javascript:impfortarget.value=1;groupsearch()" value="$lt{'se'}" />
+<input type="button" onClick=
+"javascript:impfortarget.value=1;groupimport();" value="$lt{'im'}" />
+<input type="button" onClick=
+"javascript:impfortarget.value=1;groupopen(0,1,1);" value="$lt{'bk'}" />
+<input type="button" onClick=
+"javascript:impfortarget.value=1;groupopen('$url',1,0);" value="$lt{'reco'}" />
 $lt{'as'}
-<hr>
-<input type=submit name="moveup" value="$lt{'mu'}">
-<input type=submit name="movedown" value="$lt{'md'}">
-<input type=button onClick="javascript:renametarget()" value="$lt{'re'}">
-<hr>$targetmsg
-<input type=submit name="revert" value="$lt{'rv'}">
-<input type=submit name="save" value="$lt{'sa'}">
-<input type=button onClick="javascript:viewtarget()" value="$lt{'vi'}">
+<hr />
+<input type="submit" name="moveup" value="$lt{'mu'}" />
+<input type="submit" name="movedown" value="$lt{'md'}" />
+<input type="button" onClick="javascript:renametarget()" value="$lt{'re'}" />
+<hr />$targetmsg
+<input type="submit" name="revert" value="$lt{'rv'}" />
+<input type="submit" name="save" value="$lt{'sa'}" />
+<input type="button" onClick="javascript:viewtarget()" value="$lt{'vi'}" />
 </td></tr>
 
-<tr><td bgcolor="#FFFFCC"><select name="importsel" size=10 multiple>
+<tr><td bgcolor="#FFFFCC"><select name="importsel" size="10" multiple="multiple">
 $importwindow
 </select>
 </td>
 <td bgcolor="#FFFFAA" align="center">
-$lt{'cs'}<br>
-<input type=submit name=cut value='<<<'><p>
-<hr>
-$lt{'ps'}<br>
-<input type=submit name=copy value='<--'><p>
-<hr>
-$lt{'pas'}<br>
-<input type=submit name=paste value='-->'>
+$lt{'cs'}<br />
+<input type="submit" name="cut" value="<<<" /><p>
+<hr />
+$lt{'ps'}<br />
+<input type="submit" name="copy" value="<--" /><p>
+<h /r>
+$lt{'pas'}<br />
+<input type="submit" name="paste" value="-->" />
 </td>
-<td bgcolor="#FFFFCC"><select name="target" size=10 multiple>
+<td bgcolor="#FFFFCC"><select name="target" size="10" multiple="multiple">
 $targetwindow
 </select>
 </table>
-<input type=hidden name=importdetail value="">
-<input type=hidden name=curimpdetail value="$importdetail">
-<input type=hidden name=targetdetail value="$targetdetail">
-<input type=hidden name=impfortarget value="0">
+<input type="hidden" name="importdetail" value="" />
+<input type="hidden" name="curimpdetail" value="$importdetail" />
+<input type="hidden" name="targetdetail" value="$targetdetail" />
+<input type="hidden" name="impfortarget" value="0" />
 </form>
 $end_page
 ENDSMPHEAD
@@ -762,7 +627,9 @@ sub nodir {
    $r->print(&Apache::loncommon::start_page(undef,undef,
 					    {'only_body' => 1,
 					     'bgcolor'   => '#FFFFFF',}).
-	     "<h1>No such directory: $dir</h1>".
+             '<p class="LC_error">'.
+             &mt('No such directory: [_1]','<span class="LC_filename">'.$dir.'</span>').
+             '</p>'.
 	     &Apache::loncommon::end_page());
 }
 
@@ -782,7 +649,7 @@ sub viewmap {
         );
     }
     my $idx=0;
-    $r->print('<h1>'.$url.'</h1>');
+    $r->print('<p><span class="LC_filename">'.$url.'</span></p>');
     if ($adv) {
 	$r->print('<p class="LC_warning">'
                  .&mt('Map contents are not shown in order.')
@@ -907,7 +774,140 @@ __END__
 
 
 
+=pod
 
+=head1 NAME
+
+Apache::lonratedt: simple resource assembly tool
+
+=head1 SYNOPSIS
+
+lonratedt provides the routines and the handler for the Advanced
+    Resource Assembly Tool (RAT), and ties the various pieces together
+    with Javascript.
+
+=head1 OVERVIEW
+
+=head2 Map Representation
+
+=begin latex
+
+%
+\begin{figure}
+\begin{center}\includegraphics[%
+  width=0.55\paperwidth,bb = 0 0 200 100, draft, type=eps]{Map_Example}\end{center}
+
+
+\caption{\label{Map_In_Advanced_Editor}Example of a Map in the Advanced Editor}
+\end{figure}
+%
+\begin{figure}
+\begin{lyxcode}
+<map>
+
+~~<resource~id=\char`\"{}1\char`\"{}
+
+~~~~src=\char`\"{}/res/msu/korte/phy231welcome.html\char`\"{}
+
+~~~~type=\char`\"{}start\char`\"{}
+
+~~~~title=\char`\"{}Start\char`\"{}>
+
+~~~~</resource>
+
+~~<resource~id=\char`\"{}2\char`\"{}
+
+~~~~src=\char`\"{}\char`\"{}~type=\char`\"{}finish\char`\"{}
+
+~~~~title=\char`\"{}Finish\char`\"{}>
+
+~~~~</resource>
+
+~~<resource~id=\char`\"{}6\char`\"{}
+
+~~~~src=\char`\"{}/res/msu/korte/tests/units.problem\char`\"{}
+
+~~~~type=\char`\"{}mandatory\char`\"{}
+
+~~~~title=\char`\"{}Physical~Units~Test\char`\"{}>
+
+~~~~</resource>
+
+~~<resource~id=\char`\"{}9\char`\"{}
+
+~~~~src=\char`\"{}/res/msu/korte/chapters/onedim.sequence\char`\"{}
+
+~~~~title=\char`\"{}Motion~in~One~Dimension\char`\"{}>
+
+~~~~</resource>
+
+~~<resource~id=\char`\"{}11\char`\"{}
+
+~~~~src=\char`\"{}/res/msu/bauer/bridges/units.sequence\char`\"{}
+
+~~~~title=\char`\"{}Physical~Units~Refresher\char`\"{}>
+
+~~~~</resource>
+
+~~<condition~id=\char`\"{}19\char`\"{}
+
+~~~~type=\char`\"{}stop\char`\"{}
+
+~~~~value=\char`\"{}user.assessments{[}this./res/msu/korte/tests/units.problem{]}.status=solved\char`\"{}>
+
+~~~~</condition>
+
+~~<link~from=\char`\"{}1\char`\"{}~to=\char`\"{}6\char`\"{}></link>
+
+~~<link~from=\char`\"{}6\char`\"{}~to=\char`\"{}9\char`\"{}~condition=\char`\"{}19\char`\"{}></link>
+
+~~<link~from=\char`\"{}6\char`\"{}~to=\char`\"{}11\char`\"{}></link>
+
+~~<link~from=\char`\"{}11\char`\"{}~to=\char`\"{}6\char`\"{}></link>
+
+~~</map>
+\end{lyxcode}
+
+\caption{\label{XML}XML for Map in Figure \ref{Map_In_Advanced_Editor}}
+\end{figure}
+
+=end latex
+
+Fig. "XML for Map in Figure" shows the XML representation of the
+resource map shown in Fig. "Example of a Map in the Advanced Editor",
+which is the format in which maps are stored. In the figure, however,
+additional graphical map layout information generated by the Advanced
+Resource Assembly Tool is not displayed. This graphical information is
+optional to re-generate the same graphical layout when the map is
+brought up again in the Resource Assembly Tool, and is not needed for
+any other system functionality.
+
+Maps can be generated by tools other than the Resource Assembly
+Tool. In particular, an author might have some other representation of
+a course sequence, which can be converted into a map using scripts. If
+this map then were to be brought up in the Resource Assembly Tool, the
+Tool would automatically generate a graphical layout for it. Each
+entry of the map (resources, conditions and links) is stored in a
+separate tag.
+
+Resources and conditionsX<conditions> have to have unique ID
+numbers. These numbers are automatically generated by the Resource
+Assembly Tool when the entry is first created, or added to the entries
+when a map generated outside the Resource Assembly Tool is first
+retrieved. They can also be assigned by custom scripts or added in by
+hand.
+
+In the XML example, entry 1 is the start resource of the map. When
+this map is accessed, the source (src) URL of this tag will be the
+first resource rendered. Entry 2 is the finish resource of this
+map. This resource will be the last resource in the sequence of
+resources. Entry 6 is a problem resource with the given URL and title,
+as well as the priority "mandatory". Entry 19 is a condition, which is
+used by the link between entries 6, the problem, and 9, a
+sequence. I<The final syntax for conditions has not yet been
+determined.>
+
+=cut
 
 
 
