@@ -2,7 +2,7 @@
 # Build menu bar for Advanced RAT. Uses javascript code originally in
 # static file: rat/client/code.html, now in  rat/client/ratcode.js  
 #
-# $Id: lonratmenu.pm,v 1.10 2008/03/22 01:39:05 raeburn Exp $
+# $Id: lonratmenu.pm,v 1.11 2009/04/23 17:31:25 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -57,8 +57,8 @@ sub print_html {
     my $help=&Apache::loncommon::help_open_menu('Sequence_Advanced_Editor_Creation','Sequence_Advanced_Editor_Creation',6,'RAT');
 
     my $pagetext = <<"END";
-<table border=0><tr><td bgcolor="#aaaaaa">
-<table border=0><tr>
+<table border="0"><tr><td bgcolor="#AAAAAA">
+<table border="0"><tr>
 <td bgcolor="#ffffcc">$help</td>
 <td bgcolor="#ffffcc"><a href="javascript:togglemode();"><font size="-2">Toggle display</font></a></td>
 <td bgcolor="#ffffcc"><a href="javascript:if (zscale>1) { zscale--; draw();}"><font size="-2">Zoom out</font></a></td>
